@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 13:51:10
-@LastEditTime: 2022-11-25 09:59:01
+@LastEditTime: 2024-09-06 18:05:01
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -11,7 +11,6 @@ from seven_cloudapp_frame.models.app_base_model import *
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.mp_base_model import *
 from seven_cloudapp_frame.models.push_base_model import *
-from seven_cloudapp_frame.libs.customize.baidubce_helper import *
 
 
 class AppExpireHandler(ClientBaseHandler):
@@ -44,6 +43,7 @@ class CreateWeChatQrCodeHandler(ClientBaseHandler):
         :param page：跳转地址
         :param scene：参数，不限制小程序码才支持
         :param env_version：要打开的小程序版本。正式版为 "release"，体验版为 "trial"，开发版为 "develop"。默认是正式版。不限制小程序码才支持
+        :param check_path: 检查page 是否存在，为 true 时 page 必须是已经发布的小程序存在的页面（否则报错）；为 false 时允许小程序未发布或者 page 不存在
         :param width：宽度
         :param no_limit_code：是否不限制小程序码（1-是0否）
         :return: 二进制流
@@ -53,9 +53,11 @@ class CreateWeChatQrCodeHandler(ClientBaseHandler):
         scene = self.get_param("scene", "a=1")
         width = self.get_param_int("width", 430)
         env_version = self.get_param("env_version", "release")
+        check_path = self.get_param_int("check_path", 1)
+        check_path = True if check_path == 1 else False
         no_limit_code = self.get_param_int("no_limit_code", 1)
         if no_limit_code == 1:
-            invoke_result_data = WeChatHelper.create_qr_code_unlimit(page=page, scene=scene, width=width, env_version=env_version)
+            invoke_result_data = WeChatHelper.create_qr_code_unlimit(page=page, scene=scene, width=width, env_version=env_version, check_path=check_path)
         else:
             invoke_result_data = WeChatHelper.create_qr_code(path=page, width=width)
         self.set_header("Content-type", "image/png")
@@ -70,18 +72,35 @@ class UploadFileHandler(ClientBaseHandler):
     :description: 上传文件
     """
 
-    def get_async(self):
+    def post_async(self):
         """
         :description: 上传文件
         :last_editors: HuangJianYi
         """
+        from seven_cloudapp_frame.models.enum import FileStorageType
+
+        is_auto_name = self.get_param_int("is_auto_name", 1)
+        is_auto_name = True if is_auto_name == 1 else False
         # 上传图片到资源服务器
         if not self.request.files:
             return self.response_json_error("error", "未获取到文件")
-
-        file_path = BaidubceHelper.upload_file(self.request.files, context=self)
+        # 上传图片到资源服务器
+        files_data = self.request.files
+        if not files_data or not files_data["image"] or not files_data["image"][0] or not files_data["image"][0]['body']:
+            return self.response_json_error("error", "未获取到文件")
+        file_name = files_data["image"][0]['filename']
+        file_storage_type = share_config.get_value("file_storage_type", FileStorageType.cos.value)
+        if file_storage_type == FileStorageType.cos.value:
+            from seven_cloudapp_frame.libs.customize.file_helper import COSHelper
+            file_path = COSHelper.upload(file_name=file_name, data=files_data["image"][0]['body'], is_auto_name=is_auto_name)
+        elif file_storage_type == FileStorageType.oss.value:
+            from seven_cloudapp_frame.libs.customize.file_helper import OSSHelper
+            file_path = OSSHelper.upload(file_name=file_name, data=files_data["image"][0]['body'], is_auto_name=is_auto_name)
+        else:
+            from seven_cloudapp_frame.libs.customize.file_helper import BOSHelper
+            file_path = BOSHelper.upload(file_name=file_name, data=files_data["image"][0]['body'], is_auto_name=is_auto_name)
         if not file_path:
-            return self.response_json_error("error", "上传文件失败")
+            return self.response_json_error("error", "上传文件出错")
         return self.response_json_success(file_path)
 
 
@@ -127,12 +146,20 @@ class GetHighPowerListHandler(ClientBaseHandler):
         config_data["is_customized"] = 0
         top_base_model = TopBaseModel(context=self)
         mp_base_model = MPBaseModel(context=self)
-        custom_function_list = mp_base_model.get_custom_function_list(store_user_nick)
+        invoke_result_data = mp_base_model.get_custom_function_list(store_user_nick)
+        if invoke_result_data.success == True:
+            custom_function_list = invoke_result_data.data if invoke_result_data.data else []
+        else:
+            custom_function_list = mp_base_model.get_api_custom_function_list(store_user_nick)
         if len(custom_function_list) == 0:
             app_key, app_secret = self.get_app_key_secret()
             #获取项目编码
             project_code = top_base_model.get_project_code(store_user_nick, access_token, app_key, app_secret)
-            public_function_list = mp_base_model.get_public_function_list(project_code)
+            invoke_result_data = mp_base_model.get_public_function_list(project_code)
+            if invoke_result_data.success == True:
+                public_function_list = invoke_result_data.data if invoke_result_data.data else []
+            else:
+                public_function_list = mp_base_model.get_api_public_function_list(project_code)
             if len(public_function_list) > 0:
                 config_data["function_config_list"] = query(public_function_list[0]["function_info_second_list"]).select(lambda x: {"name": x["name"], "key_name": x["key_name"]}).to_list()
         else:
