@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2023-02-10 10:52:08
+@LastEditTime: 2024-12-05 16:43:48
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -87,9 +87,10 @@ class SyncPayOrderHandler(ClientBaseHandler):
         sku_id = invoke_result_data.data["sku_id"] if invoke_result_data.data.__contains__("sku_id") else ""
         ascription_type = invoke_result_data.data["ascription_type"] if invoke_result_data.data.__contains__("ascription_type") else 1
         check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
-        continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
+        continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 1
+        error_return = invoke_result_data.data["error_return"] if invoke_result_data.data.__contains__("error_return") else True
         invoke_result_data = order_base_model.sync_tao_pay_order(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, asset_type, goods_id, sku_id, ascription_type, app_key, app_secret, is_log, check_user_nick, continue_request_expire)
-        if invoke_result_data.success == False:
+        if invoke_result_data.success == False and error_return == True:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
         ref_params["app_id"] = app_id
@@ -121,11 +122,88 @@ class SyncPayOrderHandler(ClientBaseHandler):
         return result_data
 
 
+class SyncShakeShopPayOrderHandler(ClientBaseHandler):
+    """
+    :description: 同步抖店订单给用户加资产
+    """
+    @filter_check_params(check_user_code=True)
+    def get_async(self):
+        """
+        :description: 同步抖店订单给用户加资产
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_code:用户标识
+        :param open_id:open_id
+        :param login_token:访问令牌
+        :return
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
+        user_id = self.get_user_id()
+        open_id = self.get_param("open_id")
+        module_id = self.get_param_int("module_id")
+        login_token = self.get_param("login_token")
+
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        is_log = invoke_result_data.data.get("is_log", False)
+        asset_type = invoke_result_data.data.get("asset_type", 3)
+        while_count = invoke_result_data.data.get("while_count", 1)
+        ascription_type = invoke_result_data.data.get("ascription_type", 0)
+        order_base_model = OrderBaseModel(context=self)
+        invoke_result_data = order_base_model.sync_shake_shop_pay_order(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, is_log, asset_type=asset_type, while_count=while_count, ascription_type=ascription_type)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        
+        ref_params = {}
+        ref_params["app_id"] = app_id
+        ref_params["act_id"] = act_id
+        ref_params["module_id"] = module_id
+        ref_params["user_id"] = user_id
+        ref_params["open_id"] = open_id
+        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        return self.response_json_success(invoke_result_data.data)
+    
+    def business_process_executing(self):
+        """
+        :description: 执行前事件
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {"is_log":False}
+        return invoke_result_data
+
+    def business_process_executed(self, result_data, ref_params):
+        """
+        :description: 执行后事件
+        :param result_data:result_data
+        :param ref_params: 关联参数
+        :return:
+        :last_editors: HuangJianYi
+        """
+        UserInfoModel(context=self).update_table("pay_price=pay_price+%s,pay_num=pay_num+%s", "act_id=%s and user_id=%s", params=[result_data.data["pay_price"], result_data.data["pay_num"], ref_params["act_id"],ref_params["user_id"]])
+        stat_base_model = StatBaseModel(context=self)
+        key_list_dict = {}
+        key_list_dict["PayUserCount"] = 1
+        key_list_dict["PayCount"] = result_data.data["pay_num"]
+        key_list_dict["PayMoneyCount"] = result_data.data["pay_price"]
+        stat_base_model.add_stat_list(ref_params["app_id"], ref_params["act_id"], ref_params["module_id"], ref_params["user_id"], ref_params["open_id"], key_list_dict)
+        return result_data
+
+   
 class PrizeOrderListHandler(ClientBaseHandler):
     """
     :description: 用户奖品订单列表
     """
-    filter_check_params(check_user_code=True)
+    @filter_check_params(check_user_code=True)
     def get_async(self):
         """
         :description: 用户奖品订单列表
@@ -165,7 +243,7 @@ class PrizeOrderListHandler(ClientBaseHandler):
         page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
 
@@ -189,7 +267,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
     """
     :description: 用户中奖记录列表
     """
-    filter_check_params(check_user_code=True)
+    @filter_check_params(check_user_code=True)
     def get_async(self):
         """
         :description: 用户中奖记录列表
@@ -273,9 +351,9 @@ class SubmitSkuHandler(ClientBaseHandler):
         sku_name = self.get_param("sku_name")
         sku_id = self.get_param("sku_id")
 
-        prize_roster_model = PrizeRosterModel(sub_table=FrameBaseModel(context=self).get_business_sub_table("prize_roster_tb", {"app_id": app_id}), context=self)
+        prize_roster_model = PrizeRosterModel(context=self).set_sub_table(app_id)
         prize_roster = prize_roster_model.get_entity_by_id(user_prize_id)
-        if not prize_roster or prize_roster.open_id != open_id or prize_roster.app_id != app_id:
+        if not prize_roster or prize_roster.open_id != open_id or SafeHelper.authenticat_app_id(prize_roster.app_id, app_id) == False:
             return self.response_json_error("no_user_prize", "对不起，找不到该奖品")
         if prize_roster.is_sku > 0:
             prize_roster.sku_id = sku_id
