@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2023-02-10 09:52:14
+@LastEditTime: 2023-07-30 15:50:53
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -11,7 +11,7 @@ from seven_cloudapp_frame.libs.customize.seven_helper import SevenHelper
 from seven_cloudapp_frame.libs.customize.wechat_helper import WeChatPayRequest, WeChatPayReponse, WeChatRefundReponse
 from seven_cloudapp_frame.libs.customize.tiktok_helper import TikTokPayRequest, TikTokReponse
 from seven_cloudapp_frame.libs.customize.alipay_helper import AliPayRequest
-from seven_cloudapp_frame.models.shakeshop_base_model import *
+from seven_cloudapp_frame.models.third.shakeshop_base_model import *
 from seven_cloudapp_frame.models.price_base_model import *
 from seven_cloudapp_frame.models.asset_base_model import *
 from seven_cloudapp_frame.handlers.frame_base import *
@@ -42,7 +42,7 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
         pay_order_model = PayOrderModel(context=self)
         pay_order = pay_order_model.get_entity("pay_order_no=%s", params=[pay_order_no])
         if not pay_order or pay_order.order_status != 0:
-            return self.response_json_error("error", "抱歉!未查询到订单信息,请联系客服")
+            return self.response_json_error("error", "抱歉!未查询到订单信息,请稍后再试")
         pay_config = share_config.get_value("wechat_pay")
         pay_notify_url = pay_config["pay_notify_url"]
 
@@ -55,9 +55,10 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
 
         try:
             invoke_result_data = self.business_process_executing()
-            if invoke_result_data.success == True:
-                pay_notify_url = invoke_result_data.data["pay_notify_url"] if invoke_result_data.data.__contains__("pay_notify_url") else pay_notify_url
-                time_expire = invoke_result_data.data["time_expire"] if invoke_result_data.data.__contains__("time_expire") else str(SevenHelper.get_now_int(hours=1))  #交易结束时间,设置1小时
+            if invoke_result_data.success == False:
+                return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+            pay_notify_url = invoke_result_data.data["pay_notify_url"] if invoke_result_data.data.__contains__("pay_notify_url") else pay_notify_url
+            time_expire = invoke_result_data.data["time_expire"] if invoke_result_data.data.__contains__("time_expire") else str(SevenHelper.get_now_int(hours=1))  #交易结束时间,设置1小时
             invoke_result_data = WeChatPayRequest().create_order(pay_order_no, body, total_fee, ip, pay_notify_url, pay_order.open_id, time_expire)
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -184,7 +185,8 @@ class WechatRefundNotifyHandler(FrameBaseHandler):
         :last_editors: HuangJianYi
         """
         req_info_dict = ref_params["req_info_dict"]
-        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"), context=self)
+        db_connect_key = "db_order" if config.get_value("db_order") else "db_cloudapp"
+        db_transaction = DbTransaction(db_config_dict=config.get_value(db_connect_key), context=self)
         pay_order_model = PayOrderModel(db_transaction=db_transaction, context=self)
         refund_order_model = RefundOrderModel(db_transaction=db_transaction, context=self)
         try:
@@ -379,7 +381,8 @@ class TiktokRefundNotifyHandler(FrameBaseHandler):
         """
         refund_order = ref_params["refund_order"]
         response_data = ref_params["response_data"]
-        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"), context=self)
+        db_connect_key = "db_order" if config.get_value("db_order") else "db_cloudapp"
+        db_transaction = DbTransaction(db_config_dict=config.get_value(db_connect_key), context=self)
         pay_order_model = PayOrderModel(db_transaction=db_transaction, context=self)
         refund_order_model = RefundOrderModel(db_transaction=db_transaction, context=self)
         try:
@@ -446,8 +449,7 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                         act_info_model = ActInfoModel(context=self)
                         act_info_dict = act_info_model.get_cache_dict(order_by="id desc")
                         if act_info_dict:
-                            frame_base_model = FrameBaseModel(context=self)
-                            user_info_model = UserInfoModel(sub_table=frame_base_model.get_business_sub_table("user_info_tb", {"app_id": act_info_dict["app_id"]}), context=self)
+                            user_info_model = UserInfoModel(context=self).set_sub_table(act_info_dict["app_id"])
                             user_info_dict = user_info_model.get_cache_dict("act_id=%s and open_id=%s", limit="1", order_by="id desc", params=[act_info_dict["id"],open_id])
                             if user_info_dict:
                                 tiktok_goods_id_list = []
