@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2023-03-03 14:54:15
+@LastEditTime: 2025-04-25 15:25:34
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,13 +16,14 @@ from seven_cloudapp_frame.models.asset_base_model import *
 from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.libs.customize.wechat_helper import *
 from seven_cloudapp_frame.libs.customize.tiktok_helper import *
-from seven_cloudapp_frame.libs.customize.riskmanage_helper import *
+from seven_cloudapp_frame.libs.customize.safe_helper import *
 
 class LoginHandler(ClientBaseHandler):
     """
     :description: 登录处理
     """
     @filter_check_current_limit()
+    @filter_check_flow_limit()
     def get_async(self):
         """
         :description: 登录处理
@@ -48,16 +49,20 @@ class LoginHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if not invoke_result_data.data:
             invoke_result_data.data = {}
-        is_update_user_nick = invoke_result_data.data["is_update_user_nick"] if invoke_result_data.data.__contains__("is_update_user_nick") else True
+        is_update_user_nick = invoke_result_data.data.get("is_update_user_nick", True) # 是否更新昵称
+
+        plat_type = share_config.get_value("plat_type", PlatType.tb.value)  # 平台类型
         login_ip = self.get_remote_ip()
         union_id = ""
         if pt == "wx" and code:
+            plat_type = PlatType.wx.value
             invoke_result_data = WeChatHelper.code2_session(code, app_id=share_config.get_value("app_id"), app_secret=share_config.get_value("app_secret"))
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
             open_id =  invoke_result_data.data["openid"]
             union_id =  invoke_result_data.data.get("unionid","")
         elif pt == "tt" and code:
+            plat_type = PlatType.dy.value
             invoke_result_data = TikTokHelper.code2_session(code, anonymous_code, app_id=share_config.get_value("app_id"), app_secret=share_config.get_value("app_secret"))
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -66,9 +71,10 @@ class LoginHandler(ClientBaseHandler):
             login_ip = self.get_param("source_ip")
 
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar, union_id, login_ip, is_update_user_nick, mix_nick)
+        invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar, union_id, login_ip, is_update_user_nick, mix_nick, plat_type)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+
         invoke_result_data.data["user_nick"] = CryptographyHelper.emoji_base64_to_emoji(invoke_result_data.data["user_nick"])
         if invoke_result_data.data["user_nick_encrypt"]:
             invoke_result_data.data["user_nick"] = CryptographyHelper.base64_decrypt(invoke_result_data.data["user_nick_encrypt"])
@@ -150,11 +156,18 @@ class CheckIsMemberHandler(ClientBaseHandler):
         mix_nick = self.get_param("mix_nick")
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
-        app_base_model = AppBaseModel(context=self)
-        app_info_dict = app_base_model.get_app_info_dict(app_id=app_id,is_cache=True,field="access_token")
-        if not app_info_dict:
-            return self.response_json_error("error", "小程序不存在")
-        access_token = app_info_dict["access_token"]
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        access_token = invoke_result_data.data.get('access_token', None)
+        if access_token is None:
+            app_base_model = AppBaseModel(context=self)
+            app_info_dict = app_base_model.get_app_info_dict(app_id=app_id,is_cache=True,field="access_token")
+            if not app_info_dict:
+                return self.response_json_error("error", "小程序不存在")
+            access_token = app_info_dict["access_token"]
         if access_token == "":
             return self.response_json_error("error", "未授权请联系客服授权")
         top_base_model = TopBaseModel(context=self)
@@ -178,11 +191,18 @@ class GetCrmIntegralHandler(ClientBaseHandler):
         mix_nick = self.get_param("mix_nick")
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
-        app_base_model = AppBaseModel(context=self)
-        app_info_dict = app_base_model.get_app_info_dict(app_id=app_id,is_cache=True,field="access_token")
-        if not app_info_dict:
-            return self.response_json_error("error", "小程序不存在")
-        access_token = app_info_dict["access_token"]
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        access_token = invoke_result_data.data.get('access_token', None)
+        if access_token is None:
+            app_base_model = AppBaseModel(context=self)
+            app_info_dict = app_base_model.get_app_info_dict(app_id=app_id,is_cache=True,field="access_token")
+            if not app_info_dict:
+                return self.response_json_error("error", "小程序不存在")
+            access_token = app_info_dict["access_token"]
         if access_token == "":
             return self.response_json_error("error", "未授权请联系客服授权")
         top_base_model = TopBaseModel(context=self)
@@ -262,9 +282,15 @@ class GetCouponPrizeHandler(ClientBaseHandler):
         user_prize_id = int(self.get_param("user_prize_id", 0))
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        access_token = invoke_result_data.data.get('access_token', None)
         order_base_model = OrderBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = order_base_model.get_coupon_prize(app_id, act_id, user_id, user_prize_id, app_key, app_secret, is_log)
+        invoke_result_data = order_base_model.get_coupon_prize(app_id, act_id, user_id, user_prize_id, app_key, app_secret, is_log, access_token=access_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message, invoke_result_data.data)
         else:
@@ -383,13 +409,23 @@ class GetJoinMemberUrlHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
-        app_base_model = AppBaseModel(context=self)
-        app_info_dict = app_base_model.get_app_info_dict(app_id=app_id,is_cache=True,field="access_token")
-        if not app_info_dict:
-            return self.response_json_error("error", "小程序不存在")
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        access_token = invoke_result_data.data.get('access_token', None)
+        if access_token is None:
+            app_base_model = AppBaseModel(context=self)
+            app_info_dict = app_base_model.get_app_info_dict(app_id=app_id,is_cache=True,field="access_token")
+            if not app_info_dict:
+                return self.response_json_error("error", "小程序不存在")
+            access_token = app_info_dict["access_token"]
+        if access_token == "":
+            return self.response_json_error("error", "未授权请联系客服授权")
         app_key, app_secret = self.get_app_key_secret()
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.get_join_member_url(app_info_dict["access_token"], app_key, app_secret, is_log=is_log)
+        invoke_result_data = user_base_model.get_join_member_url(access_token, app_key, app_secret, is_log=is_log)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -431,6 +467,7 @@ class SaveUserAddressHandler(ClientBaseHandler):
         :param county：区
         :param street：街道
         :param adress：地址
+        :param remark：备注
         :return: dict
         :last_editors: HuangJianYi
         """
@@ -447,5 +484,60 @@ class SaveUserAddressHandler(ClientBaseHandler):
         street = self.get_param("street")
         address = self.get_param("address")
         is_default = int(self.get_param("is_default", 0))
+        remark = self.get_param("remark")
         user_base_model = UserBaseModel(context=self)
-        return self.response_json_success(user_base_model.save_user_address(app_id, act_id, user_id, open_id, user_address_id, real_name, telephone, province, city, county, street, address, is_default))
+        return self.response_json_success(user_base_model.save_user_address(app_id, act_id, user_id, open_id, user_address_id, real_name, telephone, province, city, county, street, address, is_default, remark))
+
+
+class UserAvatarHandler(ClientBaseHandler):
+    """
+    :description: 修改头像
+    """
+
+    @filter_check_params(check_user_code=True)
+    def post_async(self):
+        """
+        :description: 修改头像
+        :return:
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
+        user_id = self.get_user_id()
+        now_date = self.get_now_datetime()
+
+        # 上传图片到资源服务器
+        files_data = self.request.files
+        if not files_data or not files_data["image"] or not files_data["image"][0] or not files_data["image"][0]['body']:
+            return self.response_json_error("error", "未获取到文件")
+
+        file_name = files_data["image"][0]['filename']
+        file_storage_type = share_config.get_value("file_storage_type", FileStorageType.cos.value)
+        if file_storage_type == FileStorageType.cos.value:
+            from seven_cloudapp_frame.libs.customize.file_helper import COSHelper
+            result = COSHelper.upload(file_name=file_name, data=files_data["image"][0]['body'])
+        elif file_storage_type == FileStorageType.oss.value:
+            from seven_cloudapp_frame.libs.customize.file_helper import OSSHelper
+            result = OSSHelper.upload(file_name=file_name, data=files_data["image"][0]['body'])
+        else:
+            from seven_cloudapp_frame.libs.customize.file_helper import BOSHelper
+            result = BOSHelper.upload(file_name=file_name, data=files_data["image"][0]['body'])
+        if not result:
+            return self.response_json_error("error", "上传文件出错")
+        user_base_model = UserBaseModel(context=self)
+        id_md5 = user_base_model._get_user_info_id_md5(act_id, user_id)
+        user_info_model = UserInfoModel(context=self).set_sub_table(app_id)
+        user_info = user_info_model.get_entity("id_md5=%s", params=[id_md5])
+        if not user_info:
+            return self.response_json_error("error", "用户信息不存在")
+        invoke_result_data = WeChatHelper.media_check_async(result, 2, 1, user_info.open_id)
+        if invoke_result_data.success == False:
+            return self.response_json_error("Except", "头像异常,请上传正确的头像")
+        # 更新
+        user_account_model = UserAccountModel(context=self)
+        user_account_model.update_table("avatar=%s,modify_date=%s", "id=%s", params=[result, now_date, user_id])
+        user_info.avatar = result
+        user_info.modify_date = now_date
+        user_info_model.update_entity(user_info, "avatar,modify_date")
+        user_base_model._delete_user_info_cache(user_info.act_id, user_info.id_md5)
+        return self.response_json_success({"user_avatar": result})
