@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2023-02-17 18:20:19
+@LastEditTime: 2024-02-02 09:08:34
 @LastEditors: HuangJianYi
 @Description: 活动模块
 """
@@ -87,6 +87,7 @@ class AddActInfoHandler(ClientBaseHandler):
         :param d2: d2
         :param agreement_json: 协议配置（用户协议或隐私条款）
         :param brand_json: 品牌配置
+        :param business_type: 业务类型
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
@@ -121,6 +122,7 @@ class AddActInfoHandler(ClientBaseHandler):
         is_visit_store = int(self.get_param("is_visit_store", -1))
         agreement_json = self.get_param("agreement_json", None)
         brand_json = self.get_param("brand_json", None)
+        business_type = self.get_param_int("business_type", -1)
 
 
         invoke_result_data = self.business_process_executing()
@@ -130,7 +132,7 @@ class AddActInfoHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
         act_base_model = ActBaseModel(context=self)
-        invoke_result_data = act_base_model.add_act_info(app_id, act_name, act_type, theme_id, share_desc_json, rule_desc_json, close_word, is_share, is_rule, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, is_visit_store, agreement_json, brand_json)
+        invoke_result_data = act_base_model.add_act_info(app_id, act_name, act_type, theme_id, share_desc_json, rule_desc_json, close_word, is_share, is_rule, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, is_visit_store, agreement_json, brand_json, business_type=business_type)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(operation_type=OperationType.add.value, model_name="act_info_tb", old_detail=None, update_detail=invoke_result_data.data, title= title_prefix + ";" + act_name)
@@ -178,6 +180,7 @@ class UpdateActInfoHandler(ClientBaseHandler):
         :param d2: d2
         :param agreement_json: 协议配置（用户协议或隐私条款）
         :param brand_json: 品牌配置
+        :param business_type: 业务类型
         :return: 
         :last_editors: HuangJianYi
         """
@@ -213,6 +216,7 @@ class UpdateActInfoHandler(ClientBaseHandler):
         d2 = self.get_param("d2", None)
         agreement_json = self.get_param("agreement_json", None)
         brand_json = self.get_param("brand_json", None)
+        business_type = self.get_param_int("business_type", -1)
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
@@ -221,7 +225,7 @@ class UpdateActInfoHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
         act_base_model = ActBaseModel(context=self)
-        invoke_result_data = act_base_model.update_act_info(app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, is_visit_store, agreement_json, brand_json)
+        invoke_result_data = act_base_model.update_act_info(app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, is_visit_store, agreement_json, brand_json, business_type=business_type)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         act_name = act_name if act_name else ''
@@ -242,6 +246,8 @@ class ActInfoListHandler(ClientBaseHandler):
         :description: 获取活动列表
         :param app_id：应用标识
         :param act_name: 活动名称
+        :param act_type: 活动类型
+        :param business_type: 业务类型
         :param is_del: 是否回收站1是0否
         :param is_release: 是否发布1是0否
         :param page_size: 条数
@@ -250,11 +256,12 @@ class ActInfoListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 20))
-        is_del = int(self.get_param("is_del", -1))
-        is_release = int(self.get_param("is_release", -1))
-        act_type = int(self.get_param("act_type", -1))
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 20)
+        is_del = self.get_param_int("is_del", 0)
+        is_release = self.get_param_int("is_release", -1)
+        act_type = self.get_param_int("act_type", -1)
+        business_type = self.get_param_int("business_type", -1)
         act_name = self.get_param("act_name")
 
         invoke_result_data = self.business_process_executing()
@@ -267,7 +274,7 @@ class ActInfoListHandler(ClientBaseHandler):
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id asc"
         app_base_model = AppBaseModel(context=self)
         act_base_model = ActBaseModel(context=self)
-        page_list, total = act_base_model.get_act_info_list(app_id, act_name, is_del, page_size, page_index, False, act_type, is_release, order_by)
+        page_list, total = act_base_model.get_act_info_list(app_id, act_name, is_del, page_size, page_index, False, act_type, is_release, order_by, business_type=business_type)
         for page in page_list:
             page["online_url"] = app_base_model.get_online_url(act_id=page['id'], app_id=app_id, act_type=page['act_type'])
             page["live_url"] = app_base_model.get_live_url(app_id)
@@ -297,7 +304,7 @@ class ActInfoHandler(ClientBaseHandler):
         app_base_model = AppBaseModel(context=self)
         act_info_dict = act_base_model.get_act_info_dict(act_id, False, False)
         if act_info_dict:
-            if act_info_dict["app_id"] != app_id:
+            if SafeHelper.authenticat_app_id(act_info_dict["app_id"], app_id) == False:
                 act_info_dict = {}
                 return self.response_json_success(act_info_dict)
             act_info_dict["finish_menu_config_json"] = self.json_loads(act_info_dict["finish_menu_config_json"]) if act_info_dict["finish_menu_config_json"] else []
