@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 10:43:58
-@LastEditTime: 2023-03-06 09:33:53
+@LastEditTime: 2025-01-13 14:36:49
 @LastEditors: HuangJianYi
 @Description: 应用模块
 """
@@ -12,6 +12,8 @@ from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.models.app_base_model import *
 from seven_cloudapp_frame.models.mp_base_model import *
 from seven_cloudapp_frame.models.asset_base_model import *
+from seven_cloudapp_frame.models.db_models.app.app_template_model import *
+from seven_cloudapp_frame.models.db_models.app.app_relation_model import *
 from asq.initiators import query
 
 
@@ -35,25 +37,64 @@ class InstantiateAppHandler(ClientBaseHandler):
         main_user_open_id = self.get_param("main_user_open_id")
         is_log = int(self.get_param("is_log", 0))
         is_log = True if is_log == 1 else False
-
+        
+        redis_init = RedisExHelper.init(config_dict=config.get_value("redis_safe"))
         cache_key = f"instantiate:{user_nick}"
-        if SevenHelper.is_continue_request(cache_key, 10000) == True:
-            return self.response_json_error("error","操作太频繁,请10秒后再试")
+        if SevenHelper.is_continue_request(cache_key, 60000) == True:
+            return self.response_json_error("error","操作太频繁,请60秒后再试")
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
+            redis_init.delete(cache_key)
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message,invoke_result_data.data)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        template_version = invoke_result_data.data.get("template_version", '')
         app_key, app_secret = self.get_app_key_secret()
         top_base_model = TopBaseModel(context=self)
-        invoke_result_data = top_base_model.instantiate(app_id, user_nick, access_token, app_key, app_secret, is_log, main_user_open_id)
+        invoke_result_data = top_base_model.instantiate(app_id, user_nick, access_token, app_key, app_secret, is_log, main_user_open_id, template_version=template_version)
         if invoke_result_data.success == False:
-            SevenHelper.redis_init().delete(cache_key)
+            redis_init.delete(cache_key)
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message,invoke_result_data.data)
         ref_params = {}
+        if user_nick and share_config.get_value("is_multiple_instantiate", False) == True:
+            relation_app_list = []
+            app_template_model = AppTemplateModel(context=self)
+            app_relation_model = AppRelationModel(context=self)
+            app_template_dict_list = app_template_model.get_dict_list()
+            if len(app_template_dict_list) > 0:
+                store_user_nick = user_nick.split(':')[0] if user_nick else ""
+                app_info_dict_list = AppInfoModel(context=self).get_dict_list("store_user_nick=%s", field="template_id", params=[store_user_nick])
+                for app_template_dict in app_template_dict_list:
+                    if query(app_info_dict_list).count(lambda x: x["template_id"] == app_template_dict["template_id"]) > 0:
+                        continue
+                    relation_invoke_result_data = top_base_model.instantiate("", user_nick, access_token, app_key, app_secret, is_log, main_user_open_id, app_name=app_template_dict["product_name"], description=app_template_dict["product_desc"], icon=app_template_dict["product_icon"], 
+                                                                             template_id=app_template_dict["template_id"], template_version=app_template_dict["client_ver"], is_instance=2)
+                    if relation_invoke_result_data.success == False:
+                        self.logging_link_error(f"模板ID：{app_template_dict['template_id']}实例化失败，原因：{relation_invoke_result_data.error_message}")
+                    else:
+                        app_relation = AppRelation()
+                        app_relation.app_id = invoke_result_data.data["app_id"]
+                        app_relation.template_id = share_config.get_value("client_template_id")
+                        app_relation.ref_app_id = relation_invoke_result_data.data["app_id"]
+                        app_relation.ref_template_id = app_template_dict["template_id"]
+                        app_relation.create_date = TimeHelper.get_now_format_time()
+                        relation_app_list.append(app_relation)
+                if len(relation_app_list) > 0:
+                    app_relation_model.add_list(relation_app_list)
+                    app_relation_model.delete_dependency_key(DependencyKey.app_relation(invoke_result_data.data["app_id"]))
+                ref_params["relation_app_list"] = relation_app_list
+        
+        # 判断是否首次实例化，是的话更新项目版本号
+        if invoke_result_data.data.get("is_first_instance", False) == True:
+            base_info = BaseInfoModel(context=self).get_entity()
+            if base_info and base_info.project_ver:
+                AppInfoModel(context=self).update_table("project_ver=%s", "app_id=%s", [base_info.project_ver, invoke_result_data.data["app_id"]])
+
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
-            SevenHelper.redis_init().delete(cache_key)
+            redis_init.delete(cache_key)
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        SevenHelper.redis_init().delete(cache_key)
+        redis_init.delete(cache_key)
         return self.response_json_success(invoke_result_data.data)
 
 
@@ -77,7 +118,7 @@ class UpdateTelephoneHandler(ClientBaseHandler):
         check_code = self.get_param("check_code")
         modify_date = self.get_now_datetime()
 
-        check_code_re = SevenHelper.redis_init().get(f"user_bind_phone_code:{open_id}")
+        check_code_re = SevenHelper.redis_init().get(f"user_bind_phone_code:{open_id}_{telephone}")
         if check_code_re == None:
             return self.response_json_error("error", "验证码已过期")
         if check_code != check_code_re:
@@ -109,7 +150,8 @@ class VersionUpgradeHandler(ClientBaseHandler):
         client_ver = base_info.client_ver
         store_user_nick = user_nick.split(':')[0]
 
-        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
+        app_info_model = AppInfoModel(context=self)
+        app_info = app_info_model.get_entity("app_id=%s", params=app_id)
         if not app_info:
             return self.response_json_error("no_app", "小程序不存在")
         test_config = share_config.get_value("test_config", {})
@@ -124,14 +166,20 @@ class VersionUpgradeHandler(ClientBaseHandler):
             if version_info:
                 if version_info.update_scope == 2 and version_info.white_lists:
                     white_lists = SevenHelper.json_loads(version_info.white_lists)
+                    if isinstance(white_lists, str):
+                        white_lists = white_lists.split(',')
                     if store_user_nick in white_lists:
                         client_ver = version_info.version_number
-
+        
+        invoke_result_data = InvokeResultData()
         top_base_model = TopBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = top_base_model.version_upgrade(app_id, client_template_id, client_ver, access_token,app_key, app_secret, app_info, is_log)
-        if invoke_result_data.success == False:
-            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if client_ver != app_info.template_ver:
+            invoke_result_data = top_base_model.version_upgrade(app_id, client_template_id, client_ver, access_token, app_key, app_secret, app_info, is_log)
+            if invoke_result_data.success == False:
+                return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+            app_info_model.delete_dependency_key(DependencyKey.app_info(app_id))
+
         return self.response_json_success(invoke_result_data.data)
 
 
@@ -149,7 +197,15 @@ class AppInfoHandler(ClientBaseHandler):
         main_user_open_id = self.get_param("main_user_open_id")
         app_base_model = AppBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
         invoke_result_data = app_base_model.get_app_info_result(self.get_user_nick(), self.get_open_id(), self.get_access_token(), app_key, app_secret, main_user_open_id)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        invoke_result_data = self.business_process_executed(invoke_result_data, {})
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -171,7 +227,14 @@ class CheckGmPowerHandler(ClientBaseHandler):
         if not user_nick:
             return self.response_json_error("error", "对不起,请先授权登录")
         store_user_nick = user_nick.split(':')[0]
-        app_info_dict = AppInfoModel(context=self).get_dict("store_user_nick=%s", field="is_gm", params=store_user_nick)
+        condition_where = ConditionWhere()
+        condition_where.add_condition("store_user_nick=%s")
+        params = [store_user_nick]
+        template_id = share_config.get_value("client_template_id")
+        if template_id:
+            condition_where.add_condition("template_id=%s")
+            params.append(template_id)
+        app_info_dict = AppInfoModel(context=self).get_dict(condition_where.to_string(), field="is_gm", params=params)
         if not app_info_dict:
             is_power = False
         if app_info_dict["is_gm"] == 1:
@@ -198,12 +261,25 @@ class GetAppidByGmHandler(ClientBaseHandler):
             return self.response_json_error("error", "对不起,请先授权登录")
         store_user_nick = user_nick.split(':')[0]
         is_power = False
-
-        app_info_dict = AppInfoModel(context=self).get_dict("store_user_nick=%s", field="is_gm", params=store_user_nick)
+        condition_where = ConditionWhere()
+        condition_where.add_condition("store_user_nick=%s")
+        params = [store_user_nick]
+        template_id = share_config.get_value("client_template_id")
+        if template_id:
+            condition_where.add_condition("template_id=%s")
+            params.append(template_id)
+        app_info_dict = AppInfoModel(context=self).get_dict(condition_where.to_string(), field="is_gm", params=params)
         if app_info_dict and app_info_dict["is_gm"] == 1:
             is_power = True
         if is_power == True:
-            app_info_dict = AppInfoModel(context=self).get_dict("store_name=%s", field="app_id", params=[store_name])
+            condition_where = ConditionWhere()
+            condition_where.add_condition("store_name=%s")
+            params = [store_name]
+            template_id = share_config.get_value("client_template_id")
+            if template_id:
+                condition_where.add_condition("template_id=%s")
+                params.append(template_id)
+            app_info_dict = AppInfoModel(context=self).get_dict(condition_where.to_string(), field="app_id", params=params)
             if app_info_dict:
                 app_id = app_info_dict["app_id"]
         return self.response_json_success(app_id)
@@ -252,10 +328,11 @@ class GetHighPowerListHandler(ClientBaseHandler):
         mp_base_model = MPBaseModel(context=self)
         # 如果登录账号的主账号等于配置文件指定的测试账号，则取子账号进行权限的获取，方便不同子账号进到不同的SaaS定制
         test_config = share_config.get_value("test_config", {})
-        if store_user_nick and store_user_nick == test_config.get("user_nick", ""):
-            custom_function_list = mp_base_model.get_custom_function_list(user_nick)
+        invoke_result_data = mp_base_model.get_custom_function_list(user_nick) if store_user_nick and store_user_nick == test_config.get("user_nick", "") else mp_base_model.get_custom_function_list(store_user_nick)
+        if invoke_result_data.success == True:
+            custom_function_list = invoke_result_data.data if invoke_result_data.data else []
         else:
-            custom_function_list = mp_base_model.get_custom_function_list(store_user_nick)
+            custom_function_list = mp_base_model.get_api_custom_function_list(user_nick) if store_user_nick and store_user_nick == test_config.get("user_nick", "") else mp_base_model.get_api_custom_function_list(store_user_nick)
         config_data_list = []
         if len(custom_function_list) == 0:
             config_data = {}
@@ -268,7 +345,11 @@ class GetHighPowerListHandler(ClientBaseHandler):
             app_key, app_secret = self.get_app_key_secret()
             #获取项目编码
             project_code = top_base_model.get_project_code(store_user_nick, access_token, app_key, app_secret)
-            public_function_list = mp_base_model.get_public_function_list(project_code)
+            invoke_result_data = mp_base_model.get_public_function_list(project_code)
+            if invoke_result_data.success == True:
+                public_function_list = invoke_result_data.data if invoke_result_data.data else []
+            else:
+                public_function_list = mp_base_model.get_api_public_function_list(project_code)
             if len(public_function_list) > 0:
                 config_data["function_config_list"] = query(public_function_list[0]["function_info_second_list"]).select(lambda x: {"name": x["name"], "key_name": x["key_name"]}).to_list()
                 config_data["skin_config_list"] = query(public_function_list[0]["skin_ids_second_list"]).select(lambda x: {"name": x["name"], "theme_id": x["theme_id"]}).to_list()
