@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-08-03 10:11:39
-@LastEditTime: 2022-10-17 17:40:25
+@LastEditTime: 2023-11-30 16:40:19
 @LastEditors: HuangJianYi
 :description: 商品模块
 """
@@ -30,9 +30,9 @@ class GoodsListHandler(ClientBaseHandler):
         goods_name = self.get_param("goods_name")
         order_tag = self.get_param("order_tag", "list_time")
         order_by = self.get_param("order_by", "desc")
-        page_index = int(self.get_param("page_index", 0))
-        page_size = self.get_param("page_size", 20)
-        is_log = int(self.get_param("is_log", 0))
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 20)
+        is_log = self.get_param_int("is_log", 0)
         is_log = True if is_log == 1 else False
 
         top_base_model = TopBaseModel(context=self)
@@ -40,7 +40,8 @@ class GoodsListHandler(ClientBaseHandler):
         invoke_result_data = top_base_model.get_goods_list(page_index, page_size, goods_name, order_tag, order_by, access_token, app_key, app_secret, is_log=is_log)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        ref_params = {}
+        return self.response_json_success(self.business_process_executed(invoke_result_data.data, ref_params))
 
 
 class GoodsListByGoodsIDHandler(ClientBaseHandler):
@@ -57,7 +58,7 @@ class GoodsListByGoodsIDHandler(ClientBaseHandler):
         """
         access_token = self.get_access_token()
         goods_ids = self.get_param("goods_ids")
-        is_log = int(self.get_param("is_log", 0))
+        is_log = self.get_param_int("is_log", 0)
         is_log = True if is_log == 1 else False
 
         top_base_model = TopBaseModel(context=self)
@@ -82,7 +83,7 @@ class GoodsInfoHandler(ClientBaseHandler):
         """
         access_token = self.get_access_token()
         goods_id = self.get_param("goods_id")
-        is_log = int(self.get_param("is_log", 0))
+        is_log = self.get_param_int("is_log", 0)
         is_log = True if is_log == 1 else False
 
         top_base_model = TopBaseModel(context=self)
@@ -106,7 +107,7 @@ class BenefitDetailHandler(ClientBaseHandler):
         """
         access_token = self.get_access_token()
         right_ename = self.get_param("right_ename")
-        is_log = int(self.get_param("is_log", 0))
+        is_log = self.get_param_int("is_log", 0)
         is_log = True if is_log == 1 else False
 
         top_base_model = TopBaseModel(context=self)
@@ -136,14 +137,15 @@ class InventoryGoodsListHandler(ClientBaseHandler):
         goods_name = self.get_param("goods_name")
         order_tag = self.get_param("order_tag", "list_time")
         order_by = self.get_param("order_by", "desc")
-        page_index = int(self.get_param("page_index", 0))
-        page_size = self.get_param("page_size", 20)
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 20)
         top_base_model = TopBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
         invoke_result_data = top_base_model.get_goods_inventory_list(page_index, page_size, goods_name, order_tag, order_by, access_token, app_key, app_secret)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        ref_params = {}
+        return self.response_json_success(self.business_process_executed(invoke_result_data.data, ref_params))
 
 
 class SpecialGoodsListHandler(ClientBaseHandler):
@@ -158,23 +160,37 @@ class SpecialGoodsListHandler(ClientBaseHandler):
         :param page_index：页索引
         :param page_size：页大小
         :param goods_name：商品名称
+        :param goods_id：商品ID
         :return:
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 20))
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 20)
         goods_name = self.get_param("goods_name")
+        goods_id = self.get_param("goods_id")
         access_token = self.get_access_token()
-        is_log = int(self.get_param("is_log", 0))
+        act_id = self.get_act_id()
+        is_log = self.get_param_int("is_log", 0)
         is_log = True if is_log == 1 else False
 
-        goods_base_model = GoodsBaseModel(context=self)
-        app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = goods_base_model.get_special_goods_list(app_id, goods_name, access_token, app_key, app_secret, is_log, page_index, page_size)
+        invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        is_top_data = invoke_result_data.data["is_top_data"] if invoke_result_data.data.__contains__("is_top_data") else False #是否直接取淘宝top数据
+        goods_base_model = GoodsBaseModel(context=self)
+        app_key, app_secret = self.get_app_key_secret()
+        if is_top_data == False:
+            invoke_result_data = goods_base_model.get_special_goods_list(app_id, goods_name, access_token, app_key, app_secret, is_log, page_index, page_size)
+        else:
+            invoke_result_data = goods_base_model.get_special_goods_list_for_tb(app_id, goods_id, access_token, app_key, app_secret, is_log, page_index, page_size, act_id)
+
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        ref_params = {}
+        return self.response_json_success(self.business_process_executed(invoke_result_data.data, ref_params))
 
 
 class BindSpecialGoodsHandler(ClientBaseHandler):
@@ -194,7 +210,7 @@ class BindSpecialGoodsHandler(ClientBaseHandler):
         access_token = self.get_access_token()
         goods_id = self.get_param("goods_id")
         goods_name = self.get_param("goods_name")
-        is_log = int(self.get_param("is_log", 0))
+        is_log = self.get_param_int("is_log", 0)
         is_log = True if is_log == 1 else False
 
         goods_base_model = GoodsBaseModel(context=self)
