@@ -84,10 +84,10 @@ class IpInfoListHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
-        is_del = int(self.get_param("is_del", 0))
-        is_release = int(self.get_param("is_release", -1))
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 20))
+        is_del = self.get_param_int("is_del", 0)
+        is_release = self.get_param_int("is_release", -1)
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 20)
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
