@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2023-03-13 11:48:10
+@LastEditTime: 2024-02-02 09:09:11
 @LastEditors: HuangJianYi
 @Description: 小活动模块（机台）
 """
@@ -90,8 +90,9 @@ class SaveActModuleHandler(ClientBaseHandler):
         elif business_type == 2:
             default_prefix = "活动"
         title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else default_prefix
+        exclude_field_list = invoke_result_data.data["exclude_field_list"] if invoke_result_data.data.__contains__("exclude_field_list") else ''
         module_base_model = ModuleBaseModel(context=self)
-        invoke_result_data = module_base_model.save_act_module(app_id, act_id, module_id, module_name, module_sub_name, start_date, end_date, module_pic, module_desc, price, price_gear_id, ip_id, join_ways, is_fictitious, sort_index, is_release, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, business_type, module_type)
+        invoke_result_data = module_base_model.save_act_module(app_id, act_id, module_id, module_name, module_sub_name, start_date, end_date, module_pic, module_desc, price, price_gear_id, ip_id, join_ways, is_fictitious, sort_index, is_release, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, business_type, module_type, exclude_field_list)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
@@ -126,7 +127,7 @@ class ActModuleHandler(ClientBaseHandler):
         module_base_model = ModuleBaseModel(context=self)
         act_module_dict = module_base_model.get_act_module_dict(module_id, False)
         if act_module_dict:
-            if act_module_dict["app_id"] != app_id:
+            if SafeHelper.authenticat_app_id(act_module_dict["app_id"], app_id) == False:
                 act_module_dict = {}
                 return self.response_json_success(act_module_dict)
         ref_params = {}
@@ -152,10 +153,10 @@ class ActModuleListHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 10))
-        is_del = int(self.get_param("is_del", -1))
-        business_type = int(self.get_param("business_type", -1))
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 10)
+        is_del = self.get_param_int("is_del", 0)
+        business_type = self.get_param_int("business_type", -1)
         module_name = self.get_param("module_name")
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
