@@ -2,12 +2,12 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2023-01-04 14:37:44
+@LastEditTime: 2025-04-28 14:20:02
 @LastEditors: HuangJianYi
 @Description: 订单模块
 """
 from seven_cloudapp_frame.models.enum import *
-from seven_cloudapp_frame.libs.customize.oss2_helper import *
+from seven_cloudapp_frame.libs.customize.file_helper import *
 from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.order_base_model import *
 
@@ -52,7 +52,7 @@ class PayOrderListHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
 
         if main_pay_order_no:
@@ -108,7 +108,6 @@ class PrizeOrderListHandler(ClientBaseHandler):
         order_status = int(self.get_param("order_status",-10))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
-        order_by = self.get_param("order_by","create_date desc")
         is_search_roster = self.get_param_int("is_search_roster", 0)
         is_search_roster = False if is_search_roster == 0 else True
         page_index = int(self.get_param("page_index", 0))
@@ -121,7 +120,7 @@ class PrizeOrderListHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
 
@@ -186,7 +185,7 @@ class PrizeRosterListHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         condition_where = ConditionWhere()
         if condition:
@@ -368,7 +367,7 @@ class PrizeOrderExportHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         operate_title = invoke_result_data.data["operate_title"] if invoke_result_data.data.__contains__("operate_title") else "发货列表"
         prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
@@ -376,20 +375,26 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         order_base_model = OrderBaseModel(context=self)
         prize_order_list_dict = []
         if page_size <= 500:
-            prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table, page_count_mode='none')
+            prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table, page_count_mode='none', is_auto=True)
         else:
-            max_page_size = 100
+            max_page_size = 500
             repeat_count = page_size // max_page_size  # 循环次数
             begin_page_index = page_index * repeat_count  # 开始页码
             for i in range(repeat_count):
-                list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, max_page_size, begin_page_index + i, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table, page_count_mode='none')
+                list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, max_page_size, begin_page_index + i, order_by, field=field, is_search_roster=True, is_cache=False, condition=condition, params=params, prize_roster_sub_table=prize_roster_sub_table, page_count_mode='none', is_auto=True)
                 if len(list_dict) <= 0:
                     break
                 prize_order_list_dict.extend(list_dict)
 
         ref_params = {}
         result_data = self.business_process_executed(prize_order_list_dict, ref_params)
-        resource_path = OSS2Helper.export_excel(result_data)
+        file_storage_type = share_config.get_value("file_storage_type", FileStorageType.oss.value)
+        if file_storage_type == FileStorageType.cos.value:
+            resource_path = COSHelper.export_excel(result_data)
+        elif file_storage_type == FileStorageType.oss.value:
+            resource_path = OSSHelper.export_excel(result_data)
+        else:
+            resource_path = BOSHelper.export_excel(result_data)
         self.create_operation_log(operation_type=OperationType.export.value, model_name="prize_order_tb", title=operate_title)
         return self.response_json_success(resource_path)
 
@@ -485,26 +490,33 @@ class PrizeRosterExportHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         operate_title = invoke_result_data.data["operate_title"] if invoke_result_data.data.__contains__("operate_title") else "中奖记录列表"
 
         order_base_model = OrderBaseModel(context=self)
         prize_roster_list_dict = []
         if page_size <= 500:
-            prize_roster_list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False, page_count_mode='none').data
+            prize_roster_list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False, page_count_mode='none', is_auto=True)
         else:
-            max_page_size = 100
+            max_page_size = 500
             repeat_count = page_size // max_page_size  # 循环次数
             begin_page_index = page_index * repeat_count  # 开始页码
             for i in range(repeat_count):
-                list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, max_page_size, begin_page_index + i, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False, page_count_mode='none').data
+                list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, max_page_size, begin_page_index + i, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False, page_count_mode='none', is_auto=True)
                 if len(list_dict) <= 0:
                     break
                 prize_roster_list_dict.extend(list_dict)
         ref_params = {}
         result_data = self.business_process_executed(prize_roster_list_dict, ref_params)
-        resource_path = OSS2Helper.export_excel(result_data)
+
+        file_storage_type = share_config.get_value("file_storage_type", FileStorageType.oss.value)
+        if file_storage_type == FileStorageType.cos.value:
+            resource_path = COSHelper.export_excel(result_data)
+        elif file_storage_type == FileStorageType.oss.value:
+            resource_path = OSSHelper.export_excel(result_data)
+        else:
+            resource_path = BOSHelper.export_excel(result_data)
         self.create_operation_log(operation_type=OperationType.export.value, model_name="prize_roster_tb", title=operate_title)
         return self.response_json_success(resource_path)
 
@@ -578,7 +590,7 @@ class TaoPayOrderExportHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         operate_title = invoke_result_data.data["operate_title"] if invoke_result_data.data.__contains__("operate_title") else "支付订单列表"
 
@@ -594,20 +606,26 @@ class TaoPayOrderExportHandler(ClientBaseHandler):
         order_base_model = OrderBaseModel(context=self)
         tao_pay_order_list_dict = []
         if page_size <= 500:
-            tao_pay_order_list_dict = order_base_model.get_tao_pay_order_list(app_id, act_id, user_id, user_open_id, user_nick, pay_date_start, pay_date_end, page_size, page_index, field=field, order_by=order_by, condition=condition, params=params).data
+            tao_pay_order_list_dict = order_base_model.get_tao_pay_order_list(app_id, act_id, user_id, user_open_id, user_nick, pay_date_start, pay_date_end, page_size, page_index, field=field, order_by=order_by, condition=condition, params=params, is_auto=True).data
         else:
-            max_page_size = 100
+            max_page_size = 500
             repeat_count = page_size // max_page_size  # 循环次数
             begin_page_index = page_index * repeat_count  # 开始页码
             for i in range(repeat_count):
-                list_dict = order_base_model.get_tao_pay_order_list(app_id, act_id, user_id, user_open_id, user_nick, pay_date_start, pay_date_end, max_page_size, begin_page_index + i, field=field, order_by=order_by, condition=condition, params=params).data
+                list_dict = order_base_model.get_tao_pay_order_list(app_id, act_id, user_id, user_open_id, user_nick, pay_date_start, pay_date_end, max_page_size, begin_page_index + i, field=field, order_by=order_by, condition=condition, params=params, is_auto=True).data
                 if len(list_dict) <= 0:
                     break
                 tao_pay_order_list_dict.extend(list_dict)
 
         ref_params = {}
         result_data = self.business_process_executed(tao_pay_order_list_dict, ref_params)
-        resource_path = OSS2Helper.export_excel(result_data)
+        file_storage_type = share_config.get_value("file_storage_type", FileStorageType.oss.value)
+        if file_storage_type == FileStorageType.cos.value:
+            resource_path = COSHelper.export_excel(result_data)
+        elif file_storage_type == FileStorageType.oss.value:
+            resource_path = OSSHelper.export_excel(result_data)
+        else:
+            resource_path = BOSHelper.export_excel(result_data)
         self.create_operation_log(operation_type=OperationType.export.value, model_name="tao_pay_order_tb", title=operate_title)
         return self.response_json_success(resource_path)
 
