@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:25:02
-@LastEditTime: 2023-01-12 09:48:32
+@LastEditTime: 2024-03-06 11:20:49
 @LastEditors: HuangJianYi
 @Description: 价格档位模块
 """
@@ -31,27 +31,29 @@ class SavePriceGearHandler(ClientBaseHandler):
         :param sku_id：sku_id
         :param remark：备注
         :param sort_index：排序
+        :param business_type:业务类型
         :return:
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
-        price_gear_id = int(self.get_param("price_gear_id", 0))
-        relation_type = int(self.get_param("relation_type", 1))
+        price_gear_id = self.get_param_int("price_gear_id", 0)
+        relation_type = self.get_param_int("relation_type", 1)
+        business_type = self.get_param_int("business_type", -1)
+        sort_index = self.get_param_int("sort_index")
         price = self.get_param("price")
         price_gear_name = self.get_param("price_gear_name")
         price_gear_pic = self.get_param("price_gear_pic")
         goods_id = self.get_param("goods_id")
         sku_id = self.get_param("sku_id")
         remark = self.get_param("remark")
-        sort_index = int(self.get_param("sort_index", 0))
-
+        
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "价格档位"
         price_base_model = PriceBaseModel(context=self)
-        invoke_result_data = price_base_model.save_price_gear(app_id, act_id, price_gear_id, relation_type, price_gear_name, price_gear_pic, price, goods_id, sku_id, remark, sort_index)
+        invoke_result_data = price_base_model.save_price_gear(app_id, act_id, price_gear_id, relation_type, price_gear_name, price_gear_pic, price, goods_id, sku_id, remark, sort_index, business_type)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
@@ -78,21 +80,23 @@ class PriceGearListHandler(ClientBaseHandler):
         :param page_index：页索引
         :param page_size：页大小
         :param is_del：是否回收站1是0否
+        :param business_type:业务类型
         :return: list
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 20))
-        is_del = int(self.get_param("is_del", 0))
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 20)
+        is_del = self.get_param_int("is_del", 0)
+        business_type = self.get_param_int("business_type", -1)
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
         if not invoke_result_data.data:
             invoke_result_data.data = {}
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc"
-        page_list, total = PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index, order_by, is_del=is_del, is_cache=False)
+        page_list, total = PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index, order_by, is_del=is_del, is_cache=False, business_type=business_type)
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
         return self.response_json_success(page_info)
 
