@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2023-01-12 09:50:22
+@LastEditTime: 2024-08-13 16:29:53
 @LastEditors: HuangJianYi
 @Description: 奖品模块
 """
@@ -11,7 +11,7 @@ from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.act_base_model import *
 from seven_cloudapp_frame.models.prize_base_model import *
 from seven_cloudapp_frame.models.seven_model import PageInfo
-from seven_cloudapp_frame.libs.customize.oss2_helper import *
+from seven_cloudapp_frame.libs.customize.file_helper import *
 
 
 class SaveActPrizeHandler(ClientBaseHandler):
@@ -66,8 +66,8 @@ class SaveActPrizeHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
-        module_id = int(self.get_param("module_id", 0))
-        prize_id = int(self.get_param("prize_id", 0))
+        module_id = self.get_param_int("module_id")
+        prize_id = self.get_param_int("prize_id")
         prize_name = self.get_param("prize_name")
         prize_title = self.get_param("prize_title")
         prize_pic = self.get_param("prize_pic")
@@ -75,35 +75,35 @@ class SaveActPrizeHandler(ClientBaseHandler):
         goods_id = self.get_param("goods_id")
         goods_code = self.get_param("goods_code")
         goods_code_list = self.get_param("goods_code_list")
-        goods_type = int(self.get_param("goods_type", 0))
-        prize_type = int(self.get_param("prize_type", 0))
+        goods_type = self.get_param_int("goods_type")
+        prize_type = self.get_param_int("prize_type")
         prize_price = self.get_param("prize_price")
-        probability = self.get_param("probability")
+        probability = self.get_param_int("probability")
         chance = self.get_param("chance")
-        prize_limit = int(self.get_param("prize_limit", 0))
-        is_prize_notice = int(self.get_param("is_prize_notice", 0))
-        prize_total = int(self.get_param("prize_total", 0))
-        is_surplus = int(self.get_param("is_surplus", 0))
-        lottery_type = int(self.get_param("lottery_type", 0))
+        prize_limit = self.get_param_int("prize_limit")
+        is_prize_notice = self.get_param_int("is_prize_notice")
+        prize_total = self.get_param_int("prize_total")
+        is_surplus = self.get_param_int("is_surplus")
+        lottery_type = self.get_param_int("lottery_type")
         tag_name = self.get_param("tag_name")
-        tag_id = int(self.get_param("tag_id", 0))
-        is_sku = int(self.get_param("is_sku", 0))
+        tag_id = self.get_param_int("tag_id")
+        is_sku = self.get_param_int("is_sku")
         sku_json = self.get_param("sku_json")
-        ascription_type = int(self.get_param("ascription_type", 0))
-        sort_index = int(self.get_param("sort_index", 0))
-        is_release = int(self.get_param("is_release", 0))
-        i1 = int(self.get_param("i1", 0))
-        i2 = int(self.get_param("i2", 0))
-        i3 = int(self.get_param("i3", 0))
-        i4 = int(self.get_param("i4", 0))
-        i5 = int(self.get_param("i5", 0))
+        ascription_type = self.get_param_int("ascription_type")
+        sort_index = self.get_param_int("sort_index")
+        is_release = self.get_param_int("is_release")
+        i1 = self.get_param_int("i1")
+        i2 = self.get_param_int("i2")
+        i3 = self.get_param_int("i3")
+        i4 = self.get_param_int("i4")
+        i5 = self.get_param_int("i5")
         s1 = self.get_param("s1")
         s2 = self.get_param("s2")
         s3 = self.get_param("s3")
         s4 = self.get_param("s4")
         s5 = self.get_param("s5")
-        d1 = self.get_param("d1", "1900-01-01 00:00:00")
-        d2 = self.get_param("d2", "1900-01-01 00:00:00")
+        d1 = self.get_param_datetime("d1", "1900-01-01 00:00:00")
+        d2 = self.get_param_datetime("d2", "1900-01-01 00:00:00")
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
@@ -112,8 +112,9 @@ class SaveActPrizeHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         prize_total = invoke_result_data.data["prize_total"] if invoke_result_data.data.__contains__("prize_total") else prize_total
         title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "奖品"
+        exclude_field_list = invoke_result_data.data["exclude_field_list"] if invoke_result_data.data.__contains__("exclude_field_list") else ''
         prize_base_model = PrizeBaseModel(context=self)
-        invoke_result_data = prize_base_model.save_act_prize(app_id, act_id, module_id, prize_id, prize_name, prize_title, prize_pic, prize_detail_json, goods_id, goods_code, goods_code_list, goods_type, prize_type, prize_price, probability, chance, prize_limit, is_prize_notice, prize_total, is_surplus, lottery_type, tag_name, tag_id, is_sku, sku_json, sort_index, is_release, ascription_type, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2)
+        invoke_result_data = prize_base_model.save_act_prize(app_id, act_id, module_id, prize_id, prize_name, prize_title, prize_pic, prize_detail_json, goods_id, goods_code, goods_code_list, goods_type, prize_type, prize_price, probability, chance, prize_limit, is_prize_notice, prize_total, is_surplus, lottery_type, tag_name, tag_id, is_sku, sku_json, sort_index, is_release, ascription_type, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, exclude_field_list)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
@@ -148,12 +149,12 @@ class ActPrizeListHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
-        module_id = int(self.get_param("module_id", 0))
+        module_id = self.get_param_int("module_id", 0)
         prize_name = self.get_param("prize_name")
-        is_del = int(self.get_param("is_del", -1))
+        is_del = self.get_param_int("is_del", 0)
         ascription_type = self.get_param_int("ascription_type", -1)
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 20))
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 20)
 
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
@@ -306,7 +307,7 @@ class ActPrizeExportHandler(ClientBaseHandler):
             invoke_result_data.data = {}
         condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         operate_title = invoke_result_data.data["operate_title"] if invoke_result_data.data.__contains__("operate_title") else "奖品列表"
 
@@ -326,7 +327,13 @@ class ActPrizeExportHandler(ClientBaseHandler):
                 act_prize_list_dict.extend(list_dict)
         ref_params = {}
         result_data = self.business_process_executed(act_prize_list_dict, ref_params)
-        resource_path = OSS2Helper.export_excel(result_data)
+        file_storage_type = share_config.get_value("file_storage_type", FileStorageType.oss.value)
+        if file_storage_type == FileStorageType.cos.value:
+            resource_path = COSHelper.export_excel(result_data)
+        elif file_storage_type == FileStorageType.oss.value:
+            resource_path = OSSHelper.export_excel(result_data)
+        else:
+            resource_path = BOSHelper.export_excel(result_data)
         self.create_operation_log(operation_type=OperationType.export.value, model_name="act_prize_tb", title=operate_title)
         return self.response_json_success(resource_path)
 
