@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-10 10:05:38
-@LastEditTime: 2023-01-12 09:51:44
+@LastEditTime: 2024-09-06 11:06:26
 @LastEditors: HuangJianYi
 @Description: 任务模块
 """
@@ -29,13 +29,18 @@ class TaskInfoListHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
-        module_id = int(self.get_param("module_id", 0))
-        is_release = int(self.get_param("is_release", -1))
+        module_id = self.get_param_int("module_id", 0)
+        is_release = self.get_param_int("is_release", -1)
+        is_del = self.get_param_int("is_del", -1)
+        source_object_id = self.get_param("source_object_id")
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index desc,id asc"
         task_base_model = TaskBaseModel(context=self)
-        return self.response_json_success(self.business_process_executed(task_base_model.get_task_info_dict_list(app_id, act_id, module_id,is_release,False), ref_params={}))
+        return self.response_json_success(self.business_process_executed(task_base_model.get_task_info_dict_list(app_id, act_id, module_id, is_release, False, source_object_id, is_del, order_by), ref_params={}))
 
 
 class SaveTaskInfoHandler(ClientBaseHandler):
@@ -55,7 +60,8 @@ class SaveTaskInfoHandler(ClientBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = self.get_act_id()
-        module_id = int(self.get_param("module_id", 0))
+        module_id = self.get_param_int("module_id")
+        source_object_id = self.get_param("source_object_id")
         task_list = self.get_param("task_list")
 
         invoke_result_data = self.business_process_executing()
@@ -67,6 +73,7 @@ class SaveTaskInfoHandler(ClientBaseHandler):
         operate_user_id = invoke_result_data.data["operate_user_id"] if invoke_result_data.data.__contains__("operate_user_id") else ""
         operate_user_name = invoke_result_data.data["operate_user_name"] if invoke_result_data.data.__contains__("operate_user_name") else ""
         operate_role_id = invoke_result_data.data["operate_role_id"] if invoke_result_data.data.__contains__("operate_role_id") else ""
+        update_field_list = invoke_result_data.data["update_field_list"] if invoke_result_data.data.__contains__("update_field_list") else "complete_type,task_name,sort_index,is_release,route_url,i1,i2,s1,s2,config_json,modify_date"
 
         try:
             task_list = SevenHelper.json_loads(task_list)
@@ -105,16 +112,18 @@ class SaveTaskInfoHandler(ClientBaseHandler):
                     task_info.s1 = s1
                     task_info.s2 = s2
                     task_info.modify_date = now_datetime
-                    task_info_model.update_entity(task_info, "complete_type,task_name,sort_index,is_release,route_url,i1,i2,s1,s2,config_json,modify_date")
+                    task_info_model.update_entity(task_info, update_field_list)
                     task_base_model._delete_task_info_dependency_key(0,task_info.id)
                     self.create_operation_log(operation_type=OperationType.update.value, model_name=task_info.__str__(), old_detail=old_task_info.__dict__, update_detail=task_info.__dict__, title=title, operate_user_id=operate_user_id, operate_user_name=operate_user_name, operate_role_id=operate_role_id)
                     ref_params = {}
+                    ref_params['old_task_info'] = old_task_info
                     self.business_process_executed(task_info, ref_params)
             else:
                 task_info = TaskInfo()
                 task_info.app_id = app_id
                 task_info.act_id = act_id
                 task_info.module_id = module_id
+                task_info.source_object_id = source_object_id
                 task_info.task_type = int(item["task_type"])
                 task_info.task_name = task_name
                 task_info.complete_type = complete_type
