@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2023-03-01 17:35:06
+@LastEditTime: 2023-05-05 19:22:10
 @LastEditors: HuangJianYi
 @Description: 用户模块
 """
@@ -245,13 +245,13 @@ class UpdateUserAssetHandler(ClientBaseHandler):
     """
     :description: 变更资产
     """
-
     @filter_check_params("asset_type,asset_value", check_user_code=True)
     def post_async(self):
         """
         :description: 变更资产
         :param app_id：应用标识
         :param act_id：活动标识
+        :param module_id：模块标识
         :param user_code：用户标识
         :param asset_type：资产类型
         :param asset_value：变更的资产值
@@ -262,8 +262,9 @@ class UpdateUserAssetHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
-        asset_type = int(self.get_param("asset_type", 0))
-        asset_value = int(self.get_param("asset_value", 0))
+        module_id = self.get_param_int("module_id", 0)
+        asset_type = self.get_param_int("asset_type", 0)
+        asset_value = self.get_param_int("asset_value", 0)
         asset_object_id = self.get_param("asset_object_id")
 
         invoke_result_data = self.business_process_executing()
@@ -276,7 +277,24 @@ class UpdateUserAssetHandler(ClientBaseHandler):
             return self.response_json_error("error", "用户信息不存在")
 
         asset_base_model = AssetBaseModel(context=self)
-        invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], asset_type, asset_value, asset_object_id, 3, "", "手动配置", "手动配置")
+        invoke_result_data = asset_base_model.update_user_asset(app_id=app_id,
+                                                                act_id=act_id,
+                                                                module_id=module_id,
+                                                                user_id=user_id,
+                                                                open_id=user_info_dict["open_id"],
+                                                                user_nick=user_info_dict["user_nick"],
+                                                                asset_type=asset_type,
+                                                                asset_value=asset_value,
+                                                                asset_object_id=asset_object_id,
+                                                                source_type=3,
+                                                                source_object_id="",
+                                                                source_object_name="手动配置",
+                                                                log_title="手动配置",
+                                                                only_id="",
+                                                                handler_name=self.__class__.__name__,
+                                                                request_code=self.request_code,
+                                                                info_json={"operate_user_id":self.get_open_id(),"operate_user_name":self.get_user_nick()
+                                                                           })
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         default_prefix = "资产配置"
@@ -287,7 +305,7 @@ class UpdateUserAssetHandler(ClientBaseHandler):
             default_prefix = "积分配置"
         elif asset_type == 3:
             default_prefix = "价格档位配置"
-            price_gear_model = PriceGearModel(context=self)
+            price_gear_model = PriceGearModel(context=self, is_auto=True)
             asset_object_id = int(asset_object_id)
             if asset_object_id > 0:
                 price_gear = price_gear_model.get_entity_by_id(asset_object_id)
@@ -305,13 +323,13 @@ class BatchUpdateUserAssetHandler(ClientBaseHandler):
     """
     :description: 批量变更资产
     """
-
     @filter_check_params("asset_object_json", check_user_code=True)
     def post_async(self):
         """
         :description: 批量变更资产
         :param app_id：应用标识
         :param act_id：活动标识
+        :param module_id：模块标识
         :param user_code：用户标识
         :param asset_object_json：变更的资产值列表
         :return: response_json_success
@@ -320,6 +338,7 @@ class BatchUpdateUserAssetHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
+        module_id = self.get_param_int("module_id", 0)
         #{"asset_type":0,"asset_object_id":"","asset_value":0}
         asset_object_json = self.get_param("asset_object_json")
 
@@ -332,7 +351,26 @@ class BatchUpdateUserAssetHandler(ClientBaseHandler):
         asset_object_json = SevenHelper.json_loads(asset_object_json)
         asset_object_ids = ""
         for asset_object in asset_object_json:
-            invoke_result_data = asset_base_model.update_user_asset(app_id, act_id, 0, user_id, user_info_dict["open_id"], user_info_dict["user_nick"], int(asset_object["asset_type"]), int(asset_object["asset_value"]), asset_object["asset_object_id"], 3, "", "手动配置", "手动配置", handler_name=self.__class__.__name__, request_code=self.request_code)
+            invoke_result_data = asset_base_model.update_user_asset(app_id=app_id,
+                                                                    act_id=act_id,
+                                                                    module_id=module_id,
+                                                                    user_id=user_id,
+                                                                    open_id=user_info_dict["open_id"],
+                                                                    user_nick=user_info_dict["user_nick"],
+                                                                    asset_type=int(asset_object["asset_type"]),
+                                                                    asset_value=int(asset_object["asset_value"]),
+                                                                    asset_object_id=asset_object["asset_object_id"],
+                                                                    source_type=3,
+                                                                    source_object_id="",
+                                                                    source_object_name="手动配置",
+                                                                    log_title="手动配置",
+                                                                    only_id="",
+                                                                    handler_name=self.__class__.__name__,
+                                                                    request_code=self.request_code,
+                                                                    info_json={
+                                                                        "operate_user_id": self.get_open_id(),
+                                                                        "operate_user_name": self.get_user_nick()
+                                                                    })
             if invoke_result_data.success == False:
                 return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message, asset_object_ids)
             else:
@@ -400,18 +438,18 @@ class AssetLogListHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         module_id = self.get_param_int("module_id", 0)
-        page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 20))
+        page_index = self.get_param_int("page_index", 0)
+        page_size = self.get_param_int("page_size", 20)
         user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         user_nick = self.get_param("nick_name")
         start_date = self.get_param("start_date")
         end_date = self.get_param("end_date")
-        source_type = int(self.get_param("source_type", 0))
+        source_type = self.get_param_int("source_type", 0)
         source_object_id = self.get_param("source_object_id")
-        asset_type = int(self.get_param("asset_type", 0))
+        asset_type = self.get_param_int("asset_type", 0)
         asset_object_id = self.get_param("asset_object_id")
-        operate_type = int(self.get_param("operate_type", -1))
+        operate_type = self.get_param_int("operate_type", -1)
 
         field = "*"
         invoke_result_data = self.business_process_executing()
