@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-30 09:22:51
-@LastEditTime: 2023-02-10 09:55:45
+@LastEditTime: 2025-05-26 10:23:53
 @LastEditors: HuangJianYi
 @Description: 排队系统帮助类
 """
@@ -17,6 +17,7 @@ class QueueUpHelper:
     :description: 排队系统帮助类 提供获取小程序总排队人数、获取用户当前排队数、获取用户正在办理中的队列信息、加入排队、退出排队、查询单个排队情况、批量查询某用户排队情况(只包含已排队的信息)、批量查询某用户排队情况(包含已排队和未排队的信息)、更新可操作时间、签到等功能；
     踢人规则1：第一个在办理中，第二个用户的过期时间=第一个结束时间+8*1，第三个=第一个结束时间+8*2，以此类推；第一个没在办理中，第一个过期时间是8*1，第二个是8*2，第三个是8*3，以此类推；
     踢人规则2：如果都没有正在办理中，那么取上次办理人退出的时间作为排在第一位人员的开始时间，进行倒计时，没有上次办理人退出时间的话，则取当前第一位人员的入队时间进行倒计时；
+    用户信息存在hash,排行信息存在zset,排队次数存在user_zset
     """
     logger_error = Logger.get_logger_by_name("log_error")
     logger_info = Logger.get_logger_by_name("log_info")
@@ -24,7 +25,7 @@ class QueueUpHelper:
     @classmethod
     def _get_zset_name(self, app_id, queue_name):
         """
-        :description: 获取排行集合名称，集合用于排行榜，排第一的优先操作
+        :description: 排行信息集合名称（集合用于排行榜，排第一的优先操作）
         :param app_id：应用标识
         :param queue_name：队列名称
         :return: 
@@ -56,7 +57,7 @@ class QueueUpHelper:
     @classmethod
     def _get_user_hash_name(self, app_id):
         """
-        :description: 获取用户关联队列名称
+        :description: 用户关联队列的hash名称
         :param app_id：应用标识
         :return: 
         :last_editors: HuangJianYi
@@ -69,7 +70,7 @@ class QueueUpHelper:
     @classmethod
     def _get_user_zset_name(self, app_id):
         """
-        :description: 用户在小程序内的排队次数信息
+        :description: 用户在小程序内的排队次数集合名称
         :param app_id：应用标识
         :return: 
         :last_editors: HuangJianYi
@@ -143,7 +144,10 @@ class QueueUpHelper:
         """
         user_zset_name = self._get_user_zset_name(app_id)
         redis_init = SevenHelper.redis_init()
-        return redis_init.zscore(user_zset_name, str(user_id))
+        queue_num = redis_init.zscore(user_zset_name, str(user_id))
+        if queue_num is None:
+            return 0
+        return queue_num
 
     @classmethod
     def get_process_user_queue(self, app_id, user_id):
@@ -166,7 +170,7 @@ class QueueUpHelper:
             return process_queue
 
     @classmethod
-    def queue(self, app_id, queue_name, user_id, user_nick="", avatar="", queue_length=10, app_limit_user_num=500, info_dict={}):
+    def queue(self, app_id, queue_name, user_id, user_nick="", avatar="", queue_length=10, app_limit_user_num=500, info_dict={}, limit_user_queue_num=0):
         """
         :description: 加入排队
         :param app_id：应用标识
@@ -177,6 +181,7 @@ class QueueUpHelper:
         :param queue_length：队列的长度
         :param app_limit_user_num：小程序内总排队人数上限
         :param info_dict：信息字典,用于存储业务端需要的数据
+        :param limit_user_queue_num：限制用户可以加入的队列数
         :return: 
         :last_editors: HuangJianYi
         """
@@ -198,8 +203,15 @@ class QueueUpHelper:
                 SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "total_limit"
-                invoke_result_data.error_message = "排队失败,排队总人数已达上限"
+                invoke_result_data.error_message = "抱歉~当前活动排队人数过多，请稍后再试"
                 return invoke_result_data
+            if limit_user_queue_num > 0 and QueueUpHelper.get_user_queue_num(app_id, user_id) >= limit_user_queue_num:
+                SevenHelper.redis_release_lock(acquire_lock_name, identifier)
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "user_limit"
+                invoke_result_data.error_message = "抱歉~当前可排队列已达上限，请稍后再试"
+                return invoke_result_data
+
             zset_name = self._get_zset_name(app_id, queue_name)
             data = str(user_id)
             expire_time = 7 * 24 * 3600
@@ -221,20 +233,20 @@ class QueueUpHelper:
                 start_timestamp = TimeHelper.get_now_timestamp()
 
                 hash_value = {}
-                hash_value["queue_name"] = queue_name  #排队名称
-                hash_value["queue_no"] = queue_no  #排队号
-                hash_value["user_id"] = data  #用户标识
-                hash_value["user_nick"] = user_nick  #用户昵称
-                hash_value["avatar"] = avatar  #头像
-                hash_value["progress_status"] = 1  #进度0未排队1已排队2办理中
-                hash_value["queue_timestamp"] = start_timestamp  #入队时间搓
-                hash_value["queue_date"] = TimeHelper.timestamp_to_format_time(start_timestamp)  #入队时间
+                hash_value["queue_name"] = queue_name  # 排队名称
+                hash_value["queue_no"] = queue_no  # 排队号
+                hash_value["user_id"] = data  # 用户标识
+                hash_value["user_nick"] = user_nick  # 用户昵称
+                hash_value["avatar"] = avatar  # 头像
+                hash_value["progress_status"] = 1  # 进度0未排队1已排队2办理中
+                hash_value["queue_timestamp"] = start_timestamp  # 入队时间搓
+                hash_value["queue_date"] = TimeHelper.timestamp_to_format_time(start_timestamp)  # 入队时间
                 hash_value["info_json"] = info_dict
 
-                queue_index = int(redis_init.zrank(zset_name, data)) + 1
+                queue_index = SevenHelper.to_int(redis_init.zrank(zset_name, data)) + 1
                 if queue_index == 1:
                     redis_init.hdel(self._get_popdate_hash_name(app_id), zset_name)
-                #添加排队信息
+                # 添加排队信息
                 hash_name = self._get_user_hash_name(app_id)
                 hash_key = f"userid_{data}_queuename_{queue_name}"
                 redis_init.hsetnx(hash_name, hash_key, SevenHelper.json_dumps(hash_value))
@@ -253,18 +265,18 @@ class QueueUpHelper:
                 SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = "该用户已在队列中,请勿重复排队"
+                invoke_result_data.error_message = "您已在队列中，请勿重复排队"
                 return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【加入排队】" + traceback.format_exc())
             SevenHelper.redis_release_lock(acquire_lock_name, identifier)
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
-            invoke_result_data.error_message = "排队失败,请稍后再来"
+            invoke_result_data.error_message = "对不起，加入队列失败，请稍后再试"
             return invoke_result_data
 
     @classmethod
-    def _set_last_pop_date(self,app_id, redis_init, hash_key):
+    def _set_last_pop_date(self, app_id, redis_init, hash_key):
         """
         :description: 设置办理中的用户退出队列的时间
         :param app_id：应用标识
@@ -302,11 +314,13 @@ class QueueUpHelper:
             data = str(user_id)
             redis_init = SevenHelper.redis_init()
             if redis_init.zscore(zset_name, data):
-                if int(redis_init.zrank(zset_name, data)) + 1 == 1:
+                if SevenHelper.to_int(redis_init.zrank(zset_name, data)) + 1 == 1:
                     self._set_last_pop_date(app_id,redis_init, zset_name)
-                redis_init.zrem(zset_name, data)
-                redis_init.zincrby(self._get_user_zset_name(app_id), -1, data)
-                redis_init.hdel(self._get_user_hash_name(app_id), f"userid_{data}_queuename_{queue_name}")
+                pipeline = redis_init.pipeline()
+                pipeline.zrem(zset_name, data)
+                pipeline.zincrby(self._get_user_zset_name(app_id), -1, data)
+                pipeline.hdel(self._get_user_hash_name(app_id), f"userid_{data}_queuename_{queue_name}")
+                pipeline.execute()
                 return invoke_result_data
             else:
                 invoke_result_data.success = False
@@ -329,9 +343,12 @@ class QueueUpHelper:
         :return: 
         :last_editors: HuangJianYi
         """
-        if SevenHelper.is_continue_request(f"pop_by_queue_name:{app_id}_{queue_name}", 200) == False:
+        if SevenHelper.is_continue_request(f"pop_by_queue_name:{app_id}_{queue_name}", 300) == False:
             try:
                 redis_init = SevenHelper.redis_init()
+                #删除用户排队次数小于等于0的数据
+                redis_init.zremrangebyscore(self._get_user_zset_name(app_id), -10, 0)
+
                 zset_name = self._get_zset_name(app_id, queue_name)
                 hash_name = self._get_user_hash_name(app_id)
                 value_list = redis_init.zrange(zset_name, 0, 1000)
@@ -360,8 +377,7 @@ class QueueUpHelper:
                     for i in range(len(value_list)):
                         data = value_list[i]
                         hash_value = [hash_value for hash_value in hash_value_list if hash_value["user_id"] == data]
-                        if len(hash_value) > 0:
-                            hash_value = hash_value[0]
+                        hash_value = hash_value[0] if len(hash_value) > 0 else None
                         is_delete = False
                         if hash_value:
                             if first_is_process == True and i == 0:
@@ -381,12 +397,15 @@ class QueueUpHelper:
                                 if now_timestamp > pop_timestamp + ((i + 1) * int(share_config.get_value("queue_confirm_time", 8))):
                                     is_delete = True
                                     self.logger_info.info("【踢掉办理用户3】" + SevenHelper.json_dumps({"zset_name": zset_name, "first_hash_value": first_hash_value, "user_id": data, "now_timestamp": now_timestamp, "pop_timestamp": pop_timestamp + ((i + 1) * int(share_config.get_value("queue_confirm_time", 8)))}))
-
+                        else:
+                            is_delete = True
                         if is_delete == True:
                             self._set_last_pop_date(app_id, redis_init, zset_name)
-                            redis_init.hdel(hash_name, f"userid_{data}_queuename_{queue_name}")
-                            redis_init.zrem(zset_name, data)
-                            redis_init.zincrby(self._get_user_zset_name(app_id), -1, data)
+                            pipeline = redis_init.pipeline()
+                            pipeline.hdel(hash_name, f"userid_{data}_queuename_{queue_name}")
+                            pipeline.zrem(zset_name, data)
+                            pipeline.zincrby(self._get_user_zset_name(app_id), -1, data)
+                            pipeline.execute()
             except Exception as ex:
                 self.logger_error.error("【删除未操作的排队信息】" + traceback.format_exc())
 
@@ -412,12 +431,13 @@ class QueueUpHelper:
                 self.pop(app_id, hash_value["queue_name"], data)
 
     @classmethod
-    def query(self, app_id, queue_name, user_id):
+    def query(self, app_id, queue_name, user_id, is_pop=True):
         """
         :description: 查询某用户排队情况
         :param app_id：应用标识
         :param queue_name：队列名称
         :param user_id：用户标识
+        :param is_pop：是否踢掉过期用户
         :return: 
         :last_editors: HuangJianYi
         """
@@ -427,9 +447,8 @@ class QueueUpHelper:
             zset_name = self._get_zset_name(app_id, queue_name)
             data = str(user_id)
             #踢掉过期用户
-            self.pop_by_queue_name(app_id, queue_name)
-            #删除用户排队次数小于等于0的数据
-            redis_init.zremrangebyscore(self._get_user_zset_name(app_id), -10, 0)
+            if is_pop == True:
+                self.pop_by_queue_name(app_id, queue_name)
 
             #判断是否存在排队信息
             score = redis_init.zscore(zset_name, data)
@@ -448,6 +467,7 @@ class QueueUpHelper:
                 query_user["avatar"] = hash_value["avatar"] if hash_value.__contains__("avatar") else ''
                 query_user["start_date"] = hash_value["start_date"] if hash_value.__contains__("start_date") else ''
                 query_user["end_date"] = hash_value["end_date"] if hash_value.__contains__("end_date") else ''
+                query_user["end_timestamp"] = hash_value["end_timestamp"] if hash_value.__contains__("end_timestamp") else ''
                 query_user["queue_date"] = hash_value["queue_date"] if hash_value.__contains__("queue_date") else ''
                 query_user["queue_timestamp"] = hash_value["queue_timestamp"] if hash_value.__contains__("queue_timestamp") else 0
                 query_user["progress_status"] = hash_value["progress_status"] if hash_value.__contains__("progress_status") else 0  #进度0未排队1已排队2办理中
@@ -462,19 +482,19 @@ class QueueUpHelper:
                 invoke_result_data.data = query_user
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = "未查到排队情况,请先排队"
+                invoke_result_data.error_message = "您当前不在队列中，请先排队"
                 return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【查询某用户排队情况】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
-            invoke_result_data.error_message = "未查到排队情况,请先排队"
+            invoke_result_data.error_message = "您当前不在队列中，请先排队"
             return invoke_result_data
 
     @classmethod
     def query_all(self, app_id, queue_name):
         """
-        :description: 查询指定队列的所有用户信息
+        :description: 查询指定队列的所有用户信息，出现请求时间太长，请使用query_list方法
         :param app_id：应用标识
         :param queue_name：队列名称
         :return: 
@@ -482,15 +502,93 @@ class QueueUpHelper:
         """
         invoke_result_data = InvokeResultData()
         invoke_result_data.data = []
-        zset_name = self._get_zset_name(app_id, queue_name)
+        zset_name = QueueUpHelper._get_zset_name(app_id, queue_name)
         redis_init = SevenHelper.redis_init()
-        user_id_list = redis_init.zrange(zset_name,0,-1)
+        user_id_list = redis_init.zrange(zset_name, 0, -1)
         if len(user_id_list) <= 0:
             return invoke_result_data
+        key_list = []
         for user_id in user_id_list:
-            query_invoke_result_data = self.query(app_id, queue_name, user_id)
-            if query_invoke_result_data.success == True:
-                invoke_result_data.data.append(query_invoke_result_data.data)
+            key = f"userid_{user_id}_queuename_{queue_name}"
+            key_list.append(key)
+        # 用户列表
+        user_list = []
+        # 踢掉过期用户
+        QueueUpHelper.pop_by_queue_name(app_id, queue_name)
+        # 总排队人数
+        total_num = QueueUpHelper._get_queue_num(app_id, queue_name)
+        hash_value_list = redis_init.hmget(QueueUpHelper._get_user_hash_name(app_id), key_list)
+        for item in hash_value_list:
+            hash_value = SevenHelper.json_loads(item) if item else {}
+            if not isinstance(hash_value, dict):
+                continue
+            query_user = {}
+            query_user["queue_name"] = hash_value.get("queue_name", '')
+            query_user["total_num"] = total_num
+            query_user["user_id"] = hash_value.get("user_id", '')
+            query_user["user_nick"] = hash_value.get("user_nick", '')
+            query_user["avatar"] = hash_value.get("avatar",'')
+            query_user["queue_timestamp"] = hash_value.get("queue_timestamp", 0)
+            query_user["progress_status"] = hash_value.get("progress_status", 0)  #进度0未排队1已排队2办理中
+            query_user["start_date"] = hash_value.get("start_date", '')
+            query_user["end_date"] = hash_value.get("end_date", '')
+            index = redis_init.zrank(zset_name, str(query_user["user_id"]))
+            if index is not None:
+                query_user["queue_index"] = int(index) + 1  #当前位置
+                query_user["before_num"] = query_user["queue_index"] - 1  #排在前面的人数
+                user_list.append(query_user)
+        invoke_result_data.data = user_list
+        return invoke_result_data
+
+    @classmethod
+    def query_list(self, app_id, queue_name, user_id, limit=10, is_pop=True):
+        """
+        :description: 查询指定队列的所有用户信息
+        :param app_id：应用标识
+        :param queue_name：队列名称
+        :param user_id：用户标识
+        :param limit：查询数量
+        :param is_pop：是否踢掉过期用户
+        :return: dict
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {}
+        zset_name = self._get_zset_name(app_id, queue_name)
+        redis_init = SevenHelper.redis_init()
+        user_id_list = redis_init.zrange(zset_name,0,limit)
+        if len(user_id_list) <= 0:
+            return invoke_result_data
+
+        result = {}
+        result["queue_name"] = queue_name  #队列名称
+        result["user_list"] = [] # 用户列表
+        result["current_user"] = {} # 当前用户
+
+        query_invoke_result_data = self.query(app_id, queue_name, user_id, is_pop)
+        if query_invoke_result_data.success == True:
+            result["current_user"] = query_invoke_result_data.data
+            result["current_user"]["service_timestamp"] = TimeHelper.get_now_timestamp()
+        result["total_num"] = self._get_queue_num(app_id, queue_name)  #总排队人数
+        key_list = []
+        for item in user_id_list:
+            key_list.append(f"userid_{item}_queuename_{queue_name}")
+        hash_value_list = redis_init.hmget(self._get_user_hash_name(app_id), key_list)
+        for item in hash_value_list:
+            if not item:
+                continue
+            hash_value = SevenHelper.json_loads(item)
+            if not isinstance(hash_value, dict):
+                continue
+            query_user = {}
+            query_user["user_id"] = hash_value.get("user_id", "")
+            query_user["user_nick"] = hash_value.get("user_nick", "")
+            query_user["avatar"] = hash_value.get("avatar", "")
+            query_user["queue_timestamp"] = hash_value.get("queue_timestamp", 0)
+            query_user["progress_status"] = hash_value.get("progress_status", 0)  #进度0未排队1已排队2办理中
+            result["user_list"].append(query_user)
+
+        invoke_result_data.data = result
         return invoke_result_data
 
     @classmethod
@@ -511,7 +609,7 @@ class QueueUpHelper:
             match_result = redis_init.hscan_iter(hash_name, match=f'userid_{data}_*')
             for item in match_result:
                 hash_value = SevenHelper.json_loads(item[1])
-                query_invoke_result_data = self.query(app_id, hash_value["queue_name"], user_id)
+                query_invoke_result_data = self.query(app_id, hash_value["queue_name"], user_id, False)
                 if query_invoke_result_data.success == True:
                     invoke_result_data.data.append(query_invoke_result_data.data)
             return invoke_result_data
@@ -519,7 +617,7 @@ class QueueUpHelper:
             self.logger_error.error("【批量查询某用户排队情况】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
-            invoke_result_data.error_message = "未查到排队情况,请先排队"
+            invoke_result_data.error_message = "您当前不在队列中，请先排队"
             return invoke_result_data
 
     @classmethod
@@ -536,7 +634,7 @@ class QueueUpHelper:
         invoke_result_data.data = []
         try:
             for queue_name in queue_name_list:
-                query_invoke_result_data = self.query(app_id, queue_name, user_id)
+                query_invoke_result_data = self.query(app_id, queue_name, user_id, False)
                 invoke_result_data.data.append(query_invoke_result_data.data)
             return invoke_result_data
         except Exception as ex:
@@ -587,6 +685,12 @@ class QueueUpHelper:
                     hash_value["end_timestamp"] = end_timestamp
                     hash_value["end_date"] = TimeHelper.timestamp_to_format_time(end_timestamp)
                 else:
+                    queue_operate_total_time = int(share_config.get_value("queue_operate_total_time", 0))
+                    now_date = TimeHelper.get_now_datetime()
+                    expire_date = TimeHelper.timestamp_to_datetime(hash_value["end_timestamp"])
+                    if expire_date > now_date and queue_operate_total_time > 0:
+                        remain_time = TimeHelper.difference_seconds(expire_date, now_date)
+                        operate_time = queue_operate_total_time - remain_time if remain_time + operate_time > queue_operate_total_time else operate_time
                     end_timestamp = hash_value["end_timestamp"] + int(operate_time)
                     hash_value["end_timestamp"] = end_timestamp
                     hash_value["end_date"] = TimeHelper.timestamp_to_format_time(end_timestamp)
@@ -600,13 +704,14 @@ class QueueUpHelper:
             return invoke_result_data
 
     @classmethod
-    def sign(self, app_id, queue_name, user_id, pop_other_queue=True):
+    def sign(self, app_id, queue_name, user_id, pop_other_queue=True, queue_operate_time=None):
         """
         :description: 签到操作（证明排队的人做出应答，开始办理业务，更新开始操作时间）
         :param app_id：应用标识
         :param queue_name：队列名称
         :param user_id：用户标识
-        :param pop_other_queue：是否退出其他正在排队的队列，True是False否
+        :param queue_operate_time：排到队可操作时间
+        :param user_id：用户标识
         :return: 
         :last_editors: HuangJianYi
         """
@@ -630,15 +735,17 @@ class QueueUpHelper:
             #判断是否存在排队信息
             score = redis_init.zscore(zset_name, data)
             if score:
-                queue_index = int(redis_init.zrank(zset_name, data)) + 1  #当前位置
+                queue_index = SevenHelper.to_int(redis_init.zrank(zset_name, data)) + 1  #当前位置
                 if queue_index != 1:
                     SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
-                    invoke_result_data.error_message = "前面还有人在排队,请耐心等待"
+                    invoke_result_data.error_message = "前面还有人在队列中，请耐心等待"
                     return invoke_result_data
                 start_timestamp = TimeHelper.get_now_timestamp()
-                end_timestamp = start_timestamp + int(share_config.get_value("queue_operate_time", 300))  #操作时间，单位秒
+                if not queue_operate_time:
+                    queue_operate_time = share_config.get_value("queue_operate_time", 300)
+                end_timestamp = start_timestamp + int(queue_operate_time)  #操作时间，单位秒
                 hash_name = self._get_user_hash_name(app_id)
                 hash_key = f"userid_{data}_queuename_{queue_name}"
                 hash_value = redis_init.hget(hash_name, hash_key)
@@ -646,14 +753,14 @@ class QueueUpHelper:
                     SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
-                    invoke_result_data.error_message = "未查到排队情况,请先排队"
+                    invoke_result_data.error_message = "您当前不在队列中，请先排队"
                     return invoke_result_data
                 hash_value = SevenHelper.json_loads(hash_value)
                 if hash_value["progress_status"] == 2:
                     SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
-                    invoke_result_data.error_message = "已签到,不能重复签到"
+                    invoke_result_data.error_message = "您已在队列中，请勿重复排队"
                     return invoke_result_data
 
                 hash_value["start_timestamp"] = start_timestamp
@@ -677,12 +784,12 @@ class QueueUpHelper:
                 SevenHelper.redis_release_lock(acquire_lock_name, identifier)
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
-                invoke_result_data.error_message = "未查到排队情况,请先排队"
+                invoke_result_data.error_message = "您当前不在队列中，请先排队"
                 return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【签到操作】" + traceback.format_exc())
             SevenHelper.redis_release_lock(acquire_lock_name, identifier)
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
-            invoke_result_data.error_message = "未查到排队情况,请先排队"
+            invoke_result_data.error_message = "您当前不在队列中，请先排队"
             return invoke_result_data
