@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2023-03-17 13:48:55
+@LastEditTime: 2025-01-15 10:55:38
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -16,6 +16,8 @@ import random
 import datetime
 import re
 import ast
+import json
+
 
 
 
@@ -33,21 +35,24 @@ class SevenHelper:
         return RedisExHelper.init(config_dict, decode_responses)
 
     @classmethod
-    def is_continue_request(self, cache_key, expire=500):
+    def is_continue_request(self, cache_key, expire=500, config_dict=None):
         """
         :description: 请求太频繁校验
         :param cache_key：自定义cache_key
         :param expire：过期时间，单位毫秒
+        :param config_dict：redis配置
         :return: bool true-代表连续请求进行限制，false-代表跳过限制
         :last_editors: HuangJianYi
         """
         if share_config.get_value("is_pressure_test",False): #是否进行压力测试
             return False
-        redis_init = self.redis_init()
+        if not config_dict:
+            config_dict = config.get_value("redis_safe")
+        redis_init = self.redis_init(config_dict=config_dict)
         post_value = redis_init.incr(cache_key,1)
-        redis_init.pexpire(cache_key,expire)
         if post_value > 1:
             return True
+        redis_init.pexpire(cache_key,expire)
         return False
 
     @classmethod
@@ -59,7 +64,7 @@ class SevenHelper:
          :return: bool False-代表达到长度限制，进行拦截
          :last_editors: HuangJianYi
          """
-        return RedisExHelper.check_llen(queue_name, queue_lenth)
+        return RedisExHelper.check_llen(queue_name, queue_lenth, config_dict=config.get_value("redis_safe"))
 
     @classmethod
     def redis_lpush(self, queue_name, value, expire):
@@ -71,7 +76,7 @@ class SevenHelper:
          :return:
          :last_editors: HuangJianYi
          """
-        RedisExHelper.lpush(queue_name, value, expire)
+        RedisExHelper.lpush(queue_name, value, expire, config_dict=config.get_value("redis_safe"))
 
     @classmethod
     def redis_lpop(self, queue_name):
@@ -81,7 +86,7 @@ class SevenHelper:
          :return: 
          :last_editors: HuangJianYi
          """
-        return RedisExHelper.lpop(queue_name)
+        return RedisExHelper.lpop(queue_name, config_dict=config.get_value("redis_safe"))
 
     @classmethod
     def redis_acquire_lock(self, lock_name, acquire_time=5, time_out=10):
@@ -93,7 +98,7 @@ class SevenHelper:
         :return 分布式锁是否获得（True获得False未获得）和解锁钥匙（释放锁时需传入才能解锁成功）
         :last_editors: HuangJianYi
         """
-        return RedisExHelper.acquire_lock(lock_name, acquire_time, time_out)
+        return RedisExHelper.acquire_lock(lock_name, acquire_time, time_out, config_dict=config.get_value("redis_safe"))
 
     @classmethod
     def redis_release_lock(self, lock_name, identifier):
@@ -104,7 +109,7 @@ class SevenHelper:
         :return bool
         :last_editors: HuangJianYi
         """
-        return RedisExHelper.release_lock(lock_name, identifier)
+        return RedisExHelper.release_lock(lock_name, identifier, config_dict=config.get_value("redis_safe"))
 
     @classmethod
     def merge_dict_list(self, source_dict_list, source_key, merge_dict_list, merge_key, merge_columns_names='', exclude_merge_columns_names=''):
@@ -221,6 +226,78 @@ class SevenHelper:
             return f"{field_name} IN({list_str})"
         else:
             return f"{field_name} NOT IN({list_str})"
+        
+    @classmethod
+    def exclude_field(self, s_model, exclude_field):
+        """
+        :description: 排除不需要的字段（查询时使用）
+        :param s_model:对象实例
+        :param exclude_field:不进行查询的字段，分隔
+        :return:字符串
+        :last_editors: HuangJianYi
+        """
+        field = "*"
+        try:
+            field_list = set(s_model.get_field_list())
+            exclude_field_list = set(exclude_field.split(','))
+            field = ','.join(list(field_list - exclude_field_list))
+        except Exception as ex:
+            pass
+        return field
+
+    @classmethod
+    def get_row_by_dict_list(self, dict_list, field_name, field_type=1):
+        """
+        :description: 获取字典列表中指定列的集合
+        :param dict_list:字典列表
+        :param field_name:字段名
+        :param field_type:字段类型（1整形2字符串）
+        :return:数组
+        :last_editors: HuangJianYi
+        """
+        if isinstance(dict_list,list) == False:
+            return []
+        if field_type == 1:
+            return [int(item[field_name]) for item in dict_list]
+        else:
+            return [str(item[field_name]) for item in dict_list]
+
+    @classmethod
+    def replace_value_to_list(self, data_list, old_item, new_item):
+        """
+        :description: 替换列表中指定元素，旧值换新值
+        :param old_item:旧元素(可对象、字典)
+        :param new_item:新元素(可对象、字典)
+        :return:list
+        :last_editors: HuangJianYi
+        """
+        try:
+            data_index = data_list.index(old_item)
+            data_list[data_index] = new_item
+        except:
+            pass
+        return data_list
+    
+    @classmethod
+    def remove_dict_field(self, data, remove_field_list=[]):
+        """
+        :description: 移除字典或字典列表中指定字段
+        :param data:字典或字典列表
+        :param remove_field_list:删除字段列表
+        :return:
+        :last_editors: HuangJianYi
+        """
+        if len(remove_field_list) > 0:
+            if isinstance(data, list):
+                for item in data:
+                    for remove_field in remove_field_list:
+                        if remove_field in item:
+                            del item[remove_field]
+            else:
+                for remove_field in remove_field_list:
+                    if remove_field in data.keys():
+                        del data[remove_field]
+        return data
 
     @classmethod
     def is_ip(self, ip_str):
@@ -416,13 +493,13 @@ class SevenHelper:
         :return: str
         :last_editors: HuangJianYi
         """
+        if rep_dic == "":
+            return ""
         try:
             rep_dic = ast.literal_eval(rep_dic)
-        except ValueError:
+        except Exception:
             pass
-        if hasattr(rep_dic, '__dict__'):
-            rep_dic = rep_dic.__dict__
-        return json.dumps(rep_dic, ensure_ascii=False, cls=JsonEncoder, default=lambda x: (x.__dict__ if not isinstance(x, datetime.datetime) else datetime.datetime.strftime(x, '%Y-%m-%d %H:%M:%S')) if not isinstance(x, decimal.Decimal) else float(x), sort_keys=False, indent=1)
+        return json.dumps(rep_dic, ensure_ascii=False, cls=JsonEncoder, sort_keys=False, indent=None)
 
     @classmethod
     def json_loads(self, rep_str):
@@ -449,8 +526,29 @@ class SevenHelper:
         sub_table = None
         if not sub_count or not object_id:
             return sub_table
+        if isinstance(object_id,str) and not object_id.isdigit():
+            object_id = CryptoHelper.md5_encrypt_int(object_id)
         sub_table = str(int(object_id) % sub_count)
         return sub_table
+    
+    @classmethod
+    def get_connect_config(self, db_key, redis_key, db_connect_key="db_cloudapp", redis_config_dict=None):
+        """
+        :description: 获取数据库和redis连接key
+        :param db_key:数据库 key
+        :param redis_key:redis key
+        :param db_connect_key:默认数据库 key
+        :param redis_config_dict:默认redis key
+        :return:
+        :last_editors: HuangJianYi
+        """
+        db_connect_key = db_key if config.get_value(db_key) else db_connect_key
+        redis_config_dict = config.get_value(redis_key) if config.get_value(redis_key) else redis_config_dict
+        connect_key_config = share_config.get_value("connect_key_config")
+        if connect_key_config:
+            db_connect_key = connect_key_config.get(db_key) if connect_key_config.get(db_key) else db_connect_key
+            redis_config_dict = config.get_value(connect_key_config.get(redis_key)) if connect_key_config.get(redis_key) else redis_config_dict
+        return db_connect_key, redis_config_dict
 
     @classmethod
     def remove_exponent(self, param):
@@ -460,9 +558,10 @@ class SevenHelper:
         :return:
         :last_editors: HuangJianYi
         """
-        if isinstance(param, str):
+        if isinstance(param, str) or isinstance(param, float):
             param = decimal.Decimal(param)
-        return param.to_integral() if param == param.to_integral() else param.normalize()
+        param = param.to_integral() if param == param.to_integral() else param.normalize()
+        return str(param)
 
     @classmethod
     def check_under_age(self, card_id):
@@ -546,47 +645,97 @@ class SevenHelper:
             return default_value
 
     @classmethod
-    def to_int(self, value):
+    def to_int(self, value, default_value=0, return_status=False):
         """
         :description: 转换成整形
         :param value:值
+        :param default_value:出现异常的默认值
+        :param return_status:返回转换结果 True成功 False失败
         :return:整形
         :last_editors: HuangJianYi
         """
+        status = True
         try:
             value = int(value)
         except Exception as ex:
-            value = 0
+            value = default_value
+            status = False
+        if return_status == True:
+            return value, status
         return value
 
     @classmethod
-    def get_row_by_dict_list(self, dict_list, field_name, field_type=1):
+    def to_decimal(self, value, default_value=0, return_status=False, round_mode=0):
         """
-        :description: 获取字典列表中指定列的集合
-        :param field_name:字段名
-        :param field_type:字段类型（1整形2字符串）
-        :return:数组
-        :last_editors: HuangJianYi
-        """
-        if isinstance(dict_list,list) == False:
-            return []
-        if field_type == 1:
-            return [int(item[field_name]) for item in dict_list]
-        else:
-            return [str(item[field_name]) for item in dict_list]
-
-    @classmethod   
-    def replace_value_to_list(self, data_list, old_item, new_item):
-        """
-        :description: 替换列表中指定元素，旧值换新值
-        :param old_item:旧元素(可对象、字典)
-        :param new_item:新元素(可对象、字典)
-        :return:list
+        :description: 转换成浮点形
+        :param value:值
+        :param default_value:出现异常的默认值
+        :param return_status:返回转换结果 True成功 False失败
+        :param round_mode:1-ROUND_CEILING: 向上舍入到最接近的整数（如果是正数），否则向下。
+                        2-ROUND_FLOOR: 向下舍入到最接近的整数（如果是负数），否则向上。
+                        3-ROUND_DOWN: 向零方向舍入（即直接截断小数部分）。
+                        4-ROUND_UP: 向远离零的方向舍入（即始终进位）。
+                        5-ROUND_HALF_UP: 四舍五入，如果数字正好在两个可能的值之间，则向上舍入。
+                        6-ROUND_HALF_DOWN: 四舍五入，如果数字正好在两个可能的值之间，则向下舍入。
+                        7-ROUND_HALF_EVEN: 银行家舍入（即向最近的偶数舍入）。
+                        8-ROUND_05UP: 如果数字的最后一位是 0 或 5，则向上舍入。
+        :return:浮点形
         :last_editors: HuangJianYi
         """
+        from decimal import ROUND_HALF_UP
+        status = True
         try:
-            data_index = data_list.index(old_item)
-            data_list[data_index] = new_item
-        except:
-            pass
-        return data_list
\ No newline at end of file
+            if round_mode == 5:
+                value = decimal.Decimal(value).quantize(decimal.Decimal('0.00'), rounding=ROUND_HALF_UP)
+            else:
+                value = decimal.Decimal(value)
+        except Exception as ex:
+            value = default_value
+            status = False
+        if return_status == True:
+            return value, status
+        return value
+
+    @classmethod
+    def to_date_time(self, value, fmt='%Y-%m-%d %H:%M:%S', default_value='1900-01-01 00:00:00', return_status=False):
+        """
+        :description: 转换成时间类型
+        :param value:值
+        :param fmt:时间格式化
+        :param default_value:出现异常的默认值
+        :param return_status:返回转换结果 True成功 False失败
+        :return:时间类型
+        :last_editors: HuangJianYi
+        """
+        status = True
+        try:
+            value = datetime.datetime.strptime(value, fmt)
+        except Exception as ex:
+            value = datetime.datetime.strptime(default_value, fmt)
+            status = False
+        if return_status == True:
+            return value, status
+        return value
+
+
+class JsonEncoder(json.JSONEncoder):
+    """
+    继承json.JSONEncoder
+
+    使用方法:json.dumps(json_obj, ensure_ascii=False, cls=JsonEncoder)
+    """
+    def default(self, obj):  # pylint: disable=E0202
+        if isinstance(obj, datetime.datetime):
+            return obj.strftime('%Y-%m-%d %H:%M:%S')
+        elif isinstance(obj, datetime.date):
+            return obj.strftime("%Y-%m-%d")
+        elif isinstance(obj, bytes):
+            return obj.decode()
+        elif isinstance(obj, decimal.Decimal):
+            return float(obj)
+        elif isinstance(obj, set):
+            return list(obj)
+        elif hasattr(obj, '__dict__'):
+            return obj.__dict__
+        else:
+            return json.JSONEncoder.default(self, obj)
\ No newline at end of file
