@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-01-14 10:44:07
-@LastEditTime: 2023-02-10 09:59:17
+@LastEditTime: 2024-08-26 10:32:23
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -24,13 +24,14 @@ class TikTokHelper:
     logger_error = Logger.get_logger_by_name("log_error")
 
     @classmethod
-    def code2_session(self, code="", anonymous_code="", app_id="", app_secret=""):
+    def code2_session(self, code="", anonymous_code="", app_id="", app_secret="", redis_config_dict=None):
         """
         :description:获取open_id、session_key等信息
         :param code: 登录票据,非匿名需要 code
         :param anonymous_code: 非匿名下的 anonymous_code 用于数据同步，匿名需要 anonymous_code
         :param app_id: app_id
         :param app_secret: app_secret
+        :param redis_config_dict: redis_config_dict
         :return: 
         :last_editors: HuangJianYi
         """
@@ -39,7 +40,7 @@ class TikTokHelper:
 
         invoke_result_data = InvokeResultData()
         redis_key = f"{app_id}_tiktok_login_code:{code}"
-        redis_init = SevenHelper.redis_init()
+        redis_init = SevenHelper.redis_init(redis_config_dict)
         code2_session_dict = redis_init.get(redis_key)
         if code2_session_dict:
             code2_session_dict = SevenHelper.json_loads(code2_session_dict)
@@ -62,6 +63,10 @@ class TikTokHelper:
                 invoke_result_data.error_code = response_data["err_no"]
                 invoke_result_data.error_message = response_data["err_tips"]
                 return invoke_result_data
+            if not isinstance(response_data, dict) or "data" not in response_data:
+                raise Exception("返回格式异常")
+            if not isinstance(response_data["data"], dict):
+                raise Exception("返回格式异常")
             open_id = response_data["data"]['openid']
             session_key = response_data["data"]['session_key']
             redis_init.set(redis_key, SevenHelper.json_dumps(response_data["data"]), ex=60 * 60)
@@ -69,19 +74,21 @@ class TikTokHelper:
             invoke_result_data.data = response_data["data"]
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【code2_session】" + traceback.format_exc())
+            self.logger_error.error(f"【code2_session】,info:{SevenHelper.json_dumps(response)},异常:{traceback.format_exc()}")
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
-            invoke_result_data.error_message = traceback.format_exc()
+            invoke_result_data.error_message = "获取openid失败"
             return invoke_result_data
 
     @classmethod
-    def get_access_token(self, grant_type="client_credential", app_id="", app_secret=""):
+    def get_access_token(self, grant_type="client_credential", app_id="", app_secret="", is_del=False):
         """
-        :description:access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。
+        :description:后续会新增和抖音能力 client_token 相通的接口，各 openapi 支持 client_token 调用，建议开发者逐步迁移新接口。token 是小程序级别 token，不要为每个用户单独分配一个 token，会导致 token 校验失败。建议每小时更新一次即可。
+        access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。
         :param grant_type: 获取access_token 时值为 client_credential
         :param app_id: app_id
         :param app_secret: app_secret
+        :param is_del:是否删除redis里的access_token
         :return: 
         :last_editors: HuangJianYi
         """
@@ -94,10 +101,12 @@ class TikTokHelper:
             'secret': app_secret,
             'grant_type': grant_type,
         }
-        response = None
-        redis_init = SevenHelper.redis_init(config_dict=share_config.get_value("platform_redis"))
-        redis_key = f"tiktok_access_token:{str(app_id)}"
         try:
+            response = None
+            redis_key = f"tiktok_access_token:{str(app_id)}"
+            redis_init = SevenHelper.redis_init(config_dict=share_config.get_value("platform_redis"))
+            if is_del == True:
+                redis_init.delete(redis_key)
             access_token = redis_init.get(redis_key)
             if access_token:
                 invoke_result_data.data = access_token
@@ -118,7 +127,56 @@ class TikTokHelper:
             self.logger_error.error("【get_access_token】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
-            invoke_result_data.error_message = traceback.format_exc()
+            invoke_result_data.error_message = "获取access_token失败"
+            return invoke_result_data
+     
+    @classmethod
+    def get_client_token(self, grant_type="client_credential", app_id="", app_secret="", is_del=False):
+        """
+        :description:client_token 用于不需要用户授权就可以调用的接口,client_token 的有效时间为 2 个小时，重复获取 client_token 后会使上次的 client_token 失效（但有 5 分钟的缓冲时间，连续多次获取 client_token 只会保留最新的两个 client_token）。
+        :param grant_type: 获取access_token 时值为 client_credential
+        :param app_id: app_id
+        :param app_secret: app_secret
+        :param is_del:是否删除redis里的access_token
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
+
+        invoke_result_data = InvokeResultData()
+        param = {
+            'appid': app_id,
+            'secret': app_secret,
+            'grant_type': grant_type,
+        }
+        try:
+            response = None
+            redis_key = f"tiktok_access_token:{str(app_id)}"
+            redis_init = SevenHelper.redis_init(config_dict=share_config.get_value("platform_redis"))
+            if is_del == True:
+                redis_init.delete(redis_key)
+            access_token = redis_init.get(redis_key)
+            if access_token:
+                invoke_result_data.data = access_token
+                return invoke_result_data
+            requset_url = 'https://open.douyin.com/oauth/client_token/'
+            headers = {"Content-type": "application/json"}
+            response = requests.post(requset_url, headers=headers, data=json.dumps(param))
+            response_data = SevenHelper.json_loads(response.text)["data"]
+            if response_data.__contains__("error_code") and response_data["error_code"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["error_code"]
+                invoke_result_data.error_message = response_data["description"]
+                return invoke_result_data
+            invoke_result_data.data = str(response_data["access_token"])
+            redis_init.set(redis_key, invoke_result_data.data, ex=3600)
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error(f"【get_client_token】,info:{SevenHelper.json_dumps(response)},异常:{traceback.format_exc()}")
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = "获取client_token失败"
             return invoke_result_data
 
     @classmethod
@@ -173,49 +231,140 @@ class TikTokHelper:
         return data
 
     @classmethod
-    def create_qr_code(self, access_token, appname="douyin", path="", width=430, line_color={ "r": 0, "g": 0, "b": 0 }, background={ "r": 255, "g": 255, "b": 255 }):
+    def create_qr_code(self, path="", width=430, line_color={ "r": 0, "g": 0, "b": 0 }, background={ "r": 255, "g": 255, "b": 255 }, app_name="douyin", set_icon=False, is_circle_code=False, app_id="", app_secret=""):
         """
         :description:获取小程序/小游戏的二维码。该二维码可通过任意 app 扫码打开，能跳转到开发者指定的对应字节系 app 内拉起小程序/小游戏， 并传入开发者指定的参数。通过该接口生成的二维码，永久有效，暂无数量限制。
-        :param access_token: 服务端 API 调用标识
-        :param appname: 打开二维码的字节系 app 名称
         :param path: 小程序/小游戏启动参数，小程序则格式为 encode({path}?{query})，小游戏则格式为 JSON 字符串，默认为空
         :param width: 二维码宽度，单位 px，最小 280px，最大 1280px，默认为 430px
         :param line_color: 二维码线条颜色，默认为黑色
         :param background: 二维码背景颜色，默认为白色
+        :param app_name: 打开二维码的字节系 app 名称
+        :param set_icon: 是否展示小程序/小游戏 icon，默认不展示
+        :param is_circle_code: 默认是false，是否生成抖音码，默认不生成（抖音码不支持自定义颜色）
         :return: 图片二进制 数据类型Array<byte>
         :last_editors: HuangJianYi
         """
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
+
         invoke_result_data = InvokeResultData()
+        redis_init = SevenHelper.redis_init(decode_responses=False)
+        redis_key = "create_qr_code:" + CryptoHelper.md5_encrypt(f"{path}")
+        redis_value = redis_init.get(redis_key)
+        if redis_value:
+            invoke_result_data.data = redis_value
+            return invoke_result_data
+
+        for i in range(2):
+            if i == 0:
+                invoke_result_data = self.get_client_token(app_id=app_id, app_secret=app_secret)
+            else:
+                invoke_result_data = self.get_client_token(app_id=app_id, app_secret=app_secret, is_del=True)
+
+            if invoke_result_data.success == True:
+                break
+        if invoke_result_data.success == False:
+            return invoke_result_data
+        access_token = invoke_result_data.data
         param = {
-                "appname": appname,
-                "access_token": access_token,
+                "app_name": app_name,
+                "appid": app_id,
                 "path": path,
                 "width": width,
                 "line_color": line_color,
-                "background": background
+                "background": background,
+                "set_icon": set_icon,
+                "is_circle_code": is_circle_code
                 }
-        response = ""
+        response = None
         try:
-            requset_url = 'https://developer.toutiao.com/api/apps/token'
-            headers = {"Content-type": "application/json"}
+            requset_url = 'https://open.douyin.com/api/apps/v1/qrcode/create/'
+            headers = {"Content-type": "application/json", "access-token": access_token}
             response = requests.post(requset_url, headers=headers, data=json.dumps(param))
             response_data = SevenHelper.json_loads(response.text)
-            if response_data["errcode"] != 0:
+            if response_data.__contains__("err_no") and response_data["err_no"] != 0:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = response_data["err_no"]
-                invoke_result_data.error_message = response_data["err_tips"]
+                invoke_result_data.error_message = response_data["err_msg"]
                 return invoke_result_data
-            else:
-                invoke_result_data.data = response_data.content
+            if not isinstance(response_data, dict) or "data" not in response_data:
+                raise Exception("返回格式异常")
+            if not isinstance(response_data["data"], dict):
+                raise Exception("返回格式异常")
+            invoke_result_data.data = response_data["data"]["img"]
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【create_qr_code】" + traceback.format_exc() + ":" + str(response.text))
+            self.logger_error.error(f"【create_qr_code】,info:{SevenHelper.json_dumps(response)},异常:{traceback.format_exc()}")
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
-            invoke_result_data.error_message = traceback.format_exc()
+            invoke_result_data.error_message = "获取小程序/小游戏的二维码失败"
             return invoke_result_data
 
 
+    @classmethod
+    def get_url_link(self, app_id="", app_secret="", app_name="douyin", expire_time=0, query="", path=""):
+        """
+        :description:用于生成能够直接跳转到端内小程序的 url link 并传入开发者指定的参数 根据参数生成 url link 链接
+        :param expire_time: 过期时间 到期失效的URL Link的失效时间。为 Unix 时间戳，实际失效时间为距离当前时间小时数，向上取整。最长间隔天数为180天 单位秒
+        :param query: 通过URL Link进入小程序时的 query（json形式），若无请填{}。最大1024个字符，只支持数字，大小写英文以及部分特殊字符：`{}!#$&'()*+,/:;=?@-._~%``
+        :param path: 跳转路径 通过URL Link进入的小程序页面路径，必须是已经发布的小程序存在的页面，不可携带 query。path 为空时会跳转小程序主页。
+        :return: 链接字符串 数据类型Srting
+        :last_editors: ChenWeiHao
+        """
+        app_id = app_id if app_id else share_config.get_value("app_id")
+        app_secret = app_secret if app_secret else share_config.get_value("app_secret")
+
+        invoke_result_data = InvokeResultData()
+        redis_init = SevenHelper.redis_init(decode_responses=False)
+        redis_key = "get_url_link:" + CryptoHelper.md5_encrypt(f"{path}")
+        redis_value = redis_init.get(redis_key)
+        if redis_value:
+            invoke_result_data.data = redis_value
+            return invoke_result_data
+
+        for i in range(2):
+            if i == 0:
+                invoke_result_data = self.get_client_token(app_id=app_id, app_secret=app_secret)
+            else:
+                invoke_result_data = self.get_client_token(app_id=app_id, app_secret=app_secret, is_del=True)
+            if invoke_result_data.success == True:
+                break
+        if invoke_result_data.success == False:
+            return invoke_result_data
+        access_token = invoke_result_data.data
+        param = {
+                "app_id": app_id,
+                "app_name": app_name,
+                "expire_time": expire_time,
+                "query": query,
+                "path": path,
+                }
+        response = None
+        try:
+            requset_url = 'https://open.douyin.com/api/apps/v1/url_link/generate/'
+            headers = {"content-type": "application/json", "access-token": access_token}
+            response = requests.post(requset_url, headers=headers, data=json.dumps(param))
+            response_data = SevenHelper.json_loads(response.text)
+            if response_data.__contains__("err_no") and response_data["err_no"] != 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = response_data["err_no"]
+                invoke_result_data.error_message = response_data["err_msg"]
+                return invoke_result_data
+            if not isinstance(response_data, dict) or "data" not in response_data:
+                raise Exception("返回格式异常")
+            if not isinstance(response_data["data"], dict):
+                raise Exception("返回格式异常")
+            invoke_result_data.data = response_data["data"]["url_link"]
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error(f"【get_url_link】,info:{SevenHelper.json_dumps(response)},异常:{traceback.format_exc()}")
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = "获取url_link链接失败"
+            return invoke_result_data
+
+
+
 class TikTokPayRequest(object):
     """
     :description: 抖音支付请求类,配置文件内容 "tiktok_pay": {"cp_extra": "","token": "","salt": ""}
@@ -281,8 +430,10 @@ class TikTokPayRequest(object):
             # 如果有第三方平台服务商id:thirdparty_id字段请把他放入data的字典里面
             data['sign'] = sign
 
+            redis_init = SevenHelper.redis_init()
+
             redis_key = f"{self.app_id}_tiktok_order_id:{str(pay_order_no)}"
-            orderInfo = SevenHelper.redis_init().get(redis_key)
+            orderInfo = redis_init.get(redis_key)
             if orderInfo:
                 invoke_result_data.data = SevenHelper.json_loads(orderInfo)
                 return invoke_result_data
@@ -296,7 +447,7 @@ class TikTokPayRequest(object):
             # data	    orderInfo	拉起收银台的 orderInfo
             # {"err_no": 2000, "err_tips": "单号记录不存在", "data": null}
             if response_data['err_no'] == 0:
-                SevenHelper.redis_init().set(redis_key, SevenHelper.json_dumps(response_data['data']), ex=3600 * 1)
+                redis_init.set(redis_key, SevenHelper.json_dumps(response_data['data']), ex=3600 * 1)
                 invoke_result_data.data = response_data['data']
                 return invoke_result_data
             else:
