@@ -2,12 +2,13 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2023-02-17 09:26:10
+@LastEditTime: 2025-03-24 15:57:20
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.seven_model import *
+from seven_cloudapp_frame.libs.customize.safe_helper import SafeHelper
 
 from seven_cloudapp_frame.models.db_models.base.base_info_model import *
 from seven_cloudapp_frame.models.db_models.act.act_type_model import *
@@ -27,7 +28,24 @@ class ActBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def _delete_act_info_dependency_key(self,app_id,act_id,delay_delete_time=0.01):
+    def _delete_act_info_dependency_key_v2(self, **args):
+        """
+        :description: 删除活动信息依赖建
+        :param args: 必须指定参数名的可变长度的关键字参数（类似字典）
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = args.get("app_id", "") # 应用标识
+        act_id = args.get("act_id", 0) # 活动标识
+        delay_delete_time = args.get("delay_delete_time", 0.01) # 延迟删除时间
+        dependency_key_list = []
+        if act_id:
+            dependency_key_list.append(DependencyKey.act_info(act_id)) 
+        if app_id:
+            dependency_key_list.append(DependencyKey.act_info_list(app_id))
+        return ActInfoModel().delete_dependency_key(dependency_key_list, delay_delete_time)
+
+    def _delete_act_info_dependency_key(self, app_id, act_id, delay_delete_time=0.01):
         """
         :description: 删除活动信息依赖建
         :param app_id: 应用标识
@@ -36,12 +54,7 @@ class ActBaseModel():
         :return: 
         :last_editors: HuangJianYi
         """
-        dependency_key_list = []
-        if act_id:
-            dependency_key_list.append(DependencyKey.act_info(act_id)) 
-        if app_id:
-            dependency_key_list.append(DependencyKey.act_info_list(app_id))
-        ActInfoModel().delete_dependency_key(dependency_key_list, delay_delete_time)
+        return self._delete_act_info_dependency_key_v2(app_id=app_id, act_id=act_id, delay_delete_time=delay_delete_time)
 
     def get_act_info_dict(self,act_id,is_cache=True,is_filter=True, field="*"):
         """
@@ -53,10 +66,10 @@ class ActBaseModel():
         :return: 返回活动信息
         :last_editors: HuangJianYi
         """
-        act_info_model = ActInfoModel(context=self.context)
+        act_info_model = ActInfoModel(context=self.context, is_auto=True)
         if is_cache:
             dependency_key = DependencyKey.act_info(act_id)
-            act_info_dict = act_info_model.get_cache_dict_by_id(primary_key_id=act_id, dependency_key=dependency_key, field=field)
+            act_info_dict = act_info_model.get_cache_dict_by_id(primary_key_id=act_id, dependency_key=dependency_key, cache_expire=600, field=field)
         else:
             act_info_dict = act_info_model.get_dict_by_id(act_id, field)
         if is_filter == True:
@@ -64,7 +77,7 @@ class ActBaseModel():
                 return None
         return act_info_dict
 
-    def get_act_info_list(self, app_id, act_name, is_del, page_size, page_index, is_cache=True, act_type=-1, is_release=-1, order_by="id asc"):
+    def get_act_info_list(self, app_id, act_name, is_del, page_size, page_index, is_cache=True, act_type=-1, is_release=-1, order_by="id asc", business_type=-1):
         """
         :description: 获取活动信息列表
         :param app_id: 应用标识
@@ -73,8 +86,10 @@ class ActBaseModel():
         :param page_size: 条数
         :param page_index: 页数
         :param is_cache: 是否缓存
+        :param act_type: 活动类型
         :param is_release: 是否发布（1是0否）
-        :param is_release: 是否发布（1是0否）
+        :param order_by: 排序
+        :param business_type: 业务类型
         :return: 
         :last_editors: HuangJianYi
         """
@@ -90,12 +105,15 @@ class ActBaseModel():
         if act_type !=-1:
             condition_where.add_condition("act_type=%s")
             params.append(act_type)
+        if business_type !=-1:
+            condition_where.add_condition("business_type=%s")
+            params.append(business_type)
         if act_name:
             condition_where.add_condition("act_name=%s")
             params.append(act_name)
 
         if is_cache:
-            page_list, total = ActInfoModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params,dependency_key=DependencyKey.act_info_list(app_id))
+            page_list, total = ActInfoModel(context=self.context, is_auto=True).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params, dependency_key=DependencyKey.act_info_list(app_id), cache_expire=300)
         else:
             page_list, total = ActInfoModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params)
         for page in page_list:
@@ -107,7 +125,7 @@ class ActBaseModel():
             page["finish_status"] = page["is_finish"]
         return page_list, total
 
-    def add_act_info(self, app_id, act_name, act_type, theme_id, share_desc_json, rule_desc_json, close_word="抱歉，程序维护中", is_share=-1, is_rule=-1, is_release=-1, start_date=None, end_date=None, is_black=-1, refund_count=-1, join_ways=-1, is_fictitious=-1, store_url=None, i1=-1, i2=-1, i3=-1, i4=-1, i5=-1, s1=None, s2=None, s3=None, s4=None, s5=None, d1=None, d2=None, is_visit_store=-1, agreement_json=[], brand_json={}):
+    def add_act_info(self, app_id, act_name, act_type, theme_id, share_desc_json, rule_desc_json, close_word="抱歉，程序维护中", is_share=-1, is_rule=-1, is_release=-1, start_date=None, end_date=None, is_black=-1, refund_count=-1, join_ways=-1, is_fictitious=-1, store_url=None, i1=-1, i2=-1, i3=-1, i4=-1, i5=-1, s1=None, s2=None, s3=None, s4=None, s5=None, d1=None, d2=None, is_visit_store=-1, agreement_json=[], brand_json={}, business_type=-1):
         """
         :description: 添加活动信息
         :param app_id: 应用标识
@@ -141,6 +159,7 @@ class ActBaseModel():
         :param is_visit_store: 是否开启访问店铺
         :param agreement_json: 协议配置（用户协议或隐私条款）
         :param brand_json: 品牌配置
+        :param business_type: 业务类型
         :return: 
         :last_editors: HuangJianYi
         """
@@ -210,12 +229,13 @@ class ActBaseModel():
         act_info.is_visit_store = is_visit_store if is_visit_store !=-1 else 0
         act_info.agreement_json = agreement_json if agreement_json else []
         act_info.brand_json = brand_json if brand_json else {}
+        act_info.business_type = business_type if business_type !=-1 else 0
         act_info.id = act_info_model.add_entity(act_info)
         invoke_result_data.data = act_info
-        self._delete_act_info_dependency_key(app_id,act_info.id)
+        self._delete_act_info_dependency_key(app_id=app_id, act_id=act_info.id)
         return invoke_result_data
 
-    def update_act_info(self, app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word="抱歉，程序维护中", store_url=None, i1=-1, i2=-1, i3=-1, i4=-1, i5=-1, s1=None, s2=None, s3=None, s4=None, s5=None, d1=None, d2=None, is_visit_store=-1, agreement_json=[], brand_json={}):
+    def update_act_info(self, app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word="抱歉，程序维护中", store_url=None, i1=-1, i2=-1, i3=-1, i4=-1, i5=-1, s1=None, s2=None, s3=None, s4=None, s5=None, d1=None, d2=None, is_visit_store=-1, agreement_json=[], brand_json={}, business_type=-1, is_set_cache=True):
         """
         :description: 修改活动信息
         :param app_id: 应用标识
@@ -250,6 +270,8 @@ class ActBaseModel():
         :param is_visit_store: 是否开启访问店铺
         :param agreement_json: 协议配置（用户协议或隐私条款）
         :param brand_json: 品牌配置
+        :param business_type: 业务类型
+        :param is_set_cache: 是否设置缓存，默认True False-则是删除依赖建
         :return: 
         :last_editors: HuangJianYi
         """
@@ -265,8 +287,6 @@ class ActBaseModel():
         now_datetime = SevenHelper.get_now_datetime()
         if act_name !=None:
             act_info.act_name = act_name
-        if is_release !=-1:
-            act_info.is_release = is_release
         if theme_id !=-1:
             act_info.theme_id = theme_id
         if is_share !=-1:
@@ -326,28 +346,37 @@ class ActBaseModel():
             act_info.agreement_json = agreement_json
         if brand_json !=None:
             act_info.brand_json = brand_json
+        if business_type !=-1:
+            act_info.business_type = business_type
+
         act_info.modify_date = now_datetime
         act_info_model.update_entity(act_info,exclude_field_list="finish_menu_config_json,is_finish,task_asset_type_json,is_launch")
         result = {}
         result["old"] = old_act_info
         result["new"] = act_info
         invoke_result_data.data = result
-        self._delete_act_info_dependency_key(app_id,act_info.id)
+        if is_set_cache == True:
+            self._delete_act_info_dependency_key(app_id=app_id, act_id=0)
+            act_info_model.set_cache_dict_by_id(act_info.id, act_info.__dict__, DependencyKey.act_info(act_info.id)) # 更新缓存
+        else:
+            self._delete_act_info_dependency_key(app_id=app_id, act_id=act_info.id)
+
         return invoke_result_data
 
-    def update_act_info_status(self,app_id,act_id,is_del):
+    def update_act_info_status(self, app_id, act_id, is_del, is_set_cache=True):
         """
         :description: 删除或者还原活动
         :param app_id：应用标识
         :param act_id：活动标识
         :param is_del：0-还原，1-删除
+        :param is_set_cache: 是否设置缓存，默认True False-则是删除依赖建
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         act_info_model = ActInfoModel(context=self.context)
         act_info_dict = act_info_model.get_dict_by_id(act_id)
-        if not act_info_dict or act_info_dict["app_id"]!=app_id:
+        if not act_info_dict or SafeHelper.authenticat_app_id(act_info_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "no_act"
             invoke_result_data.error_message = "活动信息不存在"
@@ -355,29 +384,47 @@ class ActBaseModel():
         is_release = 0
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_info_model.update_table("is_del=%s,is_release=%s,release_date=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, modify_date, act_id])
-        self._delete_act_info_dependency_key(app_id,act_id)
+        if is_set_cache == True:
+            act_info_dict['is_del'] = is_del
+            act_info_dict['is_release'] = is_release
+            act_info_dict['release_date'] = modify_date
+            act_info_dict['modify_date'] = modify_date
+            self._delete_act_info_dependency_key(app_id=app_id, act_id=0)
+            act_info_model.set_cache_dict_by_id(act_id, act_info_dict, DependencyKey.act_info(act_id)) # 更新缓存
+        else:
+            self._delete_act_info_dependency_key(app_id=app_id, act_id=act_id)
+
         invoke_result_data.data = act_info_dict
         return invoke_result_data
 
-    def release_act_info(self,app_id,act_id,is_release):
+    def release_act_info(self, app_id, act_id, is_release, is_set_cache=True):
         """
-        :description: ip上下架
+        :description: 活动上下架
         :param app_id：应用标识
         :param act_id：活动标识
         :param is_release: 是否发布 1-是 0-否
+        :param is_set_cache: 是否设置缓存，默认True False-则是删除依赖建
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         act_info_model = ActInfoModel(context=self.context)
         act_info_dict = act_info_model.get_dict_by_id(act_id)
-        if not act_info_dict or act_info_dict["app_id"]!=app_id:
+        if not act_info_dict or SafeHelper.authenticat_app_id(act_info_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "no_act"
             invoke_result_data.error_message = "活动信息不存在"
             return invoke_result_data
-        invoke_result_data.success = act_info_model.update_table("release_date=%s,is_release=%s", "id=%s", [SevenHelper.get_now_datetime(), is_release, act_id])
-        self._delete_act_info_dependency_key(app_id,act_id)
+        modify_date = SevenHelper.get_now_datetime()
+
+        invoke_result_data.success = act_info_model.update_table("release_date=%s,is_release=%s", "id=%s", [modify_date, is_release, act_id])
+        if is_set_cache == True:
+            act_info_dict['is_release'] = is_release
+            act_info_dict['release_date'] = modify_date
+            self._delete_act_info_dependency_key(app_id=app_id, act_id=0)
+            act_info_model.set_cache_dict_by_id(act_id, act_info_dict, DependencyKey.act_info(act_id)) # 更新缓存
+        else:
+            self._delete_act_info_dependency_key(app_id=app_id, act_id=act_id)
         invoke_result_data.data = act_info_dict
         return invoke_result_data
 
@@ -390,7 +437,7 @@ class ActBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        base_info_model = BaseInfoModel(context=self.context)
+        base_info_model = BaseInfoModel(context=self.context, is_auto=True)
         base_info = base_info_model.get_entity()
         if not base_info:
             invoke_result_data.success = False
@@ -428,7 +475,6 @@ class ActBaseModel():
             is_finish = 1
         result_finish_menu_config_json = SevenHelper.json_dumps(result_finish_menu_config_json)
         act_info_model.update_table("finish_menu_config_json=%s,is_finish=%s", "id=%s", [result_finish_menu_config_json, is_finish, act_id])
-        app_id = self.get_app_id()
         if is_finish == 1 and app_id:
             app_info_model = AppInfoModel(context=self.context)
             app_info_model.update_table("is_setting=1", "app_id=%s", [app_id])
@@ -459,5 +505,5 @@ class ActBaseModel():
                     invoke_result_data.error_message="请先中止投放计划"
                     return invoke_result_data
         ActInfoModel(context=self).update_table("is_launch=0", "app_id=%s and id=%s", params=[app_id, act_id])
-        ActBaseModel(context=self)._delete_act_info_dependency_key(app_id, act_id)
+        ActBaseModel(context=self)._delete_act_info_dependency_key(app_id=app_id, act_id=act_id)
         LaunchGoodsModel(context=self).del_entity("app_id=%s and act_id=%s", params=[app_id, act_id])
\ No newline at end of file
