@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2023-03-28 15:07:25
+@LastEditTime: 2025-03-19 17:52:04
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -18,6 +18,8 @@ from seven_cloudapp_frame.models.db_models.product.product_price_model import *
 from seven_cloudapp_frame.models.db_models.tao.tao_login_log_model import *
 from seven_cloudapp_frame.models.db_models.version.version_info_model import *
 from seven_cloudapp_frame.models.db_models.dict.dict_info_model import *
+from seven_cloudapp_frame.models.db_models.app.app_relation_model import *
+from seven_cloudapp_frame.models.db_models.app.app_template_model import *
 
 class AppBaseModel():
     """
@@ -28,15 +30,22 @@ class AppBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def get_app_id(self,store_name):
+    def get_app_id(self, store_name, template_id=""):
         """
         :description: 获取应用标识
         :param store_name:店铺名称
+        :param template_id:模板UD
         :return app_id
         :last_editors: HuangJianYi
         """
         app_id = ""
-        app_info_dict = AppInfoModel(context=self.context).get_cache_dict("store_name=%s", limit="1", field="app_id", params=[store_name])
+        condition_where = ConditionWhere()
+        condition_where.add_condition("store_name=%s")
+        params = [store_name]
+        if template_id:
+            condition_where.add_condition("template_id=%s")
+            params.append(template_id)
+        app_info_dict = AppInfoModel(context=self.context, is_auto=True).get_cache_dict(condition_where.to_string(), limit="1", field="app_id", params=params)
         if app_info_dict:
             app_id = app_info_dict["app_id"]
         return app_id
@@ -50,7 +59,7 @@ class AppBaseModel():
         :return: 返回应用信息
         :last_editors: HuangJianYi
         """
-        app_info_model = AppInfoModel(context=self.context)
+        app_info_model = AppInfoModel(context=self.context, is_auto=True)
         if is_cache:
             dependency_key = DependencyKey.app_info(app_id)
             return app_info_model.get_cache_dict(where="app_id=%s",limit="1", field=field, params=[app_id],dependency_key=dependency_key)
@@ -101,7 +110,7 @@ class AppBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "对不起，请先授权登录"
             return invoke_result_data
-        base_info_dict = BaseInfoModel(context=self.context).get_dict()
+        base_info_dict = BaseInfoModel(context=self.context, is_auto=True).get_dict()
         if not base_info_dict:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -148,7 +157,7 @@ class AppBaseModel():
         data["helper_info"] = helper_info
         data["renew_info"] = renew_info
 
-        product_price_model = ProductPriceModel(context=self.context)
+        product_price_model = ProductPriceModel(context=self.context, is_auto=True)
         now_date = SevenHelper.get_now_datetime()
         product_price = product_price_model.get_cache_entity(where="%s>=begin_time and %s<=end_time and is_release=1",order_by="create_time desc",params=[now_date,now_date])
         base_info = {}
@@ -159,9 +168,10 @@ class AppBaseModel():
         base_info["menu_config_list"] = SevenHelper.json_loads(base_info_dict["menu_config_json"]) if base_info_dict["menu_config_json"] else []
         base_info["product_price_list"] = SevenHelper.json_loads(product_price.content) if product_price else []
         base_info["server_ver"] = base_info_dict["server_ver"]
+        base_info["client_ver"] = base_info_dict["client_ver"]
         base_info["is_force_update"] = base_info_dict["is_force_update"]
-        base_info["is_force_phone"] = share_config.get_value("is_force_phone",True)
-        
+        helper_info["is_force_phone"] = base_info_dict["is_force_phone"]
+
         #配置文件指定账号升级
         test_config = share_config.get_value("test_config",{})
         test_client_ver = test_config.get("client_ver","")
@@ -169,15 +179,43 @@ class AppBaseModel():
             base_info["client_ver"] = test_client_ver
         else:
             #中台指定账号升级
-            version_info = VersionInfoModel(context=self.context).get_entity(where="type_id=1",order_by="id desc")
+            version_info = VersionInfoModel(context=self.context, is_auto=True).get_entity(where="type_id=1",order_by="id desc")
             if version_info:
                 if version_info.update_scope == 2 and version_info.white_lists:
                     white_lists = SevenHelper.json_loads(version_info.white_lists)
+                    if isinstance(white_lists, str):
+                        white_lists = white_lists.split(',')
                     if store_user_nick in white_lists:
                         base_info["client_ver"] = version_info.version_number
+        
+        # 如果存在项目版本号，则替换掉client_ver
+        if base_info_dict["project_ver"]:
+            base_info["client_ver"] = base_info_dict["project_ver"] # 要升级的版本号
+            data["app_info"]["client_now_ver"] = app_info_dict["project_ver"] # 当前版本号
 
         data["base_info"] = base_info
-        invoke_result_data.data =data
+
+
+        
+        # if is_multiple == 1:
+        #     relation_app_ver_list = []
+        #     app_template_model = AppTemplateModel(context=self.context)
+        #     app_template_dict_list = app_template_model.get_dict_list(field="template_id,client_ver,update_function")
+        #     if len(app_template_dict_list) > 0:
+        #         app_info_model = AppInfoModel(context=self.context)
+        #         app_info_dict_list = app_info_model.get_dict_list("store_user_nick=%s", field="template_id,template_ver", params=[store_user_nick])
+        #         for app_template_dict in app_template_dict_list:
+        #             app_info_dict_list = [item for item in app_info_dict_list if item["template_id"] == app_template_dict["template_id"]]
+        #             app_info_dict = app_info_dict_list[0] if len(app_info_dict_list) > 0 else None
+        #             other_app_ver = {}
+        #             other_app_ver["client_now_ver"] =  app_info_dict["template_ver"] if app_info_dict else ""
+        #             other_app_ver["client_ver"] = app_template_dict["client_ver"]
+        #             other_app_ver["update_function"] = app_template_dict["update_function"]
+        #             relation_app_ver_list.append(other_app_ver)
+                
+        #     data["relation_app_ver_list"] = relation_app_ver_list
+
+        invoke_result_data.data = data
         return invoke_result_data
 
     def get_app_info_result(self, user_nick, open_id, access_token, app_key, app_secret, main_user_open_id=""):
@@ -204,9 +242,23 @@ class AppBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "对不起，请先授权登录"
             return invoke_result_data
-
-        app_info_model = AppInfoModel(context=self.context)
-        app_info = app_info_model.get_entity("store_user_nick=%s", params=store_user_nick)
+        
+        base_info = BaseInfoModel(context=self.context, is_auto=True).get_dict(field="client_ver,project_ver")
+        if not base_info:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "对不起，系统异常，请联系管理员"
+            return invoke_result_data
+        
+        condition_where = ConditionWhere()
+        condition_where.add_condition("store_user_nick=%s")
+        params = [store_user_nick]
+        template_id = share_config.get_value("client_template_id")
+        if template_id:
+            condition_where.add_condition("template_id=%s")
+            params.append(template_id)
+        app_info_model = AppInfoModel(context=self.context, is_auto=True)
+        app_info = app_info_model.get_entity(condition_where.to_string(), params=params)
         top_base_model = TopBaseModel(context=self.context)
         invoke_result_data = top_base_model.get_dead_date(store_user_nick, access_token, app_key, app_secret)
         if invoke_result_data.success == False:
@@ -214,7 +266,7 @@ class AppBaseModel():
         dead_date = invoke_result_data.data
         project_code = top_base_model.get_project_code(store_user_nick,access_token,app_key, app_secret)
         now_timestamp = TimeHelper.datetime_to_timestamp(datetime.datetime.strptime(TimeHelper.get_now_format_time('%Y-%m-%d 00:00:00'), '%Y-%m-%d %H:%M:%S'))
-        login_log = TaoLoginLogModel(context=self.context).get_entity("open_id=%s", order_by="id desc", params=open_id)
+        login_log = TaoLoginLogModel(context=self.context, is_auto=True).get_entity("open_id=%s", order_by="id desc", params=open_id)
         if app_info:
             if dead_date != "expire":
                 app_info.expiration_date = dead_date
@@ -223,10 +275,12 @@ class AppBaseModel():
             invoke_result_data = top_base_model.get_shop(access_token, app_key, app_secret)
             if invoke_result_data.success == True:
                 app_info.access_token = access_token
+                app_info.store_name = invoke_result_data.data['shop_seller_get_response']['shop']['title']
+                app_info.store_icon = invoke_result_data.data['shop_seller_get_response']['shop']['pic_path']
             if app_info.main_user_open_id != main_user_open_id:
                 app_info.main_user_open_id = main_user_open_id
-            app_info_model.update_entity(app_info,"expiration_date,project_code,access_token,main_user_open_id")
-            app_info_model.delete_dependency_key(f"app_info:appid_{app_info.app_id}")
+            app_info_model.update_entity(app_info,"expiration_date,project_code,access_token,main_user_open_id,store_name,store_icon")
+            app_info_model.delete_dependency_key(DependencyKey.app_info(app_info.app_id))
 
             app_info.user_nick = user_nick
             app_info.dead_date = dead_date
@@ -235,14 +289,13 @@ class AppBaseModel():
                 dead_date_timestamp = TimeHelper.datetime_to_timestamp(datetime.datetime.strptime(app_info.dead_date, '%Y-%m-%d %H:%M:%S'))
                 app_info.surplus_day = int(int(abs(dead_date_timestamp - now_timestamp)) / 24 / 3600)
             app_info.last_login_date = login_log.modify_date if login_log else ""
+            app_info.template_ver = app_info.template_ver if not base_info["project_ver"] else app_info.project_ver
             invoke_result_data.data = app_info
             return invoke_result_data
         else:
             app_info = AppInfo()
             app_info.access_token = access_token
-            base_info = BaseInfoModel(context=self.context).get_dict(field="client_ver")
-
-            app_info.template_ver = base_info["client_ver"]
+            app_info.template_ver = base_info["client_ver"] if not base_info["project_ver"] else base_info["project_ver"]
             app_info.user_nick = user_nick
             app_info.dead_date = dead_date
             app_info.project_code = project_code
@@ -252,7 +305,7 @@ class AppBaseModel():
             app_info.last_login_date = login_log.create_date if login_log else ""
             invoke_result_data.data = app_info
             return invoke_result_data
-    
+
     def get_online_url(self, act_id, app_id, module_id=0, act_type=0):
         """
         :description: 获取online_url
@@ -275,7 +328,7 @@ class AppBaseModel():
         query = CodingHelper.url_encode(f"actid={act_id}")
         if module_id > 0:
             query = CodingHelper.url_encode(f"actid={act_id}&module_id={module_id}")
-        online_url = f"https://m.duanqu.com/?_ariver_appid={app_id}{page_index}&query={query}"
+        online_url = f"https://m.duanqu.com/?_ariver_appid={app_id}&_mp_code=tb&transition=present{page_index}&query={query}"
         return online_url
 
     def get_live_url(self, app_id):
@@ -390,9 +443,8 @@ class AppBaseModel():
             params.append(dict_type)
         condition_where.add_condition("is_release=1")
 
-        dict_info_model = DictInfoModel(context=self.context)
         if is_cache == True:
-            page_list, total = dict_info_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by,params=params,dependency_key=DependencyKey.dict_info_list(parent_id,dict_type),cache_expire=600)
+            page_list, total = DictInfoModel(context=self.context, is_auto=True).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by,params=params,dependency_key=DependencyKey.dict_info_list(parent_id,dict_type),cache_expire=600)
         else:
-            page_list, total = dict_info_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by,params=params)
+            page_list, total = DictInfoModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by,params=params)
         return page_list, total
\ No newline at end of file
