@@ -2,12 +2,13 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-26 10:22:44
-@LastEditTime: 2023-02-16 17:31:18
+@LastEditTime: 2024-01-31 10:47:43
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.libs.customize.safe_helper import SafeHelper
 from seven_cloudapp_frame.models.seven_model import PageInfo
 from seven_cloudapp_frame.models.db_models.cms.cms_info_model import *
 
@@ -15,10 +16,12 @@ class CmsBaseModel():
     """
     :description: 资讯相关业务模型 用于后台或者中台案例和教程等配置信息、字典表用于管理标签、分类等信息
     """
-    def __init__(self,context=None,logging_error=None,logging_info=None):
+
+    def __init__(self, context=None, logging_error=None, logging_info=None):
         self.context = context
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
+        self.db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_cms","redis_cms")
 
     def _delete_cms_info_dependency_key(self, place_id, delay_delete_time=0.01):
         """
@@ -71,7 +74,7 @@ class CmsBaseModel():
         cms_info_model = CmsInfoModel(context=self.context)
         if cms_id > 0:
             cms_info = cms_info_model.get_entity_by_id(cms_id)
-            if not cms_info or (app_id and cms_info.app_id != app_id):
+            if not cms_info or SafeHelper.authenticat_app_id(cms_info.app_id, app_id) == False:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = "信息不存在"
@@ -159,7 +162,7 @@ class CmsBaseModel():
         invoke_result_data = InvokeResultData()
         cms_info_model = CmsInfoModel(context=self.context)
         cms_info_dict = cms_info_model.get_dict_by_id(cms_id)
-        if not cms_info_dict or cms_info_dict["app_id"] != app_id:
+        if not cms_info_dict or SafeHelper.authenticat_app_id(cms_info_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "资讯信息不存在"
@@ -181,7 +184,7 @@ class CmsBaseModel():
         invoke_result_data = InvokeResultData()
         cms_info_model = CmsInfoModel(context=self.context)
         cms_info_dict = cms_info_model.get_dict_by_id(cms_id)
-        if not cms_info_dict or cms_info_dict["app_id"] != app_id:
+        if not cms_info_dict or SafeHelper.authenticat_app_id(cms_info_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "资讯信息不存在"
@@ -217,14 +220,13 @@ class CmsBaseModel():
             condition+=" and act_id=%s"
             params.append(act_id)
 
-        cms_info_model = CmsInfoModel(context=self.context)
         if is_cache == True:
-            page_list = cms_info_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=DependencyKey.cms_info_list(place_id),cache_expire=600,page_count_mode=page_count_mode)
+            page_list =  CmsInfoModel(context=self.context, is_auto=True).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params, dependency_key=DependencyKey.cms_info_list(place_id), cache_expire=600, page_count_mode=page_count_mode)
         else:
-            page_list = cms_info_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,page_count_mode=page_count_mode)
-        
+            page_list = CmsInfoModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,page_count_mode=page_count_mode)
+
         return page_list
-    
+
     def get_cms_info_list_v2(self, place_id, page_size, page_index, order_by="id desc", field="*", condition=None, params=None, is_cache=True, page_count_mode="total"):
         """
         :description: 位置信息列表
@@ -248,10 +250,9 @@ class CmsBaseModel():
             condition_where.add_condition(condition)
             params_list.extend(params)
 
-        cms_info_model = CmsInfoModel(context=self.context)
         if is_cache == True:
-            page_list = cms_info_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by,params=params_list,dependency_key=DependencyKey.cms_info_list(place_id),cache_expire=600,page_count_mode=page_count_mode)
+            page_list = CmsInfoModel(context=self.context, is_auto=True).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=DependencyKey.cms_info_list(place_id), cache_expire=600, page_count_mode=page_count_mode)
         else:
-            page_list = cms_info_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by,params=params_list,page_count_mode=page_count_mode)
-        
+            page_list =  CmsInfoModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by,params=params_list,page_count_mode=page_count_mode)
+
         return page_list
\ No newline at end of file
