@@ -2,12 +2,12 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2023-03-23 18:44:52
+@LastEditTime: 2024-11-13 10:15:19
 @LastEditors: HuangJianYi
 @Description: 
 """
 import threading, multiprocessing
-from seven_framework.console.base_console import *
+from seven_cloudapp_frame.libs.common.frame_console import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.db_models.asset.asset_inventory_model import *
 from seven_cloudapp_frame.models.db_models.asset.asset_warn_notice_model import *
@@ -18,6 +18,14 @@ class AssetConsoleModel():
     """
     :description: 资产控制台业务模型
     """
+    def __init__(self):
+        """
+        :description: 初始化
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        self.db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_asset","redis_asset")
+
     def console_asset(self, mod_count=1):
         """
         :description: 控制台资产预警
@@ -35,6 +43,7 @@ class AssetConsoleModel():
         t = threading.Thread(target=self._process_asset_intercept_queue, args=[])
         t.start()
 
+
     def _process_onlyid_warn(self):
         """
         :description: 处理唯一值并发预警
@@ -44,8 +53,9 @@ class AssetConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
+                heart_beat_monitor("_process_onlyid_warn")
                 asset_warn_notice_model = AssetWarnNoticeModel()
-                redis_init = SevenHelper.redis_init()
+                redis_init = SevenHelper.redis_init(config_dict=self.redis_config_dict)
                 hash_name_1 = f"warn_handler_list_{str(SevenHelper.get_now_int(fmt='%Y%m%d'))}"
                 hkeys = redis_init.hkeys(hash_name_1)
                 if len(hkeys)<=0:
@@ -90,6 +100,7 @@ class AssetConsoleModel():
             except Exception as ex:
                 time.sleep(5)
 
+
     def _push_warn_notice(self):
         """
         :description: 推送预警通知到消息系统
@@ -99,9 +110,10 @@ class AssetConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
+                heart_beat_monitor("_push_warn_notice")
                 asset_warn_notice_model = AssetWarnNoticeModel()
                 redis_init = SevenHelper.redis_init(config_dict=config.get_value("warn_redis"))
-                warn_notice_list = asset_warn_notice_model.get_list("is_notice=0 and ascription_type=1",order_by="create_date asc",limit="50")
+                warn_notice_list = asset_warn_notice_model.get_list("is_notice=0 and ascription_type=1",order_by="create_date asc",limit="200")
                 if len(warn_notice_list) > 0:
                     for warn_notice in warn_notice_list:
                         try:
@@ -124,6 +136,7 @@ class AssetConsoleModel():
             except Exception as ex:
                 time.sleep(5)
 
+
     def _process_asset_inventory_warn(self, mod_value, mod_count):
         """
         :description: 处理资产每日进销存是否对等预警
@@ -136,14 +149,15 @@ class AssetConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
+                heart_beat_monitor(f"_process_asset_inventory_warn_{mod_value}")
                 asset_inventory_model = AssetInventoryModel()
                 asset_warn_notice_model = AssetWarnNoticeModel()
                 now_date = TimeHelper.get_now_format_time()
                 now_day_int = SevenHelper.get_now_day_int()
                 if mod_count == 1:
-                    asset_inventory_list = asset_inventory_model.get_list(f"create_day={now_day_int} and process_count=0", order_by="create_date asc", limit="100")
+                    asset_inventory_list = asset_inventory_model.get_list(f"create_day={now_day_int} and process_count=0", order_by="create_date asc", limit="200")
                 else:
-                    asset_inventory_list = asset_inventory_model.get_list(f"create_day={now_day_int} and process_count=0 and MOD(user_id,{mod_count})={mod_value}", order_by="create_date asc", limit="100")
+                    asset_inventory_list = asset_inventory_model.get_list(f"create_day={now_day_int} and process_count=0 and MOD(user_id,{mod_count})={mod_value}", order_by="create_date asc", limit="200")
                 if len(asset_inventory_list) > 0:
                     for asset_inventory in asset_inventory_list:
                         try:
@@ -186,6 +200,7 @@ class AssetConsoleModel():
             except Exception as ex:
                 time.sleep(5)
 
+
     def _process_asset_inventory_queue(self):
         """
         :description: 处理资产队列入进销存
@@ -195,9 +210,10 @@ class AssetConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
-                redis_init = SevenHelper.redis_init()
+                heart_beat_monitor("_process_asset_inventory_queue")
+                redis_init = SevenHelper.redis_init(config_dict=self.redis_config_dict)
                 asset_inventory_model = AssetInventoryModel()
-                asset_queue_json = redis_init.lpop(f"asset_queue_list")
+                asset_queue_json = redis_init.rpoplpush(f"asset_queue_list", f"asset_queue_list_wait")
                 if not asset_queue_json:
                     time.sleep(1)
                     continue
@@ -250,10 +266,11 @@ class AssetConsoleModel():
                         asset_inventory_model.update_table(asset_inventory_update_sql, "id=%s", params=[old_asset_inventory_id])
                     else:
                         asset_inventory_model.add_entity(asset_inventory)
+                    redis_init.lrem(f"asset_queue_list_wait",1,asset_queue_json)
                 except Exception as ex:
                     asset_queue_dict["process_count"] += 1
                     if asset_queue_dict["process_count"] <= 10:
-                        redis_init.rpush(f"asset_queue_list", SevenHelper.json_dumps(asset_queue_dict))
+                        redis_init.lpush(f"asset_queue_list", SevenHelper.json_dumps(asset_queue_dict))
                     else:
                         logger_error.error(f"资产队列异常,json串:{SevenHelper.json_dumps(asset_queue_dict)},ex:{traceback.format_exc()}")
                     continue
@@ -261,6 +278,7 @@ class AssetConsoleModel():
                 logger_error.error(f"资产队列异常,ex:{traceback.format_exc()}")
                 time.sleep(5)
 
+
     def _process_asset_intercept_queue(self):
         """
         :description: 处理资产拦截队列入库
@@ -270,7 +288,8 @@ class AssetConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
-                redis_init = SevenHelper.redis_init()
+                heart_beat_monitor("_process_asset_intercept_queue")
+                redis_init = SevenHelper.redis_init(config_dict=self.redis_config_dict)
                 asset_warn_notice_model = AssetWarnNoticeModel()
                 queue_json = redis_init.lpop(f"asset_intercept_queue_list")
                 if not queue_json:
