@@ -2,14 +2,14 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-24 09:36:39
-@LastEditTime: 2023-02-08 10:04:51
+@LastEditTime: 2025-03-10 15:54:03
 @LastEditors: HuangJianYi
 @Description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流) 需在配置文件加 armor_url 和 armor_sign_key对应的值
 """
 
 import threading, multiprocessing
 from seven_framework import *
-from seven_framework.console.base_console import *
+from seven_cloudapp_frame.libs.common.frame_console import *
 from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
@@ -23,30 +23,39 @@ class ErpConsoleModel():
     """
     :description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流)
     """
+    def __init__(self):
+        """
+        :description: 初始化
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        self.db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_order","redis_order")
 
-    def console_erp(self, mod_count=1, prize_roster_sub_table=None):
+    def console_erp(self, mod_count=1, prize_roster_model=None, process_type=1):
         """
         :description: 控制台推送订单和回写物流
         :param mod_count: 单表队列数
-        :param prize_roster_sub_table: 中奖记录扩展表名
+        :param prize_roster_model: 中奖记录model实例化
+        :param process_type: 处理方式（1.redis 2.api） 如果是淘系使用redis处理方式非淘系用api模式
         :return: 
         :last_editors: HuangJianYi
         """
         for i in range(mod_count):
 
-            t = threading.Thread(target=self.process_order_push, args=[i, mod_count, True, prize_roster_sub_table])
+            t = threading.Thread(target=self.process_order_push, args=[i, mod_count, True, prize_roster_model])
             t.start()
 
-            j = threading.Thread(target=self.process_order_pull, args=[i, mod_count])
+            j = threading.Thread(target=self.process_order_pull, args=[i, mod_count, process_type, prize_roster_model])
             j.start()
 
-    def process_order_push(self, mod_value, mod_count, is_loop=True, prize_roster_sub_table=""):
+    def process_order_push(self, mod_value, mod_count, is_loop=True, prize_roster_model=None, decrypt_field_list=["real_name","telephone","province","city","county","street","address"]):
         """
         :description: 处理订单推送到遁甲系统
         :param mod_value: 当前队列值
         :param mod_count: 队列数
         :param is_loop: 是否循环
-        :param prize_roster_sub_table: 中奖记录扩展表名
+        :param prize_roster_model: 中奖记录model实例化
+        :param decrypt_field_list: 需要解密的字段列表
         :return: 
         :last_editors: HuangJianYi
         """
@@ -58,29 +67,33 @@ class ErpConsoleModel():
 
         while True:
             try:
-                time.sleep(0.1)
+                time.sleep(1)
+                heart_beat_monitor("process_order_push")
                 erp_relation_model = ErpRelationModel()
                 frame_base_model = FrameBaseModel()
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
-                    erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
+                    erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="200", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
                 else:
-                    erp_relation_list = erp_relation_model.get_dict_list("MOD(id,%s)=%s and is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="100", params=[mod_count, mod_value, TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
+                    erp_relation_list = erp_relation_model.get_dict_list("MOD(id,%s)=%s and is_release=1 and %s>sync_date and start_date<=%s and end_date>=%s", order_by="sync_date asc", limit="200", params=[mod_count, mod_value, TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
                 if len(erp_relation_list) > 0:
                     for erp_relation_dict in erp_relation_list:
                         try:
                             erp_relation_model.update_table("sync_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), erp_relation_dict["id"]])
-                            prize_order_model = PrizeOrderModel(sub_table=frame_base_model.get_business_sub_table("prize_order_tb", {"app_id": erp_relation_dict["app_id"]}))
-                            if not prize_roster_sub_table:
-                                prize_roster_sub_table = frame_base_model.get_business_sub_table("prize_roster_tb", {"app_id": erp_relation_dict["app_id"]})
-                            prize_roster_model = PrizeRosterModel(sub_table=prize_roster_sub_table)
-                            condition = "app_id=%s and order_status=0 and sync_status=0"
-                            params = [erp_relation_dict["app_id"]]
+                            prize_order_model = PrizeOrderModel().set_sub_table(erp_relation_dict["app_id"])
+                            if not prize_roster_model:
+                                prize_roster_model = PrizeRosterModel().set_sub_table(erp_relation_dict["app_id"])
+                            condition = "app_id=%s and order_status=0 and sync_status=0 and create_date<%s"
+                            params = [erp_relation_dict["app_id"], TimeHelper.add_minutes_by_format_time(minute=-5)]
                             record_count = prize_order_model.get_total(condition, params=params)
                             page_count = SevenHelper.get_page_count(page_size, record_count)
                             for page_index in range(page_count):
-                                prize_order_list_dict = prize_order_model.get_dict_list(condition, "", order_by="id asc", limit=str(page_size), field="*", params=params)
-                                for prize_order_dict in prize_order_list_dict:
+                                prize_order_dict_list = prize_order_model.get_dict_list(condition, "", order_by="id asc", limit=str(page_size), field="*", params=params)
+                                for prize_order_dict in prize_order_dict_list:
+                                    prize_order_dict, status = frame_base_model.sensitive_decrypt(prize_order_dict, decrypt_field_list)
+                                    if status == 0:
+                                        prize_order_model.update_table("sync_status=2,sync_date=%s,sync_result=%s", "id=%s", params=[TimeHelper.get_now_format_time(), f"敏感字段解密失败,ex:{traceback.format_exc()}", prize_order_dict["id"]])
+                                        continue
                                     request_params = self.compose_push_request_params(sign_key, erp_relation_dict, prize_order_dict, prize_roster_model)
                                     if request_params["goods"]:
                                         result = HTTPHelper.post(push_url, request_params, {"Content-Type": "application/json"})
@@ -165,35 +178,37 @@ class ErpConsoleModel():
         data["sign"] = SignHelper.params_sign_md5(data, sign_key)
         return data
 
-    def process_order_pull(self, mod_value, mod_count, process_type=1):
+    def process_order_pull(self, mod_value, mod_count, process_type=1, prize_roster_model=None):
         """
         :description: 处理订单拉取，同步物流信息
         :param mod_value: 当前队列值
         :param mod_count: 队列数
         :param process_type: 处理方式（1.redis 2.api） 如果是淘系使用redis处理方式非淘系用api模式
+        :param prize_roster_model: 中奖记录model实例化
         :return: 
         :last_editors: HuangJianYi
         """
-        erp_relation_model = ErpRelationModel()
-        erp_redis_init = SevenHelper.redis_init(config_dict=config.get_value("erp_redis"))
-
         print(f"{TimeHelper.get_now_format_time()} 拉取订单队列{mod_value}启动")
         #获取产品id
         project_name = config.get_value("project_name", 0)
         while True:
             try:
-                time.sleep(0.1)
-                frame_base_model = FrameBaseModel()
+                time.sleep(1)
+                heart_beat_monitor("process_order_pull")
+                erp_relation_model = ErpRelationModel()
+                erp_redis_init = SevenHelper.redis_init(config_dict=config.get_value("erp_redis"))
+                # frame_base_model = FrameBaseModel()
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
-                    erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="100", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
+                    erp_relation_list = erp_relation_model.get_dict_list("is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="200", params=[TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
                 else:
-                    erp_relation_list = erp_relation_model.get_dict_list("MOD(id,%s)=%s and is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="100", params=[mod_count, mod_value, TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
+                    erp_relation_list = erp_relation_model.get_dict_list("MOD(id,%s)=%s and is_release=1 and %s>return_date and start_date<=%s and end_date>=%s", order_by="return_date asc", limit="200", params=[mod_count, mod_value, TimeHelper.add_minutes_by_format_time(minute=-10), now_date, now_date])
                 if len(erp_relation_list) > 0:
                     for erp_relation_dict in erp_relation_list:
                         try:
-                            prize_order_model = PrizeOrderModel(sub_table=frame_base_model.get_business_sub_table("prize_order_tb", {"app_id": erp_relation_dict["app_id"]}))
-                            prize_roster_model = PrizeRosterModel(sub_table=frame_base_model.get_business_sub_table("prize_roster_tb", {"app_id": erp_relation_dict["app_id"]}))
+                            prize_order_model = PrizeOrderModel().set_sub_table(erp_relation_dict["app_id"])
+                            if not prize_roster_model:
+                                prize_roster_model = PrizeRosterModel().set_sub_table(erp_relation_dict["app_id"])
                             erp_relation_model.update_table("return_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), erp_relation_dict["id"]])
                             if process_type == 1:
                                 key = "order_" + project_name + "_" + erp_relation_dict["app_id"]
@@ -235,9 +250,9 @@ class ErpConsoleModel():
                                 record_count = prize_order_model.get_total(condition, params=params)
                                 page_count = SevenHelper.get_page_count(page_size, record_count)
                                 for page_index in range(0, page_count):
-                                    prize_order_list_dict, total = prize_order_model.get_dict_page_list("id,order_no", page_index, page_size, condition, "", "id asc", params)
-                                    if total > 0:
-                                        order_no_list = [prize_order['order_no'] for prize_order in prize_order_list_dict]
+                                    prize_order_dict_list = prize_order_model.get_dict_page_list("id,order_no", page_index, page_size, condition, "", "id asc", params, page_count_mode="none")
+                                    if prize_order_dict_list and len(prize_order_dict_list) > 0:
+                                        order_no_list = [prize_order['order_no'] for prize_order in prize_order_dict_list]
                                         data = {}
                                         data["mini_order"] = ",".join(order_no_list)
                                         data["timestamp"] = TimeHelper.get_now_timestamp(True)
@@ -260,14 +275,14 @@ class ErpConsoleModel():
                                                     if order_status == 1:
                                                         delivery_time = TimeHelper.timestamp_to_datetime(delivery_time)
                                                         update_sql = "order_status=1,express_no=%s,express_company=%s,deliver_date=%s,sync_date=%s"
-                                                        params = [express_no, express_company, delivery_time, modify_date, order_no]
-                                                        prize_order_model.update_table(update_sql, "order_no=%s", params=params)
+                                                        update_params = [express_no, express_company, delivery_time, modify_date, order_no]
+                                                        prize_order_model.update_table(update_sql, "order_no=%s", params=update_params)
                                                         prize_roster_model.update_table("logistics_status=1", "app_id=%s and order_no=%s", params=[erp_relation_dict["app_id"], order_no])
                                                         self.process_order_pull_executed(data)
                                                     else:
                                                         update_sql = "sync_status=2,sync_date=%s,sync_result=%s"
-                                                        params = [modify_date, "拉取订单失败", order_no]
-                                                        prize_order_model.update_table(update_sql, "order_no=%s", params=params)
+                                                        update_params = [modify_date, "拉取订单失败", order_no]
+                                                        prize_order_model.update_table(update_sql, "order_no=%s", params=update_params)
                         except Exception as ex:
                             logger_error.error(f"拉取订单队列{mod_value}异常,json串:{SevenHelper.json_dumps(erp_relation_dict)},ex:{traceback.format_exc()}")
                             continue
