@@ -7,7 +7,7 @@
 @Description: 
 """
 import threading, multiprocessing
-from seven_framework.console.base_console import *
+from seven_cloudapp_frame.libs.common.frame_console import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.models.top_base_model import *
@@ -64,6 +64,7 @@ class LaunchConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
+                heart_beat_monitor("process_launch_goods")
                 redis_init = RedisExHelper.init()
                 act_id = redis_init.lindex("queue_async_lauch",index=0)
                 app_key = share_config.get_value("app_key")
