@@ -2,12 +2,12 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2023-03-01 14:54:31
+@LastEditTime: 2025-05-07 09:51:55
 @LastEditors: HuangJianYi
 @Description: 
 """
 import threading, multiprocessing
-from seven_framework.console.base_console import *
+from seven_cloudapp_frame.libs.common.frame_console import *
 from seven_cloudapp_frame.models.seven_model import InvokeResultData
 from seven_cloudapp_frame.models.frame_base_model import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
@@ -24,6 +24,14 @@ class StatConsoleModel():
     """
     :description: 统计控制台业务模型
     """
+    def __init__(self):
+        """
+        :description: 初始化
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        self.db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_stat","redis_stat")
+
     def console_stat_queue(self, mod_count=1):
         """
         :description: 控制台统计上报
@@ -48,6 +56,7 @@ class StatConsoleModel():
             clea_data_work.start_hours = 2
             clea_data_work.end_hours = 4
             clea_data_work.sleep_time = 3600
+            clea_data_work.db_connect_key = self.db_connect_key
             clea_data_work.start_work("清理统计流水数据作业")
 
         is_process_stat_user = stat_config.get("is_process_stat_user",False)
@@ -60,6 +69,7 @@ class StatConsoleModel():
             stat_user_data_work.start_hours = 2
             stat_user_data_work.end_hours = 4
             stat_user_data_work.sleep_time = 3600
+            stat_user_data_work.db_connect_key = self.db_connect_key
             stat_user_data_work.start_work("处理统计用户数据作业")
 
 
@@ -75,19 +85,21 @@ class StatConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
-                db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
+                heart_beat_monitor(f"_process_stat_queue_{mod_value}")
+                db_transaction = DbTransaction(db_config_dict=config.get_value(self.db_connect_key))
                 stat_queue_model = StatQueueModel(db_transaction=db_transaction)
-                stat_orm_model = StatOrmModel()
+                stat_orm_model = StatOrmModel(is_auto=True)
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
-                    stat_queue_list = stat_queue_model.get_list(f"process_count<10 and '{now_date}'>process_date", order_by="process_date asc", limit="100")
+                    # 为了避免删数据导致空表进行主键重置，所以默认不删除第一条数据
+                    stat_queue_list = stat_queue_model.get_list(f"process_count<10 and '{now_date}'>process_date and id>1", order_by="process_date asc", limit="200")
                 else:
-                    stat_queue_list = stat_queue_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and process_count<10 and '{now_date}'>process_date", order_by="process_date asc", limit="100")
+                    stat_queue_list = stat_queue_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and process_count<10 and '{now_date}'>process_date and id>1", order_by="process_date asc", limit="200")
                 if len(stat_queue_list) > 0:
                     for stat_queue in stat_queue_list:
                         try:
                             stat_report_model = StatReportModel(db_transaction=db_transaction)
-                            stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_queue.key_name])
+                            stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s and object_id=%s) or (act_id=0 and module_id=0 and object_id='')) and key_name=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_queue.object_id, stat_queue.key_name])
                             if not stat_orm:
                                 stat_queue_model.del_entity("id=%s", params=[stat_queue.id])
                                 continue
@@ -95,13 +107,13 @@ class StatConsoleModel():
                             create_day_int = int(create_date.strftime('%Y%m%d'))
                             create_month_int = int(create_date.strftime('%Y%m'))
                             create_year_int = int(create_date.strftime('%Y'))
-                            stat_log_model = StatLogModel(sub_table=FrameBaseModel().get_business_sub_table("stat_log_tb", {"app_id": stat_queue.app_id}), db_transaction=db_transaction)
+                            stat_log_model = StatLogModel(db_transaction=db_transaction).set_sub_table(stat_queue.app_id)
                             is_add = True
                             if stat_orm.repeat_type > 0:
                                 if stat_orm.repeat_type == 2:
-                                    stat_log_dict = stat_log_model.get_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", field="id", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id])
+                                    stat_log_dict = stat_log_model.get_cache_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and object_id=%s", field="id", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, stat_queue.object_id])
                                 else:
-                                    stat_log_dict = stat_log_model.get_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", field="id", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, create_day_int])
+                                    stat_log_dict = stat_log_model.get_cache_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s and object_id=%s", field="id", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, create_day_int, stat_queue.object_id])
                                 if stat_log_dict:
                                     is_add = False
 
@@ -117,8 +129,8 @@ class StatConsoleModel():
                             stat_log.create_month = create_month_int
                             stat_log.create_date = create_date
 
-                            stat_report_condition = "act_id=%s and module_id=%s and key_name=%s and create_day=%s"
-                            stat_report_param = [stat_queue.act_id, stat_queue.module_id, stat_queue.key_name, create_day_int]
+                            stat_report_condition = "act_id=%s and module_id=%s and object_id=%s and key_name=%s and create_day=%s"
+                            stat_report_param = [stat_queue.act_id, stat_queue.module_id, stat_queue.object_id, stat_queue.key_name, create_day_int]
                             stat_report_dict = stat_report_model.get_dict(stat_report_condition, params=stat_report_param)
 
                             db_transaction.begin_transaction()
@@ -128,6 +140,7 @@ class StatConsoleModel():
                                     stat_report.app_id = stat_queue.app_id
                                     stat_report.act_id = stat_queue.act_id
                                     stat_report.module_id = stat_queue.module_id
+                                    stat_report.object_id = stat_queue.object_id
                                     stat_report.key_name = stat_queue.key_name
                                     stat_report.key_value = stat_queue.key_value
                                     stat_report.create_date = create_date
@@ -158,6 +171,7 @@ class StatConsoleModel():
                 logger_error.error(f"统计队列{mod_value}异常,ex:{traceback.format_exc()}")
                 time.sleep(5)
 
+
     def _process_redis_stat_queue(self, mod_value):
         """
         :description: 处理redis统计队列
@@ -170,32 +184,34 @@ class StatConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
-                db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-                stat_orm_model = StatOrmModel()
-                redis_init = SevenHelper.redis_init()
+                heart_beat_monitor(f"_process_redis_stat_queue_{mod_value}")
+                redis_init = SevenHelper.redis_init(config_dict=self.redis_config_dict)
                 redis_stat_key = f"stat_queue_list:{mod_value}"
-                stat_queue_json = redis_init.lindex(redis_stat_key, index=0)
+                check_redis_stat_key = f"stat_queue_list:check:{mod_value}"
+                stat_queue_json = redis_init.rpoplpush(redis_stat_key, check_redis_stat_key)
                 if not stat_queue_json:
                     time.sleep(1)
                     continue
                 try:
                     stat_queue_dict = SevenHelper.json_loads(stat_queue_json)
+                    db_transaction = DbTransaction(db_config_dict=config.get_value(self.db_connect_key))
+                    stat_orm_model = StatOrmModel(is_auto=True)
                     stat_report_model = StatReportModel(db_transaction=db_transaction)
-                    stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"]])
+                    stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s and object_id=%s) or (act_id=0 and module_id=0 and object_id='')) and key_name=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict.get("object_id", ''), stat_queue_dict["key_name"]])
                     if not stat_orm:
-                        redis_init.lpop(redis_stat_key)
+                        redis_init.lrem(check_redis_stat_key, 1, stat_queue_json)
                         continue
                     create_date = TimeHelper.format_time_to_datetime(stat_queue_dict["create_date"])
                     create_day_int = int(create_date.strftime('%Y%m%d'))
                     create_month_int = int(create_date.strftime('%Y%m'))
                     create_year_int = int(create_date.strftime('%Y'))
-                    stat_log_model = StatLogModel(sub_table=FrameBaseModel().get_business_sub_table("stat_log_tb", {"app_id": stat_queue_dict["app_id"]}), db_transaction=db_transaction)
+                    stat_log_model = StatLogModel(db_transaction=db_transaction).set_sub_table(stat_queue_dict["app_id"])
                     is_add = True
                     if stat_orm.repeat_type > 0:
                         if stat_orm.repeat_type == 2:
-                            stat_log_dict = stat_log_model.get_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", field="id", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"]])
+                            stat_log_dict = stat_log_model.get_cache_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and object_id=%s", field="id", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"], stat_queue_dict.get("object_id",'')])
                         else:
-                            stat_log_dict = stat_log_model.get_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", field="id", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"], create_day_int])
+                            stat_log_dict = stat_log_model.get_cache_dict("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s and object_id=%s", field="id", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_orm.id, stat_queue_dict["user_id"], create_day_int, stat_queue_dict.get("object_id",'')])
                         if stat_log_dict:
                             is_add = False
 
@@ -203,6 +219,7 @@ class StatConsoleModel():
                     stat_log.app_id = stat_queue_dict["app_id"]
                     stat_log.act_id = stat_queue_dict["act_id"]
                     stat_log.module_id = stat_queue_dict["module_id"]
+                    stat_log.object_id = stat_queue_dict.get("object_id",'')
                     stat_log.orm_id = stat_orm.id
                     stat_log.user_id = stat_queue_dict["user_id"]
                     stat_log.open_id = stat_queue_dict["open_id"]
@@ -211,42 +228,40 @@ class StatConsoleModel():
                     stat_log.create_month = create_month_int
                     stat_log.create_date = create_date
 
-                    stat_report_condition = "act_id=%s and module_id=%s and key_name=%s and create_day=%s"
-                    stat_report_param = [stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"], create_day_int]
-                    stat_report_dict = stat_report_model.get_dict(stat_report_condition, params=stat_report_param)
+                    stat_report = StatReport()
+                    stat_report.app_id = stat_queue_dict["app_id"]
+                    stat_report.act_id = stat_queue_dict["act_id"]
+                    stat_report.module_id = stat_queue_dict["module_id"]
+                    stat_report.object_id = stat_queue_dict.get("object_id",'')
+                    stat_report.key_name = stat_queue_dict["key_name"]
+                    stat_report.key_value = stat_queue_dict["key_value"]
+                    stat_report.create_date = create_date
+                    stat_report.create_year = create_year_int
+                    stat_report.create_month = create_month_int
+                    stat_report.create_day = create_day_int
 
                     if is_add:
                         db_transaction.begin_transaction()
-                        if not stat_report_dict:
-                            stat_report = StatReport()
-                            stat_report.app_id = stat_queue_dict["app_id"]
-                            stat_report.act_id = stat_queue_dict["act_id"]
-                            stat_report.module_id = stat_queue_dict["module_id"]
-                            stat_report.key_name = stat_queue_dict["key_name"]
-                            stat_report.key_value = stat_queue_dict["key_value"]
-                            stat_report.create_date = create_date
-                            stat_report.create_year = create_year_int
-                            stat_report.create_month = create_month_int
-                            stat_report.create_day = create_day_int
-                            stat_report_model.add_entity(stat_report)
-                        else:
-                            key_value = stat_queue_dict["key_value"]
-                            stat_report_model.update_table(f"key_value=key_value+{key_value}", stat_report_condition, params=stat_report_param)
+                        stat_report_model.add_update_entity(stat_report, update_sql=f"key_value=key_value+{stat_queue_dict['key_value']}")
                         stat_log_model.add_entity(stat_log)
-                        result,message = db_transaction.commit_transaction(True)
+                        result, message = db_transaction.commit_transaction(True)
                         if result == False:
                             raise Exception("执行事务失败", message)
 
-                    redis_init.lpop(redis_stat_key)
+                    redis_init.lrem(check_redis_stat_key, 1, stat_queue_json)
 
                 except Exception as ex:
-                    logger_error.error(f"统计队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue_dict)},ex:{traceback.format_exc()}")
+                    if "Duplicate entry" not in traceback.format_exc():
+                        redis_init.lpush(redis_stat_key, stat_queue_json)
+                        redis_init.lrem(check_redis_stat_key, 1, stat_queue_json)
+                        logger_error.error(f"统计队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue_dict)},ex:{traceback.format_exc()}")
                     continue
 
             except Exception as ex:
                 logger_error.error(f"统计队列{mod_value}异常,ex:{traceback.format_exc()}")
                 time.sleep(5)
 
+
     def _process_redis_stat_user_queue(self, mod_value):
         """
         :description: 处理redis统计用户队列
@@ -259,16 +274,18 @@ class StatConsoleModel():
         while True:
             try:
                 time.sleep(0.1)
-                db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
-                redis_init = SevenHelper.redis_init()
+                heart_beat_monitor(f"_process_redis_stat_user_queue_{mod_value}")
+                db_transaction = DbTransaction(db_config_dict=config.get_value(self.db_connect_key))
+                redis_init = SevenHelper.redis_init(config_dict=self.redis_config_dict)
                 redis_stat_key = f"stat_user_queue_list:{mod_value}"
-                stat_queue_json = redis_init.lindex(redis_stat_key, index=0)
+                check_redis_stat_key = f"stat_user_queue_list:check:{mod_value}"
+                stat_queue_json = redis_init.rpoplpush(redis_stat_key, check_redis_stat_key)
                 if not stat_queue_json:
                     time.sleep(1)
                     continue
                 try:
                     stat_queue_dict = SevenHelper.json_loads(stat_queue_json)
-                    stat_user_log_model = StatUserLogModel(db_transaction=db_transaction)
+                    stat_user_log_model = StatUserLogModel(db_transaction=db_transaction).set_sub_table(stat_queue_dict["app_id"])
                     stat_user_report_model = StatUserReportModel(db_transaction=db_transaction)
                     create_date = TimeHelper.format_time_to_datetime(stat_queue_dict["create_date"])
                     create_day_int = int(create_date.strftime('%Y%m%d'))
@@ -289,8 +306,8 @@ class StatConsoleModel():
                     stat_user_log.create_month = create_month_int
                     stat_user_log.create_date = create_date
 
-                    stat_report_condition = "act_id=%s and module_id=%s and create_day=%s and user_id=%s"
-                    stat_report_param = [stat_queue_dict["act_id"], stat_queue_dict["module_id"], create_day_int, stat_queue_dict["user_id"]]
+                    stat_report_condition = "act_id=%s and module_id=%s and create_day=%s and user_id=%s and app_id=%s"
+                    stat_report_param = [stat_queue_dict["act_id"], stat_queue_dict["module_id"], create_day_int, stat_queue_dict["user_id"], stat_queue_dict["app_id"]]
                     stat_report_dict = stat_user_report_model.get_dict(stat_report_condition, params=stat_report_param)
                     if not stat_report_dict:
                         stat_user_report = StatUserReport()
@@ -299,8 +316,6 @@ class StatConsoleModel():
                         stat_user_report.module_id = stat_queue_dict["module_id"]
                         stat_user_report.user_id = stat_queue_dict["user_id"]
                         stat_user_report.open_id = stat_queue_dict["open_id"]
-                        stat_user_report.key_name = field_name
-                        stat_user_report.key_value = stat_queue_dict["key_value"]
                         stat_user_report.create_date = create_date
                         stat_user_report.create_year = create_year_int
                         stat_user_report.create_month = create_month_int
@@ -315,10 +330,13 @@ class StatConsoleModel():
                     if result == False:
                         raise Exception("执行事务失败", message)
 
-                    redis_init.lpop(redis_stat_key)
+                    redis_init.lrem(check_redis_stat_key, 1, stat_queue_json)
 
                 except Exception as ex:
-                    logger_error.error(f"统计用户队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue_dict)},ex:{traceback.format_exc()}")
+                    if "Duplicate entry" not in traceback.format_exc():
+                        redis_init.lpush(redis_stat_key, stat_queue_json)
+                        redis_init.lrem(check_redis_stat_key, 1, stat_queue_json)
+                        logger_error.error(f"统计用户队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue_dict)},ex:{traceback.format_exc()}")
                     continue
 
             except Exception as ex:
@@ -333,6 +351,7 @@ class ClearDataWork(TimingWork):
     :last_editors: HuangJianYi
     """
     def execute(self):
+        heart_beat_monitor("ClearDataWork", check_time=2*24*60)
         invoke_result_data = InvokeResultData()
         self.process_only_table()
 
@@ -348,7 +367,7 @@ class ClearDataWork(TimingWork):
         stat_orm_model = StatOrmModel()
         page_index = 0
         while True:
-            stat_orm_dict_list, is_next = stat_orm_model.get_dict_page_list(field="id,repeat_type", page_index=page_index, page_size=50, order_by="id asc", page_count_mode="next")
+            stat_orm_dict_list, is_next = stat_orm_model.get_dict_page_list(field="id,repeat_type", page_index=page_index, page_size=200, order_by="id asc", page_count_mode="next")
             if len(stat_orm_dict_list) <= 0:
                 break
             for stat_orm_dict in stat_orm_dict_list:
@@ -368,6 +387,7 @@ class StatUserDataWork(TimingWork):
     """
 
     def execute(self):
+        heart_beat_monitor("StatUserDataWork", check_time=2*24*60)
         invoke_result_data = InvokeResultData()
         self.clear_log()
         self.clear_report()
@@ -397,7 +417,7 @@ class StatUserDataWork(TimingWork):
         stat_config = share_config.get_value("stat_config", {})
         space_day = int(stat_config.get("user_report_space_day", 365))
         while True:
-            stat_user_report_list = stat_user_report_model.get_list(where="create_day<%s", order_by="id asc", limit="100", params=[SevenHelper.get_now_day_int(-24 * space_day)])
+            stat_user_report_list = stat_user_report_model.get_list(where="create_day<%s", order_by="id asc", limit="200", params=[SevenHelper.get_now_day_int(-24 * space_day)])
             if len(stat_user_report_list) <= 0:
                 break
             for item in stat_user_report_list:
