@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:58:31
-@LastEditTime: 2023-01-12 09:14:53
+@LastEditTime: 2025-03-19 16:21:45
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -13,9 +13,9 @@ from seven_framework.base_model import *
 from seven_cloudapp_frame.models.cache_model import *
 
 class ActInfoModel(CacheModel):
-    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
+    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(ActInfoModel, self).__init__(ActInfo, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
@@ -29,6 +29,7 @@ class ActInfo:
         self.id = 0  # id
         self.app_id = ""  # 应用标识
         self.act_name = ""  # 活动名称
+        self.business_type = 0  # 业务类型
         self.act_type = 0  # 活动类型
         self.theme_id = 0  # 主题标识
         self.is_visit_store = 0  # 是否开启访问店铺
@@ -73,7 +74,7 @@ class ActInfo:
     @classmethod
     def get_field_list(self):
         return [
-            'id', 'app_id', 'act_name', 'act_type', 'theme_id', 'is_visit_store', 'store_url', 'close_word', 'is_share', 'share_desc_json', 'is_rule', 'rule_desc_json', 'start_date', 'end_date', 'is_black', 'refund_count', 'finish_menu_config_json', 'is_finish', 'is_launch', 'is_del', 'join_ways', 'is_fictitious', 'task_asset_type_json', 'lc_order_id', 'agreement_json', 'brand_json', 'is_release', 'release_date', 'sort_index', 'create_date', 'modify_date', 'i1', 'i2', 'i3', 'i4', 'i5', 's1',
+            'id', 'app_id', 'act_name', 'business_type', 'act_type', 'theme_id', 'is_visit_store', 'store_url', 'close_word', 'is_share', 'share_desc_json', 'is_rule', 'rule_desc_json', 'start_date', 'end_date', 'is_black', 'refund_count', 'finish_menu_config_json', 'is_finish', 'is_launch', 'is_del', 'join_ways', 'is_fictitious', 'task_asset_type_json', 'lc_order_id', 'agreement_json', 'brand_json', 'is_release', 'release_date', 'sort_index', 'create_date', 'modify_date', 'i1', 'i2', 'i3', 'i4', 'i5', 's1',
             's2', 's3', 's4', 's5', 'd1', 'd2'
         ]
 
