@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:59:46
-@LastEditTime: 2022-10-27 16:48:11
+@LastEditTime: 2023-05-05 15:16:14
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -13,9 +13,9 @@ from seven_cloudapp_frame.models.cache_model import *
 
 
 class ActPrizeModel(CacheModel):
-    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
+    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(ActPrizeModel, self).__init__(ActPrize, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
@@ -39,7 +39,7 @@ class ActPrize:
         self.goods_code = ""  # 商品编码
         self.goods_code_list = ""  # 多个sku商品编码
         self.goods_type = 0  # 物品类型（1虚拟2实物）
-        self.prize_type = 0  # 奖品类型(1现货2优惠券3红包4参与奖5预售6积分7卡片)业务自定义从101开始
+        self.prize_type = 0  # 奖品类型(1-现货 2-优惠券 3-红包 4-参与奖 5-预售 6-积分 7-卡片 8-专属下单商品)业务自定义从101开始
         self.prize_price = 0  # 奖品价格
         self.probability = 0  # 奖品权重
         self.chance = 0  # 概率
