@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-20 10:09:52
-@LastEditTime: 2022-07-28 11:34:40
+@LastEditTime: 2024-03-15 13:52:44
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -13,9 +13,9 @@ from seven_cloudapp_frame.models.cache_model import *
 
 
 class AppInfoModel(CacheModel):
-    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
+    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(AppInfoModel, self).__init__(AppInfo, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
@@ -51,6 +51,7 @@ class AppInfo:
         self.is_setting = 0  # 是否完成数据配置：0-未完成，1-已配置
         self.expiration_date = "1900-01-01 00:00:00"  # 过期时间
         self.project_code = ""  # 项目编码
+        self.project_ver = "" # 项目版本号
         self.modify_date = "1900-01-01 00:00:00"  # 更新时间
         self.is_gm = 0  # 是否开启gm权限：0-否，1-是
         self.current_limit_count = 0  # 限流数量
@@ -65,7 +66,7 @@ class AppInfo:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'store_name', 'store_user_nick','main_user_open_id', 'store_id', 'store_icon', 'seller_id', 'app_id', 'app_name', 'app_icon', 'app_url', 'app_ver', 'app_key', 'access_token', 'preview_url', 'app_desc', 'template_id', 'template_ver', 'clients', 'app_telephone', 'is_instance', 'instance_date', 'is_setting', 'expiration_date', 'project_code', 'modify_date', 'is_gm', 'current_limit_count', 'i1', 'i2', 'i3', 'i4', 's1', 's2', 's3', 's4']
+        return ['id', 'store_name', 'store_user_nick','main_user_open_id', 'store_id', 'store_icon', 'seller_id', 'app_id', 'app_name', 'app_icon', 'app_url', 'app_ver', 'app_key', 'access_token', 'preview_url', 'app_desc', 'template_id', 'template_ver', 'clients', 'app_telephone', 'is_instance', 'instance_date', 'is_setting', 'expiration_date', 'project_code', 'project_ver', 'modify_date', 'is_gm', 'current_limit_count', 'i1', 'i2', 'i3', 'i4', 's1', 's2', 's3', 's4']
 
     @classmethod
     def get_primary_key(self):
