@@ -13,9 +13,9 @@ from seven_cloudapp_frame.models.cache_model import *
 
 
 class BaseInfoModel(CacheModel):
-    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
+    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(BaseInfoModel, self).__init__(BaseInfo, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
@@ -36,6 +36,7 @@ class BaseInfo:
         self.experience_pic = ""  # 案例二维码图
         self.client_ver = ""  # 客户端版本号
         self.server_ver = ""  # 服务端版本号
+        self.project_ver = "" # 项目版本号
         self.update_function = ""  # 版本更新内容
         self.update_function_b = ""  # 千牛端版本更新内容
         self.store_study_url = ""  # 店铺装修教程图文地址（如何上架小程序）
@@ -45,6 +46,7 @@ class BaseInfo:
         self.decoration_poster_json = ""  # 装修海报
         self.menu_config_json = ""  # 菜单配置信息
         self.is_remind_phone = 0  # 是否提醒提示配置手机号
+        self.is_force_phone = 0  # 是否强制配置手机号
         self.is_force_update = 0  # 是个强制更新客户端版本
         self.is_contact_us = 0  # 是否提醒联系我们
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
@@ -60,7 +62,7 @@ class BaseInfo:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'guid', 'product_name', 'product_icon', 'product_desc', 'service_market_url', 'customer_service', 'experience_pic', 'client_ver', 'server_ver', 'update_function', 'update_function_b', 'store_study_url', 'study_url', 'video_url', 'course_url', 'decoration_poster_json', 'menu_config_json', 'is_remind_phone', 'is_force_update', 'is_contact_us', 'create_date', 'modify_date', 'i1', 'i2', 'i3', 'i4', 's1', 's2', 's3', 's4']
+        return ['id', 'guid', 'product_name', 'product_icon', 'product_desc', 'service_market_url', 'customer_service', 'experience_pic', 'client_ver', 'server_ver', 'project_ver', 'update_function', 'update_function_b', 'store_study_url', 'study_url', 'video_url', 'course_url', 'decoration_poster_json', 'menu_config_json', 'is_remind_phone', 'is_force_phone', 'is_force_update', 'is_contact_us', 'create_date', 'modify_date', 'i1', 'i2', 'i3', 'i4', 's1', 's2', 's3', 's4']
 
     @classmethod
     def get_primary_key(self):
