@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-12 17:38:51
-@LastEditTime: 2021-11-24 10:38:24
+@LastEditTime: 2024-01-03 10:36:29
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -13,9 +13,10 @@ from seven_cloudapp_frame.models.cache_model import *
 
 
 class InviteLogModel(CacheModel):
-    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
+    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(InviteLogModel, self).__init__(InviteLog, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_task","redis_task", db_connect_key)
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
