@@ -13,9 +13,9 @@ from seven_cloudapp_frame.models.cache_model import *
 
 
 class IpTypeModel(CacheModel):
-    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
+    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(IpTypeModel, self).__init__(IpType, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
@@ -36,7 +36,6 @@ class IpType:
         self.is_release = 0  # 是否发布（1发布0未发布）
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
         self.modify_date = "1900-01-01 00:00:00"  # 修改时间
-        self.is_del = 0  # 是否删除（1是0否）
 
     @classmethod
     def get_field_list(self):
