@@ -13,9 +13,9 @@ from seven_cloudapp_frame.models.cache_model import *
 
 
 class MiddlerProductModel(CacheModel):
-    def __init__(self, db_connect_key='db_middler_platform', sub_table=None, db_transaction=None, context=None):
+    def __init__(self, db_connect_key='db_middler_platform', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(MiddlerProductModel, self).__init__(MiddlerProduct, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
