@@ -1,3 +1,11 @@
+# -*- coding: utf-8 -*-
+"""
+@Author: HuangJianYi
+@Date: 2023-07-26 19:29:43
+@LastEditTime: 2024-03-06 10:49:00
+@LastEditors: HuangJianYi
+@Description: 
+"""
 #此文件由rigger自动生成
 from seven_framework.mysql import MySQLHelper
 from seven_framework.base_model import *
@@ -5,9 +13,9 @@ from seven_cloudapp_frame.models.cache_model import *
 
 
 class PriceGearModel(CacheModel):
-    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
+    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(PriceGearModel, self).__init__(PriceGear, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
@@ -21,6 +29,7 @@ class PriceGear:
         self.id = 0  # id
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动标识
+        self.business_type = 0 # 业务类型
         self.relation_type = 0  # 关联类型：1商品skuid关联2商品id关联
         self.goods_id = ""  # 商品ID
         self.sku_id = ""  # sku_id
@@ -36,7 +45,7 @@ class PriceGear:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'relation_type', 'goods_id', 'sku_id', 'price_gear_name', 'price_gear_pic', 'price', 'is_del', 'sort_index', 'effective_date', 'create_date', 'modify_date', 'remark']
+        return ['id', 'app_id', 'act_id', 'business_type', 'relation_type', 'goods_id', 'sku_id', 'price_gear_name', 'price_gear_pic', 'price', 'is_del', 'sort_index', 'effective_date', 'create_date', 'modify_date', 'remark']
 
     @classmethod
     def get_primary_key(self):
