@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:55:09
-@LastEditTime: 2022-10-27 16:48:27
+@LastEditTime: 2024-01-03 10:39:26
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -13,9 +13,10 @@ from seven_cloudapp_frame.models.cache_model import *
 
 
 class PrizeRosterModel(CacheModel):
-    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
+    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(PrizeRosterModel, self).__init__(PrizeRoster, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_order","redis_order", db_connect_key)
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
@@ -60,6 +61,7 @@ class PrizeRoster:
         self.sub_pay_order_no = ""  # 支付子订单号
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
         self.request_code = ""  # 请求代码
+        self.business_type = 0 # 业务类型
         self.i1 = 0  # i1
         self.i2 = 0  # i2
         self.i3 = 0  # i3
@@ -76,7 +78,7 @@ class PrizeRoster:
     @classmethod
     def get_field_list(self):
         return [
-            'id', 'app_id', 'act_id', 'user_id', 'open_id', 'user_nick', 'order_no', 'source_type', 'source_object_id', 'module_id', 'module_name', 'goods_type', 'prize_type', 'prize_id', 'prize_name', 'prize_pic', 'prize_detail_json', 'prize_price', 'tag_name', 'tag_id', 'logistics_status', 'prize_status', 'pay_status', 'goods_id', 'goods_code', 'goods_code_list', 'is_sku', 'sku_id', 'sku_name', 'sku_json', 'main_pay_order_no', 'sub_pay_order_no', 'create_date', 'request_code', 'i1', 'i2',
+            'id', 'app_id', 'act_id', 'user_id', 'open_id', 'user_nick', 'order_no', 'source_type', 'source_object_id', 'module_id', 'module_name', 'goods_type', 'prize_type', 'prize_id', 'prize_name', 'prize_pic', 'prize_detail_json', 'prize_price', 'tag_name', 'tag_id', 'logistics_status', 'prize_status', 'pay_status', 'goods_id', 'goods_code', 'goods_code_list', 'is_sku', 'sku_id', 'sku_name', 'sku_json', 'main_pay_order_no', 'sub_pay_order_no', 'create_date', 'request_code', 'business_type', 'i1', 'i2',
             'i3', 'i4', 'i5', 's1', 's2', 's3', 's4', 's5', 'd1', 'd2'
         ]
 
