@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:26:10
-@LastEditTime: 2021-09-30 10:19:50
+@LastEditTime: 2024-01-03 10:39:45
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -13,9 +13,10 @@ from seven_cloudapp_frame.models.cache_model import *
 
 
 class RefundOrderModel(CacheModel):
-    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
+    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(RefundOrderModel, self).__init__(RefundOrder, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_order","redis_order", db_connect_key)
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
@@ -31,6 +32,7 @@ class RefundOrder:
         self.act_id = 0  # 活动标识
         self.user_id = 0  # 用户标识
         self.open_id = ""  # open_id
+        self.refund_type = 1  # 退款类型（1-手动 2-自动）
         self.pay_order_no = ""  # 支付单号
         self.refund_no = ""  # 退款单号
         self.out_refund_no = ""  # 平台退款单号
@@ -44,7 +46,7 @@ class RefundOrder:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'user_id', 'open_id', 'pay_order_no', 'refund_no', 'out_refund_no', 'out_order_no', 'refund_amount', 'refund_status', 'refund_reason', 'refund_date', 'refund_result_detail', 'create_date']
+        return ['id', 'app_id', 'act_id', 'user_id', 'open_id', 'refund_type', 'pay_order_no', 'refund_no', 'out_refund_no', 'out_order_no', 'refund_amount', 'refund_status', 'refund_reason', 'refund_date', 'refund_result_detail', 'create_date']
 
     @classmethod
     def get_primary_key(self):
