@@ -5,9 +5,10 @@ from seven_cloudapp_frame.models.cache_model import *
 
 
 class StatQueueModel(CacheModel):
-    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
+    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(StatQueueModel, self).__init__(StatQueue, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_stat","redis_stat", db_connect_key)
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
@@ -22,6 +23,7 @@ class StatQueue:
         self.app_id = ""  # 应用标识
         self.act_id = 0  # 活动标识
         self.module_id = 0  # 活动模块标识
+        self.object_id = ""  # 对象标识
         self.user_id = 0  # 用户标识
         self.open_id = ""  # open_id
         self.key_name = ""  # key名称
@@ -34,7 +36,7 @@ class StatQueue:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'act_id', 'module_id', 'user_id', 'open_id', 'key_name', 'key_value', 'request_code', 'create_date', 'process_count', 'process_result', 'process_date']
+        return ['id', 'app_id', 'act_id', 'module_id','object_id', 'user_id', 'open_id', 'key_name', 'key_value', 'request_code', 'create_date', 'process_count', 'process_result', 'process_date']
 
     @classmethod
     def get_primary_key(self):
