@@ -2,22 +2,24 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-10 10:09:06
-@LastEditTime: 2021-09-02 17:41:04
+@LastEditTime: 2023-07-18 15:40:15
 @LastEditors: HuangJianYi
 @Description: 
 """
 #此文件由rigger自动生成
 from seven_framework.mysql import MySQLHelper
 from seven_framework.base_model import *
+from seven_cloudapp_frame.models.cache_model import *
 
-
-class TaskCountModel(BaseModel):
-    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
+class TaskCountModel(CacheModel):
+    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
         super(TaskCountModel, self).__init__(TaskCount, sub_table)
-        self.db = MySQLHelper(config.get_value(db_connect_key))
+        db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_task","redis_task", db_connect_key)
+        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
         self.db_connect_key = db_connect_key
         self.db_transaction = db_transaction
         self.db.context = context
+        self.redis_config_dict = config.get_value("redis_task")
 
     #方法扩展请继承此类
 
