@@ -2,13 +2,14 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:44:36
-@LastEditTime: 2023-01-04 17:46:27
+@LastEditTime: 2025-03-28 18:46:45
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.libs.customize.safe_helper import SafeHelper
 from seven_cloudapp_frame.models.db_models.ip.ip_info_model import *
 from seven_cloudapp_frame.models.db_models.ip.ip_type_model import *
 
@@ -49,7 +50,7 @@ class IpBaseModel():
             dependency_key_list.append(DependencyKey.ip_type_list(act_id))
         IpTypeModel().delete_dependency_key(dependency_key_list, delay_delete_time)
 
-    def save_ip_info(self, app_id,act_id,ip_id,ip_name,ip_pic,show_pic,sort_index,is_release,ip_type,ip_summary,mode_type=0,ip_config_json=None):
+    def save_ip_info(self, app_id,act_id,ip_id,ip_name,ip_pic,show_pic,sort_index,is_release,ip_type,ip_summary,mode_type=0,ip_config_json=None, is_set_cache=True):
         """
         :description: 保存ip信息
         :param app_id：应用标识
@@ -64,6 +65,7 @@ class IpBaseModel():
         :param ip_summary：ip描述
         :param mode_type：模式类型
         :param ip_config_json：ip配置
+        :param is_set_cache: 是否设置缓存，默认True False-则是删除依赖建
         :return
         :last_editors: HuangJianYi
         """
@@ -112,10 +114,14 @@ class IpBaseModel():
         result["new"] = ip_info
         result["old"] = old_ip_info
         invoke_result_data.data = result
-        self._delete_ip_info_dependency_key(act_id,ip_info.id)
+        if is_set_cache == True and ip_id > 0:
+            self._delete_ip_info_dependency_key(act_id, 0)
+            ip_info_model.set_cache_dict_by_id(ip_id, ip_info.__dict__, dependency_key=DependencyKey.ip_info(ip_id))
+        else:
+            self._delete_ip_info_dependency_key(act_id, ip_id)
         return invoke_result_data
 
-    def get_ip_info_list(self, app_id, act_id, page_size, page_index, is_del=0,is_release=-1, field="*", condition="", params=[], order_by="sort_index desc", is_cache=True, page_count_mode="total"):
+    def get_ip_info_list(self, app_id, act_id, page_size, page_index, is_del=0,is_release=-1, field="*", condition="", params=[], order_by="sort_index desc", is_cache=True, page_count_mode="total", dependency_key=""):
         """
         :description: 获取IP列表
         :param app_id：应用标识
@@ -130,12 +136,18 @@ class IpBaseModel():
         :param order_by：排序
         :param is_cache：是否缓存
         :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
+        :param dependency_key：依赖建
         :return: list
         :last_editors: HuangJianYi
         """
-        params_list = [app_id, act_id]
+        params_list = []
         condition_where = ConditionWhere()
-        condition_where.add_condition("app_id=%s and act_id=%s")
+        if app_id:
+            condition_where.add_condition("app_id=%s")
+            params_list.append(app_id)
+        if act_id != 0:
+            condition_where.add_condition("act_id=%s")
+            params_list.append(act_id)
         if condition:
             condition_where.add_condition(condition)
             params_list.extend(params)
@@ -146,59 +158,78 @@ class IpBaseModel():
             condition_where.add_condition("is_release=%s")
             params_list.append(is_release)
         if is_cache == True:
-            page_list = IpInfoModel(context=self.context).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=DependencyKey.ip_info_list(act_id), cache_expire=600, page_count_mode=page_count_mode)
+            if not dependency_key:
+                dependency_key = DependencyKey.ip_info_list(act_id)
+            page_list = IpInfoModel(context=self.context, is_auto=True).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=dependency_key, cache_expire=600, page_count_mode=page_count_mode)
         else:
             page_list = IpInfoModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, page_count_mode=page_count_mode)
         return page_list
 
-    def update_ip_info_status(self,app_id,ip_id,is_del):
+    def update_ip_info_status(self, app_id, ip_id, is_del, is_set_cache=True):
         """
         :description: 删除ip
         :param app_id：应用标识
         :param ip_id：ip标识
         :param is_del：0-还原，1-删除
+        :param is_set_cache: 是否设置缓存，默认True False-则是删除依赖建
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         ip_info_model = IpInfoModel(context=self.context)
         ip_info_dict = ip_info_model.get_dict_by_id(ip_id)
-        if not ip_info_dict or ip_info_dict["app_id"] != app_id:
+        if not ip_info_dict or SafeHelper.authenticat_app_id(ip_info_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "ip信息不存在"
             return invoke_result_data
         is_release = 0
         del_date = SevenHelper.get_now_datetime()
+
         invoke_result_data.success = ip_info_model.update_table("is_del=%s,is_release=%s,modify_date=%s,del_date=%s", "id=%s", [is_del, is_release, del_date, del_date, ip_id])
-        self._delete_ip_info_dependency_key(ip_info_dict["act_id"],ip_id)
+        if is_set_cache == True:
+            ip_info_dict['is_del'] = is_del
+            ip_info_dict['is_release'] = is_release
+            ip_info_dict['modify_date'] = del_date
+            ip_info_dict['del_date'] = del_date
+            self._delete_ip_info_dependency_key(ip_info_dict["act_id"], 0)
+            ip_info_model.set_cache_dict_by_id(ip_id, ip_info_dict, dependency_key=DependencyKey.ip_info(ip_id))
+        else:
+            self._delete_ip_info_dependency_key(ip_info_dict["act_id"], ip_id)
         invoke_result_data.data = ip_info_dict
         return invoke_result_data
 
-    def release_ip_info(self,app_id,ip_id,is_release):
+    def release_ip_info(self, app_id, ip_id, is_release, is_set_cache=True):
         """
         :description: ip上下架
         :param app_id：应用标识
         :param ip_id：ip标识
         :param is_release: 是否发布 1-是 0-否
+        :param is_set_cache: 是否设置缓存，默认True False-则是删除依赖建
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         ip_info_model = IpInfoModel(context=self.context)
         ip_info_dict = ip_info_model.get_dict_by_id(ip_id)
-        if not ip_info_dict or ip_info_dict["app_id"]!=app_id:
+        if not ip_info_dict or SafeHelper.authenticat_app_id(ip_info_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "ip信息不存在"
             return invoke_result_data
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = ip_info_model.update_table("is_release=%s,modify_date=%s", "id=%s", [is_release, modify_date, ip_id])
-        self._delete_ip_info_dependency_key(ip_info_dict["act_id"],ip_id)
+        if is_set_cache == True:
+            ip_info_dict['is_release'] = is_release
+            ip_info_dict['modify_date'] = modify_date
+            self._delete_ip_info_dependency_key(ip_info_dict["act_id"], 0)
+            ip_info_model.set_cache_dict_by_id(ip_id, ip_info_dict, dependency_key=DependencyKey.ip_info(ip_id))
+        else:
+            self._delete_ip_info_dependency_key(ip_info_dict["act_id"], ip_id)
         invoke_result_data.data = ip_info_dict
         return invoke_result_data
 
-    def save_ip_type(self,app_id,act_id,ip_type_id,type_name,sort_index,is_release,type_pic=""):
+    def save_ip_type(self,app_id,act_id,ip_type_id,type_name,sort_index,is_release,type_pic="", is_set_cache=True):
         """
         :description: 保存ip类型
         :param app_id：应用标识
@@ -208,6 +239,7 @@ class IpBaseModel():
         :param sort_index：排序
         :param is_release：是否发布
         :param type_pic：类型图片
+        :param is_set_cache: 是否设置缓存，默认True False-则是删除依赖建
         :return
         :last_editors: HuangJianYi
         """
@@ -224,7 +256,7 @@ class IpBaseModel():
         ip_type_model = IpTypeModel(context=self.context)
         if ip_type_id > 0:
             ip_type = ip_type_model.get_entity_by_id(ip_type_id)
-            if not ip_type or ip_type.app_id != app_id:
+            if not ip_type or SafeHelper.authenticat_app_id(ip_type.app_id, app_id) == False:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = "ip类型信息不存在"
@@ -250,7 +282,11 @@ class IpBaseModel():
         result["new"] = ip_type
         result["old"] = old_ip_type
         invoke_result_data.data = result
-        self._delete_ip_type_dependency_key(act_id,ip_type.id)
+        if is_set_cache == True and ip_type_id > 0:
+            self._delete_ip_type_dependency_key(act_id, 0)
+            ip_type_model.set_cache_dict_by_id(ip_type_id, ip_type.__dict__, dependency_key=DependencyKey.ip_type(ip_type_id))
+        else:
+            self._delete_ip_type_dependency_key(act_id, ip_type_id)
         return invoke_result_data
 
     def get_ip_type_list(self, app_id, act_id, page_size, page_index,is_release=-1, field="*", condition="", params=[], order_by="sort_index desc", is_cache=True, page_count_mode="total"):
@@ -270,9 +306,14 @@ class IpBaseModel():
         :return:
         :last_editors: HuangJianYi
         """
-        params_list = [app_id, act_id]
+        params_list = []
         condition_where = ConditionWhere()
-        condition_where.add_condition("app_id=%s and act_id=%s")
+        if app_id:
+            condition_where.add_condition("app_id=%s")
+            params_list.append(app_id)
+        if act_id != 0:
+            condition_where.add_condition("act_id=%s")
+            params_list.append(act_id)
         if condition:
             condition_where.add_condition(condition)
             params_list.extend(params)
@@ -280,30 +321,37 @@ class IpBaseModel():
             condition_where.add_condition("is_release=%s")
             params_list.append(is_release)
         if is_cache == True:
-            page_list = IpTypeModel(context=self.context).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=DependencyKey.ip_type_list(act_id), cache_expire=600, page_count_mode=page_count_mode)
+            page_list = IpTypeModel(context=self.context, is_auto=True).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=DependencyKey.ip_type_list(act_id), cache_expire=600, page_count_mode=page_count_mode)
         else:
             page_list = IpTypeModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, page_count_mode=page_count_mode)
         return page_list
 
-    def release_ip_type(self,app_id, ip_type_id, is_release):
+    def release_ip_type(self,app_id, ip_type_id, is_release, is_set_cache=True):
         """
         :description: ip上下架
         :param app_id：应用标识
         :param ip_type_id：ip类型标识
         :param is_release: 是否发布 1-是 0-否
+        :param is_set_cache: 是否设置缓存，默认True False-则是删除依赖建
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         ip_type_model = IpTypeModel(context=self.context)
         ip_type_dict = ip_type_model.get_dict_by_id(ip_type_id)
-        if not ip_type_dict or ip_type_dict["app_id"]!=app_id:
+        if not ip_type_dict or SafeHelper.authenticat_app_id(ip_type_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "ip信息不存在"
             return invoke_result_data
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = ip_type_model.update_table("is_release=%s,modify_date=%s", "id=%s", [is_release, modify_date, ip_type_id])
-        self._delete_ip_type_dependency_key(ip_type_dict["act_id"],ip_type_id)
+        if is_set_cache == True and ip_type_id > 0:
+            ip_type_dict['is_release'] = is_release
+            ip_type_dict['modify_date'] = modify_date
+            self._delete_ip_type_dependency_key(ip_type_dict["act_id"], 0)
+            ip_type_model.set_cache_dict_by_id(ip_type_id, ip_type_dict, dependency_key=DependencyKey.ip_type(ip_type_id))
+        else:
+            self._delete_ip_type_dependency_key(ip_type_dict["act_id"], ip_type_id)
         invoke_result_data.data = ip_type_dict
         return invoke_result_data
\ No newline at end of file
