@@ -390,12 +390,13 @@ class LaunchBaseModel():
                 launch_plan_model.add_entity(launch_plan)
             return invoke_result_data
     
-    def init_launch_goods_callback(self, app_id, act_id, close_goods_id):
+    def init_launch_goods_callback(self, app_id, act_id, close_goods_id, call_back_info):
         """
         :description: 初始化投放商品回调接口
         :param app_id：应用标识
         :param act_id：活动标识
         :param close_goods_id：投放失败时关闭投放的商品ID  多个逗号,分隔
+        :param call_back_info：回调信息
         :return 
         :last_editors: HuangJianYi
         """
