@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:26:29
-@LastEditTime: 2023-01-04 15:59:34
+@LastEditTime: 2024-03-06 11:00:07
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -17,10 +17,12 @@ class PriceBaseModel():
     """
     :description: 价格档位业务模型
     """
-    def __init__(self, context=None,logging_error=None, logging_info=None):
+
+    def __init__(self, context=None, logging_error=None, logging_info=None, process_launch_goods=True):
         self.context = context
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
+        self.process_launch_goods = process_launch_goods
 
     def _delete_price_gear_dependency_key(self, act_id, delay_delete_time=0.01):
         """
@@ -32,7 +34,7 @@ class PriceBaseModel():
         """
         PriceGearModel().delete_dependency_key(DependencyKey.price_gear_list(act_id), delay_delete_time)
 
-    def save_price_gear(self,app_id,act_id,price_gear_id,relation_type,price_gear_name,price_gear_pic,price,goods_id,sku_id,remark="",sort_index=0):
+    def save_price_gear(self, app_id, act_id, price_gear_id, relation_type, price_gear_name, price_gear_pic, price, goods_id, sku_id, remark="", sort_index=0, business_type=0):
         """
         :description: 保存价格档位
         :param app_id：应用标识
@@ -46,6 +48,7 @@ class PriceBaseModel():
         :param sku_id：sku_id
         :param remark：备注
         :param sort_index：排序
+        :param business_type：业务类型
         :return:
         :last_editors: HuangJianYi
         """
@@ -89,6 +92,7 @@ class PriceBaseModel():
         price_gear.sku_id = sku_id
         price_gear.remark = remark
         price_gear.sort_index = sort_index
+        price_gear.business_type = business_type
         price_gear.modify_date = SevenHelper.get_now_datetime()
 
         if is_add:
@@ -114,8 +118,9 @@ class PriceBaseModel():
 
         launch_goods_id = price_gear.goods_id if price_gear else ''
         old_goods_id = old_price_gear.goods_id if old_price_gear else ''
-        launch_base_model = LaunchBaseModel(context=self.context)
-        launch_base_model.add_launch_goods(app_id,act_id, launch_goods_id, old_goods_id,"2")
+        if self.process_launch_goods == True:
+            launch_base_model = LaunchBaseModel(context=self.context)
+            launch_base_model.add_launch_goods(app_id,act_id, launch_goods_id, old_goods_id,"2")
 
         result = {}
         result["is_add"] = is_add
@@ -125,7 +130,7 @@ class PriceBaseModel():
         self._delete_price_gear_dependency_key(act_id)
         return invoke_result_data
 
-    def get_price_gear_list(self,app_id,act_id,page_size,page_index,order_by="id desc",is_del=0,is_cache=True, page_count_mode="total"):
+    def get_price_gear_list(self, app_id, act_id, page_size, page_index, order_by="id desc", is_del=0, is_cache=True, page_count_mode="total", business_type=-1):
         """
         :description: 获取价格档位列表
         :param app_id：应用标识
@@ -136,30 +141,34 @@ class PriceBaseModel():
         :param is_del：是否回收站1是0否
         :param is_cache：是否缓存
         :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
+        :param business_type：业务类型
         :return:
         :last_editors: HuangJianYi
         """
         condition = "app_id=%s and act_id=%s"
+        params = [app_id,act_id]
         if is_del == 1:
             condition += " and is_del=1"
         else:
             condition += " and is_del=0"
+        if business_type != -1:
+            condition += " and business_type=%s"
+            params.append(business_type)
 
-        params = [app_id,act_id]
-        price_gear_model = PriceGearModel(context=self.context)
         if is_cache == True:
-            page_list = price_gear_model.get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=DependencyKey.price_gear_list(act_id),page_count_mode=page_count_mode)
+            page_list = PriceGearModel(context=self.context, is_auto=True).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params, dependency_key=DependencyKey.price_gear_list(act_id), cache_expire=300, page_count_mode=page_count_mode)
         else:
-            page_list = price_gear_model.get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,page_count_mode=page_count_mode)
+            page_list = PriceGearModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,page_count_mode=page_count_mode)
         return page_list
 
-    def update_price_gear_status(self,app_id,act_id,price_gear_id,is_del):
+    def update_price_gear_status(self, app_id, act_id, price_gear_id, is_del, is_clear_goods_sku=True):
         """
         :description: 删除或恢复价格档位
         :param app_id：应用标识
         :param act_id：活动标识
         :param price_gear_id：价格档位标识
         :param is_del：1删除0恢复
+        :param is_clear_goods_sku：是否清空商品ID和sku_id
         :return: 
         :last_editors: HuangJianYi
         """
@@ -172,10 +181,14 @@ class PriceBaseModel():
             invoke_result_data.error_message = "价格档位信息不存在"
             return invoke_result_data
         goods_id =  price_gear_dict["goods_id"]
-        invoke_result_data.success = price_gear_model.update_table("is_del=%s,goods_id='',sku_id=''", "id=%s", [is_del, price_gear_id])
+        if is_clear_goods_sku == True:
+            invoke_result_data.success = price_gear_model.update_table("is_del=%s,goods_id='',sku_id='',modify_date=%s", "id=%s", [is_del, TimeHelper.get_now_format_time(), price_gear_id])
+        else:
+            invoke_result_data.success = price_gear_model.update_table("is_del=%s,modify_date=%s", "id=%s", [is_del, TimeHelper.get_now_format_time(), price_gear_id])
         if invoke_result_data.success ==True and is_del == 1:
-            launch_base_model = LaunchBaseModel(context=self.context)
-            launch_base_model.update_launch_goods(act_id, goods_id,"2")
+            if self.process_launch_goods == True:
+                launch_base_model = LaunchBaseModel(context=self.context)
+                launch_base_model.update_launch_goods(act_id, goods_id,"2")
         self._delete_price_gear_dependency_key(act_id)
         invoke_result_data.data = price_gear_dict
         return invoke_result_data
