@@ -2,12 +2,13 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2023-02-21 13:38:22
+@LastEditTime: 2025-03-28 18:47:11
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.libs.customize.safe_helper import SafeHelper
 from seven_cloudapp_frame.models.db_models.act.act_module_model import *
 from seven_cloudapp_frame.models.db_models.act.act_prize_model import *
 from seven_cloudapp_frame.models.db_models.tao.tao_coupon_model import *
@@ -61,7 +62,7 @@ class PrizeBaseModel():
                 return None
         return act_prize_dict
 
-    def get_act_prize_list(self,app_id,act_id,module_id,prize_name,ascription_type,is_del,page_size,page_index,order_by="sort_index desc,id asc",condition="",params=[],field="*",is_cache=True,page_count_mode="total"):
+    def get_act_prize_list(self,app_id,act_id,module_id,prize_name,ascription_type,is_del,page_size,page_index,order_by="sort_index desc,id asc",condition="",params=[],field="*",is_cache=True, page_count_mode="total", is_auto=False):
         """
         :description: 获取活动奖品列表
         :param app_id: 应用标识
@@ -77,35 +78,42 @@ class PrizeBaseModel():
         :param params：参数化数组
         :param field:查询字段
         :param is_cache: 是否缓存
-        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算       
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
+        :param is_auto: True-走从库 False-走主库
         :return: 
         :last_editors: HuangJianYi
         """
-        where = "app_id=%s and act_id=%s"
-        params_list = [app_id,act_id]
+        params_list = []
+        condition_where = ConditionWhere()
+        if app_id:
+            condition_where.add_condition("app_id=%s")
+            params_list.append(app_id)
+        if act_id:
+            condition_where.add_condition("act_id=%s")
+            params_list.append(act_id)
         if condition:
-            where += " and " + condition
+            condition_where.add_condition(condition)
             params_list.extend(params)
         if ascription_type != -1:
-            where += " and ascription_type=%s"
+            condition_where.add_condition("ascription_type=%s")
             params_list.append(ascription_type)
         if is_del !=-1:
-            where += " and is_del=%s"
+            condition_where.add_condition("is_del=%s")
             params_list.append(is_del)
         if module_id:
-            where += " and module_id=%s"
+            condition_where.add_condition("module_id=%s")
             params_list.append(module_id)
         if prize_name:
-            where += " and prize_name=%s"
+            condition_where.add_condition("prize_name=%s")
             params_list.append(prize_name)
-        act_prize_model = ActPrizeModel(context=self.context)
+        act_prize_model = ActPrizeModel(context=self.context, is_auto=is_auto)
         if is_cache:
-            page_list = act_prize_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=DependencyKey.act_prize_list(act_id,module_id),page_count_mode=page_count_mode)
+            page_list = act_prize_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=DependencyKey.act_prize_list(act_id,module_id), cache_expire=300, page_count_mode=page_count_mode)
         else:
-            page_list = act_prize_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,page_count_mode=page_count_mode)
+            page_list = act_prize_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list,page_count_mode=page_count_mode)
         return page_list
 
-    def save_act_prize(self,app_id,act_id,module_id,prize_id,prize_name,prize_title,prize_pic,prize_detail_json,goods_id,goods_code,goods_code_list,goods_type,prize_type,prize_price,probability,chance,prize_limit,is_prize_notice,prize_total,is_surplus,lottery_type,tag_name,tag_id,is_sku,sku_json,sort_index,is_release,ascription_type=0,i1=0,i2=0,i3=0,i4=0,i5=0,s1='',s2='',s3='',s4='',s5='',d1='',d2=''):
+    def save_act_prize(self,app_id,act_id,module_id,prize_id,prize_name,prize_title,prize_pic,prize_detail_json,goods_id,goods_code,goods_code_list,goods_type,prize_type,prize_price,probability,chance,prize_limit,is_prize_notice,prize_total,is_surplus,lottery_type,tag_name,tag_id,is_sku,sku_json,sort_index,is_release,ascription_type=0,i1=0,i2=0,i3=0,i4=0,i5=0,s1='',s2='',s3='',s4='',s5='',d1='',d2='', exclude_field_list='', is_set_cache=True):
         """
         :description: 保存活动模块信息
         :param app_id: 应用标识
@@ -148,6 +156,8 @@ class PrizeBaseModel():
         :param s5: s5
         :param d1: d1
         :param d2: d2
+        :param exclude_field_list: 排除更新的字段
+        :param is_set_cache: 是否设置缓存，默认True False-则是删除依赖建
         :return: 
         :last_editors: HuangJianYi
         """
@@ -224,17 +234,39 @@ class PrizeBaseModel():
             act_prize.prize_total = prize_total
             act_prize.id = act_prize_model.add_entity(act_prize)
         else:
-            act_prize_model.update_entity(act_prize,exclude_field_list="app_id,act_id,module_id,prize_total,surplus,hand_out")
-            operate_num = prize_total - act_prize.prize_total
-            if operate_num != 0:
-                act_prize_model.update_table(f"surplus=surplus+{operate_num},prize_total=prize_total+{operate_num}", "id=%s", act_prize.id)
+            db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"), context=self)
+            act_prize_model = ActPrizeModel(db_transaction=db_transaction, context=self.context)
+            try:
+                db_transaction.begin_transaction()
+                if not exclude_field_list:
+                    exclude_field_list = 'app_id,act_id,module_id,prize_total,surplus,hand_out'
+                act_prize_model.update_entity(act_prize,exclude_field_list=exclude_field_list)
+                operate_num = prize_total - act_prize.prize_total
+                if operate_num != 0:
+                    act_prize_model.update_table(f"surplus=surplus+{operate_num},prize_total=prize_total+{operate_num}", "id=%s", act_prize.id)
+                result, message = db_transaction.commit_transaction(True)
+                if not result:
+                    raise Exception("执行事务失败",message)
+            except Exception as ex:
+                if self.context:
+                    self.context.logging_link_error("【更新奖品失败】" + traceback.format_exc())
+                elif self.logging_link_error:
+                    self.logging_link_error("【更新奖品失败】" + traceback.format_exc())
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = "更新失败"
+                return invoke_result_data
 
         result = {}
         result["is_add"] = is_add
         result["new"] = act_prize
         result["old"] = old_act_prize
         invoke_result_data.data = result
-        self._delete_act_prize_dependency_key(act_id,module_id,act_prize.id)
+        if is_set_cache == True and act_prize.id > 0:
+            self._delete_act_prize_dependency_key(act_id,module_id,0)
+            act_prize_model.set_cache_dict_by_id(act_prize.id, act_prize.__dict__, DependencyKey.act_prize(act_prize.id))
+        else:
+            self._delete_act_prize_dependency_key(act_id,module_id,act_prize.id)
         return invoke_result_data
 
     def save_tao_coupon(self,app_id,act_id,prize_id,coupon_type,right_ename,pool_id,coupon_start_date,coupon_end_date,coupon_url,coupon_price,use_sill_price):
@@ -279,19 +311,20 @@ class PrizeBaseModel():
         tao_coupon_model.delete_dependency_key([DependencyKey.coupon(tao_coupon.id),DependencyKey.coupon_list(act_id)])
         return invoke_result_data
 
-    def update_act_prize_status(self,app_id,prize_id,is_del):
+    def update_act_prize_status(self, app_id, prize_id, is_del, is_set_cache=True):
         """
         :description: 删除或者还原活动奖品
         :param app_id：应用标识
         :param prize_id：奖品标识
         :param is_del：0-还原，1-删除
+        :param is_set_cache: 是否设置缓存，默认True False-则是删除依赖建
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         act_prize_model = ActPrizeModel(context=self.context)
         act_prize_dict = act_prize_model.get_dict_by_id(prize_id)
-        if not act_prize_dict or act_prize_dict["app_id"] != app_id:
+        if not act_prize_dict or SafeHelper.authenticat_app_id(act_prize_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "活动奖品信息不存在"
@@ -299,29 +332,44 @@ class PrizeBaseModel():
         is_release = 0 if is_del == 1 else 1
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_prize_model.update_table("is_del=%s,is_release=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, prize_id])
-        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],act_prize_dict["module_id"],prize_id)
+        if is_set_cache == True:
+            act_prize_dict['is_del'] = is_del
+            act_prize_dict['is_release'] = is_release
+            act_prize_dict['modify_date'] = modify_date
+            self._delete_act_prize_dependency_key(act_prize_dict["act_id"],act_prize_dict["module_id"],0)
+            act_prize_model.set_cache_dict_by_id(prize_id, act_prize_dict, DependencyKey.act_prize(prize_id))
+        else:
+            self._delete_act_prize_dependency_key(act_prize_dict["act_id"],act_prize_dict["module_id"], prize_id)
+
         invoke_result_data.data = act_prize_dict
         return invoke_result_data
 
-    def release_act_prize(self,app_id,prize_id,is_release):
+    def release_act_prize(self, app_id, prize_id, is_release, is_set_cache=True):
         """
         :description: 活动奖品上下架
         :param app_id：应用标识
         :param prize_id：奖品标识
         :param is_release: 是否发布 1-是 0-否
+        :param is_set_cache: 是否设置缓存，默认True False-则是删除依赖建
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         act_prize_model = ActPrizeModel(context=self.context)
         act_prize_dict = act_prize_model.get_dict_by_id(prize_id)
-        if not act_prize_dict or act_prize_dict["app_id"] != app_id:
+        if not act_prize_dict or SafeHelper.authenticat_app_id(act_prize_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "活动奖品不存在"
             return invoke_result_data
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_prize_model.update_table("modify_date=%s,is_release=%s", "id=%s", [modify_date, is_release, prize_id])
-        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],act_prize_dict["module_id"],prize_id)
+        if is_set_cache == True:
+            act_prize_dict['is_release'] = is_release
+            act_prize_dict['modify_date'] = modify_date
+            self._delete_act_prize_dependency_key(act_prize_dict["act_id"],act_prize_dict["module_id"],0)
+            act_prize_model.set_cache_dict_by_id(prize_id, act_prize_dict, DependencyKey.act_prize(prize_id))
+        else:
+            self._delete_act_prize_dependency_key(act_prize_dict["act_id"],act_prize_dict["module_id"], prize_id)
         invoke_result_data.data = act_prize_dict
         return invoke_result_data
