@@ -33,8 +33,10 @@ class PushBaseModel():
         invoke_result_data = InvokeResultData()
         redis_init = SevenHelper.redis_init()
         redis_key = f"wechat_subscribe_list:{app_id}_{template_id}"
-        redis_init.zincrby(redis_key, value=open_id, amount=1)
-        redis_init.expire(redis_key, 3600 * 24 * 30)
+        pipeline = redis_init.pipeline()
+        pipeline.zincrby(redis_key, value=open_id, amount=1)
+        pipeline.expire(redis_key, 3600 * 24 * 30)
+        pipeline.execute()
         return invoke_result_data
 
     def push_wechat_message(self, open_id, template_id, page, request_data, miniprogram_state="formal", lang="zh_CN", app_id="", app_secret="", plan_id=0):
@@ -77,8 +79,10 @@ class PushBaseModel():
             push_redis_key = f"wechat_pushlog_list:{app_id}"
             if plan_id > 0:
                 push_redis_key += f"_{plan_id}"
-            redis_init.rpush(push_redis_key, SevenHelper.json_dumps(push_log_dict))
-            redis_init.expire(push_redis_key, 3600 * 24 * 30)
+            pipeline = redis_init.pipeline()
+            pipeline.rpush(push_redis_key, SevenHelper.json_dumps(push_log_dict))
+            pipeline.expire(push_redis_key, 3600 * 24 * 30)
+            pipeline.execute()
             return invoke_result_data
         except Exception as ex:
             log_info = "【推送微信订阅信息】" + traceback.format_exc()
