@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-02 15:17:41
-@LastEditTime: 2023-03-29 17:13:54
+@LastEditTime: 2024-08-23 14:17:31
 @LastEditors: HuangJianYi
 :description: 自定义实体模型
 """
@@ -279,14 +279,18 @@ class DependencyKey():
         return f"ip_info:ipid_{ip_id}"
 
     @classmethod
-    def ip_info_list(self, act_id):
+    def ip_info_list(self, act_id, type_id=0):
         """
         :description: 位置信息列表
         :param act_id: 活动标识
+        :param type_id: ip类型标识
         :return str
         :last_editors: HuangJianYi
         """
-        return f"ip_info_list:actid_{act_id}"
+        if type_id:
+            return f"ip_info_list:actid_{act_id}_typeid_{type_id}"
+        else:
+            return f"ip_info_list:actid_{act_id}"
 
     @classmethod
     def ip_type(self, type_id):
@@ -309,17 +313,20 @@ class DependencyKey():
         return f"ip_type_list:actid_{act_id}"
 
     @classmethod
-    def prize_order_list(self, act_id, user_id=0):
+    def prize_order_list(self, act_id, user_id=0, app_id=''):
         """
         :description: 奖品订单列表
         :param act_id: 活动标识
         :param user_id: 用户标识
+        :param app_id: 应用标识
         :return str
         :last_editors: HuangJianYi
         """
         dependency_key = f"prize_order_list:actid_{act_id}"
         if user_id:
             dependency_key += f"_userid_{user_id}"
+        if act_id == 0 and app_id:
+            dependency_key += f"_appid_{app_id}"
         return dependency_key
 
     @classmethod
@@ -506,3 +513,26 @@ class DependencyKey():
         """
         return f"invite_help_list:{id_md5}_{user_id}"
     
+    @classmethod
+    def app_relation(self, app_id):
+        """
+        :description: 应用关联
+        :param app_id：app_id
+        :return str
+        :last_editors: HuangJianYi
+        """
+        return f"app_relation:appid_{app_id}"
+    
+    
+    @classmethod
+    def user_asset(self, act_id, user_id):
+        """
+        :description: 用户资产
+        :param act_id：活动标识
+        :param user_id：用户标识
+        :return str
+        :last_editors: HuangJianYi
+        """
+        return f"user_asset:actid_{act_id}_userid_{user_id}"
+    
+    
