@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2023-03-23 10:16:34
+@LastEditTime: 2025-04-28 14:56:06
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -22,7 +22,7 @@ class TopBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def instantiate(self, app_id, user_nick, access_token, app_key, app_secret, is_log=False, main_user_open_id=''):
+    def instantiate(self, app_id, user_nick, access_token, app_key, app_secret, is_log=False, main_user_open_id='', app_name='', description='', icon="", template_id='', template_version='', is_instance=1):
         """
         :description: 实例化
         :param app_id:应用标识
@@ -31,6 +31,13 @@ class TopBaseModel():
         :param app_key:app_key
         :param app_secret:app_secret
         :param is_log：是否记录返回信息
+        :param main_user_open_id：main_user_open_id
+        :param app_name：应用名称
+        :param description：应用描述
+        :param icon：应用图标
+        :param template_id：模板ID
+        :param template_version：模板版本号
+        :param is_instance：实例化类型(0-未实例化 1-主实例化 2-关联实例化)
         :return
         :last_editors: HuangJianYi
         """
@@ -41,11 +48,11 @@ class TopBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "基础信息未配置"
             return invoke_result_data
-        app_name = base_info.product_name
-        description = base_info.product_desc
-        icon = base_info.product_icon
-        template_id = share_config.get_value("client_template_id")
-        template_version = base_info.client_ver
+        app_name = base_info.product_name if not app_name else app_name
+        description = base_info.product_desc if not description else description
+        icon = base_info.product_icon if not icon else icon
+        template_id = share_config.get_value("client_template_id") if not template_id else template_id
+        template_version = base_info.client_ver if not template_version else template_version
         app_info_model = AppInfoModel(context=self.context)
         app_info = None
         is_change_project_code = False #是否改变了项目代码，用于判断是否进行了服务市场套餐的改变,第一次实例化默认False
@@ -72,13 +79,13 @@ class TopBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "对不起,请先授权登录"
             return invoke_result_data
-        app_info = app_info_model.get_entity(where="store_user_nick=%s", params=store_user_nick)
+        app_info = app_info_model.get_entity(where="store_user_nick=%s and template_id=%s", params=[store_user_nick, template_id])
         # 有效时间获取
         invoke_result_data = self.get_dead_date(store_user_nick, access_token, app_key, app_secret, is_log)
         if invoke_result_data.success == False:
             return invoke_result_data
         dead_date = invoke_result_data.data
-        project_code = self.get_project_code(store_user_nick,access_token, app_key, app_secret, is_log)
+        project_code = self.get_project_code(store_user_nick, access_token, app_key, app_secret, is_log)
         if app_info:
             if main_user_open_id !="" and app_info.main_user_open_id == "":
                 app_info.main_user_open_id = main_user_open_id
@@ -92,7 +99,12 @@ class TopBaseModel():
             invoke_result_data = self.get_shop(access_token, app_key, app_secret, is_log)
             if invoke_result_data.success == True:
                 app_info.access_token = access_token
-            app_info_model.update_entity(app_info, "main_user_open_id,expiration_date,project_code,access_token")
+                shop_info = invoke_result_data.data            
+                if "shop_seller_get_response" in shop_info.keys():
+                    app_info.store_name = shop_info["shop_seller_get_response"]["shop"]["title"]
+                    app_info.store_icon = shop_info["shop_seller_get_response"]["shop"]["pic_path"] if "https:" in shop_info["shop_seller_get_response"]["shop"]["pic_path"] or "//gw.alicdn.com" in shop_info["shop_seller_get_response"]["shop"]["pic_path"]  else "http://logo.taobao.com/shop-logo" + shop_info["shop_seller_get_response"]["shop"]["pic_path"]
+                
+            app_info_model.update_entity(app_info, "main_user_open_id,expiration_date,project_code,access_token,store_name,store_icon")
             app_info_model.delete_dependency_key(DependencyKey.app_info(app_info.app_id))
             invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": user_nick, "access_token": app_info.access_token, "seller_id":app_info.seller_id, "is_change_project_code":is_change_project_code}
             return invoke_result_data
@@ -108,12 +120,12 @@ class TopBaseModel():
         #     invoke_result_data.error_code = "account_error"
         #     invoke_result_data.error_message = "对不起，请使用主账号或者授权的子账号进行创建"
         #     return invoke_result_data
-        
+
         invoke_result_data = self.get_shop(access_token, app_key, app_secret, is_log)
         if invoke_result_data.success == False:
             if invoke_result_data.error_code == "no_power":
                 invoke_result_data.error_code = "account_error"
-                invoke_result_data.error_message = "对不起，初次创建活动包含实例化，请使用主账号进行创建。"
+                invoke_result_data.error_message = "该账号无操作权限，请联系主账号开通小程序权限"
             return invoke_result_data
 
         shop_info = invoke_result_data.data if invoke_result_data.success == True else {}
@@ -130,7 +142,7 @@ class TopBaseModel():
             req.template_version = template_version
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【小程序实例化】" + SevenHelper.json_dumps(req)
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【小程序实例化】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -158,15 +170,13 @@ class TopBaseModel():
                 app_info.store_name = shop_info["shop_seller_get_response"]["shop"]["title"]
                 app_info.store_id = shop_info["shop_seller_get_response"]["shop"]["sid"]
                 app_info.store_icon = shop_info["shop_seller_get_response"]["shop"]["pic_path"]
-                if app_info.store_icon != "":
-                    app_info.store_icon = "http://logo.taobao.com/shop-logo" + app_info.store_icon
 
             invoke_result_data = self.get_user_seller(access_token,app_key,app_secret, is_log)
             user_seller = invoke_result_data.data if invoke_result_data.success == True else {}
             if "user_seller_get_response" in user_seller.keys():
                 app_info.seller_id = user_seller["user_seller_get_response"]["user"]["user_id"]
 
-            app_info.is_instance = 1
+            app_info.is_instance = is_instance
             app_info.store_user_nick = store_user_nick
             app_info.instance_date = SevenHelper.get_now_datetime()
             app_info.modify_date = SevenHelper.get_now_datetime()
@@ -178,7 +188,7 @@ class TopBaseModel():
             if "miniapp_template_onlineapp_response" in online_app_info.keys():
                 app_info.app_url = online_app_info["miniapp_template_onlineapp_response"]["app_info"]["online_url"]
             app_info.id = app_info_model.add_entity(app_info)
-            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": store_user_nick, "user_nick": user_nick, "access_token": access_token, "seller_id":app_info.seller_id, "is_change_project_code":is_change_project_code}
+            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": store_user_nick, "user_nick": user_nick, "access_token": access_token, "seller_id":app_info.seller_id, "is_change_project_code":is_change_project_code, "is_first_instance": True}
             return invoke_result_data
         except Exception as ex:
             if self.context:
@@ -218,7 +228,7 @@ class TopBaseModel():
             req.template_version = client_ver
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【app更新】" + SevenHelper.json_dumps(req)
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token  + "【app更新】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -265,6 +275,9 @@ class TopBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
+        invoke_result_data.data = ""
+        if not num_iids or not sku_id:
+            return invoke_result_data
         try:
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.ItemsSellerListGetRequest()
@@ -280,14 +293,15 @@ class TopBaseModel():
             if "items_seller_list_get_response" in resp.keys():
                 if "items" in resp["items_seller_list_get_response"].keys():
                     props_names = resp["items_seller_list_get_response"]["items"]["item"][0]["props_name"].split(';')
-                    for sku in resp["items_seller_list_get_response"]["items"]["item"][0]["skus"]["sku"]:
-                        if sku["sku_id"] == sku_id:
-                            props_name = [i for i in props_names if sku["properties"] in i]
-                            if len(props_name) > 0:
-                                invoke_result_data.data = props_name[0][(len(sku["properties"]) + 1):]
-                            else:
-                                invoke_result_data.data = sku["properties_name"].split(':')[1]
-                            return invoke_result_data
+                    if "skus" in resp["items_seller_list_get_response"]["items"]["item"][0]:
+                        for sku in resp["items_seller_list_get_response"]["items"]["item"][0]["skus"]["sku"]:
+                            if sku["sku_id"] == sku_id:
+                                props_name = [i for i in props_names if sku["properties"] in i]
+                                if len(props_name) > 0:
+                                    invoke_result_data.data = props_name[0][(len(sku["properties"]) + 1):]
+                                else:
+                                    invoke_result_data.data = sku["properties_name"].split(':')[1]
+                                return invoke_result_data
             return invoke_result_data
         except Exception as ex:
             if self.context:
@@ -308,7 +322,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_buy_order_info(self, order_no, access_token, app_key, app_secret,is_log=False):
+    def get_buy_order_info(self, order_no, access_token, app_key, app_secret,is_log=False, fields="tid,status,payment,price,created,orders,num,pay_time,buyer_open_uid"):
         """
         :description: 获取单笔订单
         :param order_no：订单编号
@@ -316,6 +330,7 @@ class TopBaseModel():
         :param app_key:app_key
         :param app_secret:app_secret
         :param is_log：是否记录返回信息
+        :param fields: 查询字段
         :return: InvokeResultData
         :last_editors: HuangJianYi
         """
@@ -324,7 +339,7 @@ class TopBaseModel():
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.OpenTradeGetRequest()
 
-            req.fields = "tid,status,payment,price,created,orders,num,pay_time,buyer_open_uid"
+            req.fields = fields
             req.tid = order_no
             resp = req.getResponse(access_token)
             if is_log:
@@ -357,7 +372,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_buy_order_list(self, open_id, access_token, app_key, app_secret, start_created="", end_created="", page_size=50, is_log=False, type="fixed,step",field="tid,status,payment,price,created,orders,num,pay_time,step_trade_status,step_paid_fee,type"):
+    def get_buy_order_list(self, open_id, access_token, app_key, app_secret, start_created="", end_created="", page_size=50, is_log=False, type="fixed,step",field="tid,status,payment,price,created,orders,num,pay_time,step_trade_status,step_paid_fee,type,outer_iid", page_count = None):
         """
         :description: 获取淘宝购买订单，出现API字段映射错误，请提供参数信息联系小二处理。字段名:buyer_nick，说明open_id跟app_key没对应上，不是app_key下产品的open_id
         :param open_id：open_id
@@ -370,12 +385,15 @@ class TopBaseModel():
         :param is_log：是否记录返回信息
         :param type：订单类型
         :param field：返回字段
+        :param page_count：循坏获取的页数
         :return InvokeResultData
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         all_order = []
         has_next = True
+        if page_size > 100:
+            page_size = 100
         try:
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.OpenTradesSoldGetRequest()
@@ -396,7 +414,7 @@ class TopBaseModel():
             while has_next:
                 resp = req.getResponse(access_token)
                 if is_log:
-                    log_info = str(resp) + "【access_token】：" + access_token + "【获取购买订单】"
+                    log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【获取购买订单】"
                     if self.context:
                         self.context.logging_link_info(log_info)
                     elif self.logging_link_info:
@@ -406,6 +424,8 @@ class TopBaseModel():
                         all_order = all_order + resp["open_trades_sold_get_response"]["trades"]["trade"]
                     req.page_no += 1
                     has_next = resp["open_trades_sold_get_response"]["has_next"]
+                    if page_count and req.page_no > page_count:
+                        has_next = False
             invoke_result_data.data = all_order
             return invoke_result_data
         except Exception as ex:
@@ -466,7 +486,7 @@ class TopBaseModel():
             while has_next:
                 resp = req.getResponse(access_token)
                 if is_log:
-                    log_info = str(resp) + "【access_token】：" + access_token + "【获取退单订单】"
+                    log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【获取退单订单】"
                     if self.context:
                         self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -524,7 +544,7 @@ class TopBaseModel():
             req.app_version = app_version
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【app上线】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【app上线】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -567,7 +587,7 @@ class TopBaseModel():
             req.fields = "sid,title,pic_path"
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【获取店铺信息】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【获取店铺信息】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -595,7 +615,7 @@ class TopBaseModel():
 
     def get_user_seller(self, access_token, app_key, app_secret, is_log=False):
         """
-        :description: 获取关注店铺用户信息
+        :description: 查询卖家用户信息
         :param access_token：access_token
         :param app_key：app_key
         :param app_secret：app_secret
@@ -610,7 +630,7 @@ class TopBaseModel():
             req.fields = "user_id,nick,sex"
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【获取关注店铺用户信息】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【查询卖家用户信息】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -703,7 +723,7 @@ class TopBaseModel():
                 req.num_iids = cur_num_iids
                 resp = req.getResponse(access_token)
                 if is_log:
-                    log_info = str(resp) + "【access_token】：" + access_token + "【获取在售商品列表by_goodsids】"
+                    log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【获取在售商品列表by_goodsids】"
                     if self.context:
                         self.context.logging_link_info(log_info)
                     elif self.logging_link_info:
@@ -768,7 +788,7 @@ class TopBaseModel():
                 req.order_by = order_tag + ":" + order_by
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【获取在售商品列表】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【获取在售商品列表】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -818,7 +838,7 @@ class TopBaseModel():
             req.num_iid = num_iid
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【获取单个商品详细信息】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【获取单个商品详细信息】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -877,7 +897,7 @@ class TopBaseModel():
                 resp["pageSize"] = page_size
                 resp["pageIndex"] = page_index
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token+ "【获取仓库商品列表】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【获取仓库商品列表】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -926,7 +946,7 @@ class TopBaseModel():
             req.add_bind = status
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【小程序投放商品】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【小程序投放商品】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -971,7 +991,7 @@ class TopBaseModel():
             req.order_id_request["order_id_list"] = order_id_list
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【查询小程序投放计划】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【查询小程序投放计划】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -997,7 +1017,7 @@ class TopBaseModel():
                         invoke_result_data.error_message = content[len("submsg="):]
                         return invoke_result_data
             return invoke_result_data
-    
+
     def alibaba_benefit_query(self, right_ename, access_token, app_key, app_secret, is_log=False):
         """
         :description: 查询优惠券详情信息
@@ -1018,7 +1038,7 @@ class TopBaseModel():
             req.award_type = "1"
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【查询优惠券详情信息】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【查询优惠券详情信息】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1067,7 +1087,7 @@ class TopBaseModel():
             req.app_name = "promotioncenter-" + share_config.get_value("server_template_id")
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【发放优惠劵】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【发放优惠劵】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1115,7 +1135,7 @@ class TopBaseModel():
                 req.nick = nick
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【获取淘宝会员信息】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【获取淘宝会员信息】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1163,7 +1183,7 @@ class TopBaseModel():
                 if "member_info" in resp["crm_member_identity_get_response"]["result"].keys():
                     is_member = True
         return is_member
-    
+
     def get_member_grade(self, mix_nick, access_token, app_key, app_secret, is_log=False):
         """
         :description: 查询会员等级
@@ -1181,11 +1201,11 @@ class TopBaseModel():
             return invoke_result_data
         resp = invoke_result_data.data
         if "crm_member_identity_get_response" in resp.keys():
-                if "result" in resp["crm_member_identity_get_response"].keys():
-                    if "member_info" in resp["crm_member_identity_get_response"]["result"].keys():
-                        if "grade" in resp["crm_member_identity_get_response"]["result"]["member_info"].keys() and "grade_name" in resp["crm_member_identity_get_response"]["result"]["member_info"].keys():
-                            member_info = resp["crm_member_identity_get_response"]["result"]["member_info"]
-        
+            if "result" in resp["crm_member_identity_get_response"].keys():
+                if "member_info" in resp["crm_member_identity_get_response"]["result"].keys():
+                    if "grade" in resp["crm_member_identity_get_response"]["result"]["member_info"].keys() and "grade_name" in resp["crm_member_identity_get_response"]["result"]["member_info"].keys():
+                        member_info = resp["crm_member_identity_get_response"]["result"]["member_info"]
+
         invoke_result_data.data = member_info
         return invoke_result_data
 
@@ -1207,7 +1227,7 @@ class TopBaseModel():
             req.extra_info = "{\"source\":\"isvapp\",\"activityId\":\"\",\"entrance\":\"hudong\"}"
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【获取加入会员地址】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【获取加入会员地址】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1219,6 +1239,9 @@ class TopBaseModel():
                         if invoke_result_data.data and "https:" not in invoke_result_data.data and "http:" not in invoke_result_data.data:
                             invoke_result_data.data = "https:" + invoke_result_data.data
                         return invoke_result_data
+            else:
+                invoke_result_data.data = ""
+                return invoke_result_data
         except Exception as ex:
             if self.context:
                 self.context.logging_link_error(traceback.format_exc())
@@ -1257,7 +1280,7 @@ class TopBaseModel():
             req.miniapp_id = app_id
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【专属下单查询】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【专属下单查询】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1307,7 +1330,7 @@ class TopBaseModel():
             req.limit_num = 1
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【专属下单可购买用户标记】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【专属下单可购买用户标记】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1359,7 +1382,7 @@ class TopBaseModel():
             req.item_ids = str(goods_id)
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【专属下单商品绑定】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【专属下单商品绑定】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1438,7 +1461,7 @@ class TopBaseModel():
             req.nick = user_nick
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【订购关系查询】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【订购关系查询】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1471,7 +1494,7 @@ class TopBaseModel():
             req.miniapp_url = url
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【获取短链接】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【获取短链接】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1520,7 +1543,7 @@ class TopBaseModel():
                 req.open_uid = open_id
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + str(resp) +  "【access_token】：" + access_token + "【获取店铺会员积分】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【获取店铺会员积分】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1552,7 +1575,7 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def change_crm_point(self, open_id, mix_nick, change_type, opt_type, quantity, access_token, app_key, app_secret, activity_id=0, activity_name="", is_log=False):
+    def change_crm_point(self, open_id, mix_nick, change_type, opt_type, quantity, access_token, app_key, app_secret, activity_id=0, activity_name="", is_log=False, account_date=""):
         """
         :description: 操作店铺会员积分
         :param open_id：买家open_id
@@ -1566,6 +1589,7 @@ class TopBaseModel():
         :param activity_id：活动Id
         :param activity_name：活动名称
         :param is_log：是否记录返回信息
+        :param account_date：积分有效期，主要用于互动场景,示例值：2017-07-30
         :return 返回操作结果
         :last_editors: HuangJianYi
         """
@@ -1577,6 +1601,12 @@ class TopBaseModel():
                 req.activity_id = activity_id
             if activity_name:
                 req.activity_name = activity_name
+            if account_date:
+                req.account_date = account_date
+            else:
+                crm_point_account_date = share_config.get_value("crm_point_account_date", 0)
+                if crm_point_account_date > 0:
+                    req.account_date = TimeHelper.add_days_by_format_time(day=crm_point_account_date, format='%Y-%m-%d')
             req.change_type = change_type
             req.opt_type = opt_type
             req.quantity = quantity
@@ -1586,7 +1616,7 @@ class TopBaseModel():
                 req.mix_nick = mix_nick
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + str(resp) + "【access_token】：" + access_token + "【操作店铺会员积分】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【操作店铺会员积分】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1639,7 +1669,7 @@ class TopBaseModel():
             req.param0["template_id"] = widget_template_id
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【查询淘宝小部件信息】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【查询淘宝小部件信息】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1664,7 +1694,7 @@ class TopBaseModel():
                         invoke_result_data.error_message = content[len("submsg="):]
                         return invoke_result_data
             return invoke_result_data
-        
+
     def miniapp_widget_template_instantiate(self, template_version, description, widget_template_id, access_token, app_key, app_secret, is_log=False):
         """
         :description: 实例化小部件 resp={"miniapp_widget_template_instantiate_response": {"result": {"model": {"app_description": "提供商家会员权益集合", "app_icon": "https://ossgw.alicdn.com/taobao-miniapp/img/39eb12a3c266c7a8d72e8dcb1b6a1530.png", "app_name": "天志C店_会员身份卡片", "appkey": "400013325276", "id": "3000000070599924", "online_code": "https://m.duanqu.com/?_ariver_appid=3000000070599924&_mp_code=tb&transition=present", "online_version": "0.0.1"}, "success": True}, "request_id": "15rv0rkcwiqtn"}}
@@ -1688,7 +1718,7 @@ class TopBaseModel():
             req.param_mini_app_instantiate_template_app_simple_request["description"] = description
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【实例化小部件】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【实例化小部件】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -1724,7 +1754,7 @@ class TopBaseModel():
                         invoke_result_data.error_message = content[len("submsg="):]
                         return invoke_result_data
             return invoke_result_data
-        
+
     def miniapp_widget_template_instance_update(self, widgets_id, widget_template_id, template_version, access_token, app_key, app_secret, is_log=False):
         """
         :description: 更新小部件版本
@@ -1748,7 +1778,7 @@ class TopBaseModel():
             req.param_mini_app_instantiate_template_app_update_request["template_version"] = template_version
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【更新小部件版本】"
+                log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + SevenHelper.json_dumps(resp) + "【access_token】：" + access_token + "【更新小部件版本】"
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
