@@ -2,13 +2,15 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2023-03-24 20:25:14
+@LastEditTime: 2025-04-28 14:22:32
 @LastEditors: HuangJianYi
 @Description: 
 """
 from emoji import unicode_codes
 from seven_cloudapp_frame.libs.customize.cryptography_helper import CryptographyHelper
+from seven_cloudapp_frame.libs.customize.wechat_helper import WeChatHelper
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.libs.customize.safe_helper import SafeHelper
 from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
 from seven_cloudapp_frame.models.db_models.user.user_account_model import *
@@ -28,19 +30,24 @@ class UserBaseModel(FrameBaseModel):
         self.context = context
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
+        self.db_connect_key, self.redis_config_dict = SevenHelper.get_connect_config("db_user","redis_user")
         super(UserBaseModel, self).__init__(context)
 
-    def _get_user_info_id_md5(self, act_id, user_id):
+    def _get_user_info_id_md5(self, act_id, user_id, app_id=''):
         """
         :description: 生成用户信息唯一标识
         :param act_id：活动标识
         :param user_id：用户标识
+        :param app_id：应用标识
         :return: 用户信息唯一标识
         :last_editors: HuangJianYi
         """
-        if not act_id or not user_id:
+        if (not app_id and not act_id) or not user_id:
             return 0
-        return CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}")
+        if act_id > 0:
+            return CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}")
+        else:
+            return CryptoHelper.md5_encrypt_int(f"{app_id}_0_{user_id}")
 
     def _delete_user_black_cache(self, act_id, user_id, delay_delete_time=0.01):
         """
@@ -53,7 +60,7 @@ class UserBaseModel(FrameBaseModel):
         """
         UserBlackModel().delete_dependency_key(DependencyKey.user_black(act_id, user_id),delay_delete_time)
 
-    def _delete_user_info_cache(self, act_id, id_md5, delay_delete_time=0.01):
+    def _delete_user_info_cache(self, act_id, id_md5, delay_delete_time=0.01, open_id=''):
         """
         :description: 删除用户信息缓存
         :param act_id：活动标识
@@ -62,7 +69,10 @@ class UserBaseModel(FrameBaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        UserInfoModel().delete_dependency_key(DependencyKey.user_info(act_id, id_md5),delay_delete_time)
+        dependency_keys = [DependencyKey.user_info(act_id, id_md5)]
+        if open_id:
+            dependency_keys.append(DependencyKey.user_info(act_id, "", open_id))
+        UserInfoModel().delete_dependency_keys(dependency_keys, delay_delete_time)
 
     def get_user_info_dict(self, app_id, act_id, user_id, open_id="", is_cache=True):
         """
@@ -75,10 +85,10 @@ class UserBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         user_info_dict = None
-        if not act_id or (not user_id and not open_id):
+        if (not act_id and not app_id) or (not user_id and not open_id):
             return user_info_dict
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}),context=self.context)
-        id_md5 = self._get_user_info_id_md5(act_id, user_id)
+        user_info_model = UserInfoModel(context=self.context).set_sub_table(app_id)
+        id_md5 = self._get_user_info_id_md5(act_id, user_id, app_id)
         dependency_key = DependencyKey.user_info(act_id, id_md5, open_id)
         if id_md5:
             if is_cache:
@@ -91,7 +101,7 @@ class UserBaseModel(FrameBaseModel):
             else:
                 user_info_dict = user_info_model.get_dict("act_id=%s and open_id=%s", limit="1", params=[act_id, open_id])
 
-        if user_info_dict and user_info_dict["app_id"] != app_id:
+        if user_info_dict and SafeHelper.authenticat_app_id(user_info_dict["app_id"], app_id) == False:
             user_info_dict = None
         return user_info_dict
 
@@ -138,7 +148,7 @@ class UserBaseModel(FrameBaseModel):
         if end_date:
             condition += " AND create_date<=%s"
             params.append(end_date)
-        page_list, total = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}),context=self.context).get_dict_page_list("*", page_index, page_size, condition, order_by=order_by, params=params)
+        page_list, total = UserInfoModel(context=self.context).set_sub_table(app_id).get_dict_page_list("*", page_index, page_size, condition, order_by=order_by, params=params)
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
@@ -155,9 +165,9 @@ class UserBaseModel(FrameBaseModel):
         top_base_model = TopBaseModel(context=self.context)
         return top_base_model.get_join_member_url(access_token, app_key, app_secret, is_log)
 
-    def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id="", login_ip="", is_update_user_nick=True, mix_nick=''):
+    def save_user_by_openid(self, app_id, act_id, open_id, user_nick, avatar, union_id="", login_ip="", is_update_user_nick=True, mix_nick='', plat_type=0, continue_request_expire=1, is_acquire_lock=False, is_refresh_token=True):
         """
-        :description: 获取或更新用户信息（主要用于登录）
+        :description: 获取或更新用户信息（主要用于登录），注意事项：压测的时候如果使用同一个用户可能触发行级锁
         :param app_id：应用标识
         :param act_id：活动标识
         :param open_id：open_id
@@ -167,32 +177,48 @@ class UserBaseModel(FrameBaseModel):
         :param login_ip：登录ip地址
         :param is_update_user_nick：是否更新用户昵称
         :param mix_nick：混淆昵称
+        :param plat_type：注册平台类型
+        :param continue_request_expire：连续请求限制时间，0不限制
+        :param is_acquire_lock：是否开启分布式锁
+        :param is_refresh_token：是否刷新token
         :return: 返回用户信息
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not act_id or not open_id:
+        if not open_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
-            invoke_result_data.error_message = "参数不能为空或等于0"
+            invoke_result_data.error_message = "参数不能为空"
             return invoke_result_data
 
-        acquire_lock_name = f"save_user_by_openid:{app_id}_{open_id}"
-        acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
-        if acquire_lock_status == False:
+        if continue_request_expire > 0 and SevenHelper.is_continue_request(f"continue_request:save_user_by_openid:{app_id}_{open_id}", expire=continue_request_expire * 1000) == True:
             invoke_result_data.success = False
-            invoke_result_data.error_code = "acquire_lock"
-            invoke_result_data.error_message = "请求超时,请稍后再试"
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = f"对不起,请{continue_request_expire}秒后再试"
             return invoke_result_data
+        if is_acquire_lock == True:
+            acquire_lock_name = f"save_user_by_openid:{app_id}_{open_id}"
+            acquire_lock_status, identifier = SevenHelper.redis_acquire_lock(acquire_lock_name)
+            if acquire_lock_status == False:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "acquire_lock"
+                invoke_result_data.error_message = "请求超时,请稍后再试"
+                return invoke_result_data
 
         user_account = None
         user_account_model = UserAccountModel(context=self.context)
         user_info = None
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}), context=self.context)
+        user_info_model = UserInfoModel(context=self.context).set_sub_table(app_id)
         now_datetime = SevenHelper.get_now_datetime()
         try:
-            user_account = user_account_model.get_cache_entity("open_id=%s", params=[open_id],dependency_key=DependencyKey.user_account(open_id))
+            user_account = user_account_model.get_cache_entity("open_id=%s", params=[open_id], dependency_key=DependencyKey.user_account(open_id))
             if not user_account:
+                # 设置默认昵称和头像
+                user_config = share_config.get_value("user_config",{})
+                if not user_nick:
+                    user_nick = user_config.get("default_user_nick","")
+                if not avatar:
+                    avatar = user_config.get("default_avatar", "")
                 user_account = UserAccount()
                 user_account.union_id = union_id
                 user_account.open_id = open_id
@@ -229,11 +255,11 @@ class UserBaseModel(FrameBaseModel):
                 user_account_model.update_entity(user_account, "user_nick,user_nick_encrypt,mix_nick,avatar,union_id,login_date,login_ip")
                 if delete_account_cache == True:
                     user_account_model.delete_dependency_key(DependencyKey.user_account(open_id))
-                    
-            user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
+
+            user_info = user_info_model.get_cache_entity("act_id=%s and open_id=%s", params=[act_id, open_id], dependency_key=DependencyKey.user_info(act_id, "", open_id))
             if not user_info:
                 user_info = UserInfo()
-                user_info.id_md5 = self._get_user_info_id_md5(act_id, user_account.id)
+                user_info.id_md5 = self._get_user_info_id_md5(act_id, user_account.id, app_id)
                 user_info.app_id = app_id
                 user_info.act_id = act_id
                 user_info.open_id = open_id
@@ -243,14 +269,14 @@ class UserBaseModel(FrameBaseModel):
                 user_info.user_nick = user_account.user_nick
                 user_info.user_nick_encrypt = user_account.user_nick_encrypt
                 user_info.avatar = user_account.avatar
-                user_info.avatar = avatar if avatar else user_info.avatar
                 user_info.is_auth = 0 if not user_info.user_nick else 1
                 user_info.create_date = now_datetime
                 user_info.modify_date = now_datetime
                 user_info.login_token = SevenHelper.get_random(16)
+                user_info.plat_type = plat_type
                 user_info.id = user_info_model.add_entity(user_info)
             else:
-                if user_info.app_id != app_id:
+                if SafeHelper.authenticat_app_id(user_info.app_id, app_id) == False:
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "非法操作"
@@ -264,9 +290,10 @@ class UserBaseModel(FrameBaseModel):
                 #     user_info.is_new = 0
                 user_info.is_new = 0
                 user_info.modify_date = now_datetime
-                user_info.login_token = SevenHelper.get_random(16)
+                if is_refresh_token == True:
+                    user_info.login_token = SevenHelper.get_random(16)
                 user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,user_nick_encrypt,avatar,is_auth,union_id")
-                user_info_model.delete_dependency_key([DependencyKey.user_info(act_id, user_info.id_md5), DependencyKey.user_info(act_id, "", user_info.open_id)])
+            user_info_model.delete_dependency_key([DependencyKey.user_info(act_id, user_info.id_md5), DependencyKey.user_info(act_id, "", open_id)])
 
         except Exception as ex:
             if self.context:
@@ -274,7 +301,10 @@ class UserBaseModel(FrameBaseModel):
             elif self.logging_link_error:
                 self.logging_link_error("【获取或更新用户信息】" + traceback.format_exc())
         finally:
-            SevenHelper.redis_release_lock(acquire_lock_name, identifier)
+            if is_acquire_lock == True:
+                SevenHelper.redis_release_lock(acquire_lock_name, identifier)
+            else:
+                pass
         if not user_info:
             invoke_result_data.success = False
             invoke_result_data.error_code = "fail"
@@ -304,19 +334,19 @@ class UserBaseModel(FrameBaseModel):
         """
         invoke_result_data = InvokeResultData()
 
-        if not act_id or (not user_id and not open_id):
+        if (not act_id and not app_id) or (not user_id and not open_id):
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
-        
+
         # 进行授权，有头像没昵称，则给默认的昵称
         if avatar and not user_nick:
             user_nick = "未知"
 
         user_account_model = UserAccountModel(context=self.context)
         user_info_dict = None
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}),context=self.context)
+        user_info_model = UserInfoModel(context=self.context).set_sub_table(app_id)
 
         try:
             user_info_dict = self.get_user_info_dict(app_id, act_id, user_id, open_id)
@@ -326,7 +356,7 @@ class UserBaseModel(FrameBaseModel):
                 invoke_result_data.error_message = "更新失败，找不到用户信息"
                 return invoke_result_data
             else:
-                if user_info_dict["app_id"] != app_id:
+                if SafeHelper.authenticat_app_id(user_info_dict["app_id"], app_id) == False:
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
                     invoke_result_data.error_message = "非法操作"
@@ -339,7 +369,7 @@ class UserBaseModel(FrameBaseModel):
                 user_info_dict["avatar"] = avatar if avatar else user_info_dict["avatar"]
                 user_info_dict["is_auth"] = 1 if user_info_dict["user_nick"] else 0
                 user_info_dict["modify_date"] = SevenHelper.get_now_datetime()
-                user_info_model.update_table("user_nick=%s,user_nick_encrypt=%s,avatar=%s,modify_date=%s,is_auth=%s,is_member_before=%s,is_favor_before=%s", "id=%s", params=[user_info_dict["user_nick"], user_info_dict["user_nick_encrypt"], user_info_dict["avatar"], user_info_dict["modify_date"], user_info_dict["is_auth"], user_info_dict["is_member_before"], user_info_dict["is_favor_before"], user_info_dict["id"]])
+                user_info_model.update_table("user_nick=%s,user_nick_encrypt=%s,avatar=%s,modify_date=%s,is_auth=%s,is_member_before=%s,is_favor_before=%s", "id_md5=%s", params=[user_info_dict["user_nick"], user_info_dict["user_nick_encrypt"], user_info_dict["avatar"], user_info_dict["modify_date"], user_info_dict["is_auth"], user_info_dict["is_member_before"], user_info_dict["is_favor_before"], user_info_dict["id_md5"]])
                 user_info_model.delete_dependency_key([DependencyKey.user_info(act_id, user_info_dict["id_md5"]), DependencyKey.user_info(act_id, "", user_info_dict["open_id"])])
 
                 update_sql = ""
@@ -376,15 +406,15 @@ class UserBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        id_md5 = self._get_user_info_id_md5(act_id, user_id)
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}), context=self.context)
+        id_md5 = self._get_user_info_id_md5(act_id, user_id, app_id)
+        user_info_model = UserInfoModel(context=self.context).set_sub_table(app_id)
         user_info = user_info_model.get_entity("id_md5=%s", params=[id_md5])
         if not user_info:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "用户信息不存在"
             return invoke_result_data
-        if user_info.app_id != app_id:
+        if SafeHelper.authenticat_app_id(user_info.app_id, app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
@@ -401,23 +431,24 @@ class UserBaseModel(FrameBaseModel):
         user_info.modify_date = modify_date
         user_info_model.update_entity(user_info, "user_state,relieve_date,modify_date")
 
-        self._delete_user_info_cache(user_info.act_id, user_info.id_md5)
+        self._delete_user_info_cache(user_info.act_id, user_info.id_md5, open_id=user_info.open_id)
         invoke_result_data.data = user_info.__dict__
         return invoke_result_data
 
-    def update_user_state_by_black(self, app_id, act_id, user_id, reason=""):
+    def update_user_state_by_black(self, app_id, act_id, user_id, reason="", black_type=2):
         """
         :description: 用户拉入黑名单
         :param app_id：应用标识
         :param act_id：活动标识
         :param user_id：用户标识
         :param reason：拉黑理由
+        :param black_type：拉黑类型(1-自动 2-手动)
         :return:
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"),context=self.context)
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}), db_transaction=db_transaction, context=self.context)
+        db_transaction = DbTransaction(db_config_dict=config.get_value(self.db_connect_key), context=self.context)
+        user_info_model = UserInfoModel(db_transaction=db_transaction, context=self.context).set_sub_table(app_id)
         user_black_model = UserBlackModel(db_transaction=db_transaction, context=self.context)
 
         user_info_dict = self.get_user_info_dict(app_id, act_id, user_id)
@@ -426,7 +457,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "用户信息不存在"
             return invoke_result_data
-        if user_info_dict["app_id"] != app_id:
+        if SafeHelper.authenticat_app_id(user_info_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
@@ -452,14 +483,14 @@ class UserBaseModel(FrameBaseModel):
                 user_black.user_id = user_info_dict["user_id"]
                 user_black.open_id = user_info_dict["open_id"]
                 user_black.user_nick = user_info_dict["user_nick"]
-                user_black.black_type = 2
+                user_black.black_type = black_type
                 user_black.refund_order_data = []
                 user_black.reason = reason
                 user_black.create_date = SevenHelper.get_now_datetime()
                 user_black_model.add_entity(user_black)
             else:
                 user_black.audit_status = 0
-                user_black.black_type = 2
+                user_black.black_type = black_type
                 user_black.reason = reason
                 user_black.create_date = SevenHelper.get_now_datetime()
                 user_black_model.update_entity(user_black)
@@ -467,7 +498,7 @@ class UserBaseModel(FrameBaseModel):
             if not result:
                 raise Exception("执行事务失败",mesage)
             invoke_result_data.data = {"user_info": user_info_dict}
-            self._delete_user_info_cache(user_info_dict["act_id"], user_info_dict["id_md5"])
+            self._delete_user_info_cache(user_info_dict["act_id"], user_info_dict["id_md5"], open_id=user_info_dict["open_id"])
             self._delete_user_black_cache(act_id, user_id)
         except Exception as ex:
             if self.context:
@@ -491,7 +522,7 @@ class UserBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not act_id or (not user_id and not open_id):
+        if (not act_id and not app_id) or (not user_id and not open_id):
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
@@ -502,7 +533,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "用户信息不存在"
             return invoke_result_data
-        if user_info_dict["app_id"] != app_id:
+        if SafeHelper.authenticat_app_id(user_info_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
@@ -514,7 +545,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_message = "账号正常,无需申请解封"
             return invoke_result_data
         user_black_model = UserBlackModel(context=self.context)
-        user_black = user_black_model.get_cache_entity("act_id=%s and user_id=%s", order_by="create_date desc", params=[act_id, user_id], dependency_key=DependencyKey.user_black(act_id, user_id))
+        user_black = user_black_model.get_cache_entity("act_id=%s and user_id=%s", order_by="id desc", params=[act_id, user_id], dependency_key=DependencyKey.user_black(act_id, user_id))
         if not user_black:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -555,14 +586,14 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "找不到该条记录"
             return invoke_result_data
-        if user_black.app_id != app_id:
+        if SafeHelper.authenticat_app_id(user_black.app_id, app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
             return invoke_result_data
 
-        user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}),context=self.context)
-        id_md5 = self._get_user_info_id_md5(user_black.act_id, user_black.user_id)
+        user_info_model = UserInfoModel(context=self.context).set_sub_table(app_id)
+        id_md5 = self._get_user_info_id_md5(user_black.act_id, user_black.user_id, app_id)
         user_info = user_info_model.get_entity("id_md5=%s", params=[id_md5])
         if not user_info:
             invoke_result_data.success = False
@@ -592,7 +623,7 @@ class UserBaseModel(FrameBaseModel):
             user_black_model.update_table(condition, "id=%s", params)
 
         invoke_result_data.data = {"user_info": user_info.__dict__}
-        self._delete_user_info_cache(user_info.act_id, user_info.id_md5)
+        self._delete_user_info_cache(user_info.act_id, user_info.id_md5, open_id=user_info.open_id)
         self._delete_user_black_cache(user_black.act_id, user_black.user_id)
         return invoke_result_data
 
@@ -618,7 +649,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "找不到该条记录"
             return invoke_result_data
-        if user_black.app_id != app_id:
+        if SafeHelper.authenticat_app_id(user_black.app_id, app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
@@ -639,18 +670,17 @@ class UserBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         user_black_dict = None
-        if not act_id or not user_id:
+        if (not act_id and not app_id) or not user_id:
             return user_black_dict
         user_info_dict = self.get_user_info_dict(app_id, act_id, user_id)
         if not user_info_dict:
             return user_black_dict
         where = "act_id=%s and user_id=%s"
         params = [act_id, user_id]
-        user_black_model = UserBlackModel(context=self.context)
         if is_cache:
-            user_black_dict = user_black_model.get_cache_dict(where=where, limit="1", params=params, dependency_key=DependencyKey.user_black(act_id, user_id))
+            user_black_dict = UserBlackModel(context=self.context, is_auto=True).get_cache_dict(where=where, limit="1", params=params, dependency_key=DependencyKey.user_black(act_id, user_id))
         else:
-            user_black_dict = user_black_model.get_dict(where, limit="1", params=params)
+            user_black_dict = UserBlackModel(context=self.context).get_dict(where, limit="1", params=params)
         return user_black_dict
 
     def get_black_list(self, app_id, act_id, page_size=20, page_index=0, audit_status=-1, user_id=0, start_date="", end_date="", user_nick="", open_id="", order_by="id desc"):
@@ -706,13 +736,14 @@ class UserBaseModel(FrameBaseModel):
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
-    def check_pull_black(self, user_info_dict, is_black, refund_count, all_order_data):
+    def check_pull_black(self, user_info_dict, is_black, refund_count, all_order_data, plat_type = 1):
         """
         :description: 校验是否拉黑
         :param user_info_dict：用户信息字典
         :param is_black：是否拉黑
         :param refund_count：退款次数
         :param all_order_data:淘宝订单列表
+        :param plat_type:平台类型
         :return: 
         :last_editors: HuangJianYi
         """
@@ -720,14 +751,17 @@ class UserBaseModel(FrameBaseModel):
         try:
             if user_info_dict["user_state"] == 0 and is_black == 1 and refund_count > 0:
                 #退款的订单  子订单存在退款 记录一次
-                refund_order_data = [i for i in all_order_data if i["refund_status"] not in self.refund_status()]
+                if plat_type == 1:
+                    refund_order_data = [i for i in all_order_data if i.get("refund_status") and i.get("refund_status") not in self.refund_status()]
+                else:
+                    refund_order_data = [i for i in all_order_data if i.get("after_sale_info") and str(i["after_sale_info"]['refund_status']) == '3']
                 #如果不是黑用户 并且存在退款时间 代表黑用户解禁
                 if user_info_dict["relieve_date"] != '1900-01-01 00:00:00':
                     refund_order_data = [i for i in refund_order_data if TimeHelper.format_time_to_datetime(str(i['pay_time'])) > TimeHelper.format_time_to_datetime(str(user_info_dict["relieve_date"]))]
                 #超过变成黑用户
                 if len(refund_order_data) >= refund_count:
                     result = True
-                    user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":user_info_dict["app_id"]}),context=self.context)
+                    user_info_model = UserInfoModel(context=self.context).set_sub_table(user_info_dict["app_id"])
                     user_info_model.update_table("user_state=1", "id=%s", user_info_dict["id"])
                     user_black_model = UserBlackModel(context=self.context)
                     user_black = user_black_model.get_entity("act_id=%s and user_id=%s", params=[user_info_dict["act_id"], user_info_dict["user_id"]])
@@ -758,7 +792,7 @@ class UserBaseModel(FrameBaseModel):
                         user_black.refund_order_data = SevenHelper.json_dumps(refund_order_data)
                         user_black.create_date = SevenHelper.get_now_datetime()
                         user_black_model.add_entity(user_black)
-                    self._delete_user_info_cache(user_info_dict["act_id"], user_info_dict["id_md5"])
+                    self._delete_user_info_cache(user_info_dict["act_id"], user_info_dict["id_md5"], open_id=user_info_dict["open_id"])
         except Exception as ex:
             if self.context:
                 self.context.logging_link_error("【校验是否拉黑】" + traceback.format_exc())
@@ -767,34 +801,37 @@ class UserBaseModel(FrameBaseModel):
             result = False
         return result
 
-    def get_user_address_list(self, app_id, act_id, user_id, is_cache=True):
+    def get_user_address_list(self, app_id, act_id, user_id, is_cache=True, decrypt_field_list=["real_name","telephone","province","city","county","street","address"]):
         """
         :description: 获取用户地址列表
         :param app_id：应用标识
         :param act_id：活动标识
         :param tb_user_id：用户标识
         :param is_cache：是否缓存
+        :param decrypt_field_list: 需要解密的字段列表        
         :return: 
         :last_editors: HuangJianYi
         """
-        user_address_list = []
-        if not act_id or not user_id:
-            return user_address_list
+        user_address_dict_list = []
+        if (not act_id and not app_id) or not user_id:
+            return user_address_dict_list
         condition = "act_id=%s AND user_id=%s"
         params = [act_id, user_id]
         if app_id:
             condition += " AND app_id=%s"
             params.append(app_id)
-        
-        user_address_model = UserAddressModel(context=self.context)
+
         if is_cache:
-            user_address_list = user_address_model.get_cache_dict_list(condition, limit="100", params=params, dependency_key=DependencyKey.user_address_list(act_id,user_id))
+            user_address_dict_list = UserAddressModel(context=self.context, is_auto=True).get_cache_dict_list(condition, limit="100", params=params, dependency_key=DependencyKey.user_address_list(act_id,user_id))
         else:
-            user_address_list = user_address_model.get_dict_list(condition, limit="100", params=params)
+            user_address_dict_list = UserAddressModel(context=self.context).get_dict_list(condition, limit="100", params=params)
 
-        return user_address_list
+        # 敏感字段加密
+        user_address_dict_list, status = self.sensitive_decrypt(user_address_dict_list, decrypt_field_list)
 
-    def save_user_address(self, app_id, act_id, user_id, open_id, user_address_id, real_name, telephone, province, city, county, street, address, is_default):
+        return user_address_dict_list
+
+    def save_user_address(self, app_id, act_id, user_id, open_id, user_address_id, real_name, telephone, province, city, county, street, address, is_default, remark=""):
         """
         :description: 保存用户地址
         :param app_id：应用标识
@@ -810,11 +847,12 @@ class UserBaseModel(FrameBaseModel):
         :param street：街道
         :param address：地址
         :param is_default：是否默认地址（1是0否）
+        :param remark：备注（用于存放第三方的县ID、街道ID等信息）
         :return: 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not act_id or (not user_id and not open_id):
+        if (not act_id and not app_id) or (not user_id and not open_id):
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
@@ -835,13 +873,13 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "用户信息不存在"
             return invoke_result_data
-        if user_info_dict["app_id"] != app_id:
+        if SafeHelper.authenticat_app_id(user_info_dict["app_id"], app_id) == False:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "非法操作"
             return invoke_result_data
 
-        user_address_model = UserAddressModel()
+        user_address_model = UserAddressModel(context=self.context)
         if is_default == 1:
             user_address_model.update_table("is_default=0", "act_id=%s and user_id=%s", params=[act_id, user_id])
         user_address = None
@@ -849,6 +887,14 @@ class UserBaseModel(FrameBaseModel):
             user_address = user_address_model.get_entity("act_id=%s and user_id=%s", params=[act_id, user_id])
             user_address_id = user_address.id if user_address else 0
 
+        real_name = self.sensitive_encrypt(real_name)
+        telephone = self.sensitive_encrypt(telephone)
+        province = self.sensitive_encrypt(province)
+        city = self.sensitive_encrypt(city)
+        county = self.sensitive_encrypt(county)
+        street = self.sensitive_encrypt(street)
+        address = self.sensitive_encrypt(address)
+
         if user_address_id > 0:
             if not user_address:
                 user_address = user_address_model.get_entity("id=%s", params=[user_address_id])
@@ -865,7 +911,8 @@ class UserBaseModel(FrameBaseModel):
             user_address.street = street
             user_address.address = address
             user_address.is_default = is_default
-            user_address_model.update_entity(user_address, "real_name,telephone,province,city,county,street,address,is_default")
+            user_address.remark = remark
+            user_address_model.update_entity(user_address, "real_name,telephone,province,city,county,street,address,is_default,remark")
         else:
             user_address = UserAddress()
             user_address.app_id = app_id
@@ -880,7 +927,34 @@ class UserBaseModel(FrameBaseModel):
             user_address.street = street
             user_address.address = address
             user_address.is_default = is_default
+            user_address.remark = remark
             user_address.create_date = SevenHelper.get_now_datetime()
             user_address_model.add_entity(user_address)
         user_address_model.delete_dependency_key(DependencyKey.user_address_list(act_id,user_id))
         return invoke_result_data
+
+    def update_user_telephone(self, open_id, telephone="", code=""):
+        """
+        :description: 更新用户手机号
+        :param open_id：open_id
+        :param telephone：手机号
+        :param code: 微信code，用于获取手机号
+        :return: InvokeResultData
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        if not telephone and not code:
+            invoke_result_data.error_code = "param_error"
+            invoke_result_data.error_message = "telephone和code不能都为空"
+            return invoke_result_data
+        if code:
+            invoke_result_data = WeChatHelper.get_user_phonenumber(code, share_config.get_value("app_id"), share_config.get_value("app_secret"))
+            if invoke_result_data.success == False:
+                return invoke_result_data
+            telephone = invoke_result_data.data.get("phoneNumber","")
+        # 敏感字段加密
+        telephone = self.sensitive_encrypt(telephone)
+        user_account_model = UserAccountModel(context=self.context)
+        user_account_model.update_table("telephone=%s","open_id=%s",params=[telephone, open_id])
+        user_account_model.delete_dependency_key(DependencyKey.user_account(open_id))
+        return invoke_result_data
