@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2023-02-16 17:56:48
+@LastEditTime: 2024-08-20 18:48:19
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -17,14 +17,15 @@ def seven_cloudapp_frame_route():
     return [
         (r"/monitor", MonitorHandler),
         (r"/", IndexHandler),
+        (r"/websocket", WebSocketBaseHandler),  # 连接websocket
         #客户端
-        (r"/client/address_list", address.AddressInfoListHandler),  #收货地址列表
+        (r"/client/address_list", address.AddressInfoListHandler),  #行政区列表
         (r"/client/login", user.LoginHandler),  #小程序登录
         (r"/client/update_user_info", user.UpdateUserInfoHandler),  #更新用户信息如昵称、头像等
         (r"/client/check_is_member", user.CheckIsMemberHandler),  #校验是否是店铺会员
         (r"/client/apply_black_unbind", user.ApplyBlackUnbindHandler),  #申请黑名单解封
         (r"/client/get_unbind_apply", user.GetUnbindApplyHandler),  #获取黑名单解封申请记录
-        (r"/client/user_asset_list", user.GetUserAssetHandler),  #获取单条用户资产
+        (r"/client/user_asset", user.GetUserAssetHandler),  #获取单条用户资产
         (r"/client/user_asset_list", user.UserAssetListHandler),  #用户资产列表
         (r"/client/asset_log_list", user.AssetLogListHandler),  #用户资产流水列表
         (r"/client/get_join_member_url", user.GetJoinMemberUrlHandler),  #加入会员地址
